#ifndef __tts_lib  ' mult include guard
	#define __tts_lib

	#if 0	// Source Code Header

		/*=======================================================================================
		#
		#	tts.bas:
		#   - This file, when #included (after being updated for an ARMbasic host), enables use
		#		of the MikroElektronika TextToSpeech Click which is based on the Epson S1V30120
		#
		#	Setup and Use:
		#	- TODO: [explain use, file rqmts, lib rqmts, locations, etc. to enable employment]
		#
		#	Acknowledgements:
		#	- Attribution:	This library was ported from original c source code:
		#					https://github.com/MikroElektronika/Click_TextToSpeech_S1V30120
		#
		#	Resources:
		#	- https://global.epson.com/products_and_drivers/semicon/products/speech/voice/s1v30120.html
		#	- ADD DROPBOX LINK HERE WITH ARCHIVE OF ALL TOOLS AND DOCS/DATA COLLECTED TO DATE
		#
		#	Other Lib Requirements:
		#		memset.bas	- implements an approximation of the C standard library function
		#
		#========================================================================================
		#
		#	Revision History:
		#.........................................................................................
		#	0179_2345	TAW	27JUN20	feature additions - Released: via coridium.us forums
		#
		#	Updates:
		#		✓ renamed lib files from .lib to .bas per B's suggestion
		#		✓ modified all 0x hex prefixes for hex values to &H, per B's suggestion
		#		✓ chased down a silly hang I was getting on the 1756 during the tts_hw-init proc
		#			ended up having to throw a goofy 10ms wait therein - dunno why, but it fixed it...
		#.........................................................................................
		#	0175_2145	TAW	23Jun20	Initial Instantiation - Released: via coridium.us forums
		#
		#	Ported during 31May2020-23Jun2020
		#
		#	Features:
		#		✓ Works with Coridium's SuperPRO Rev 7
		#		✓ Works with Coridium's ARMbasic firmware running on an Itaca uChip
		#		✓ Works with Coridium's ARMbasic firmware running on a Protoneer Nano-ARM
		#		✓ Works with Coridium's ARMbasic firmware running on a RobotDyn SAMD21 M0
		#
		#========================================================================================
		#	Known Issues Actively Being Worked:
		#		- Adding support for other Coridium Targets
		#
		#========================================================================================
		#	FIXMEs
		#	   - ...
		#
		#.........................................................................................
		#	To Dos:
		#		- Address Known Issues/FIXMEs detailed above
		#		- ...
		#
		#========================================================================================

		NOTES TO CONSIDER WHEN MODIFYING LIBRARY FOR NEW TARGET MICROCONTROLLERS

		There are 5 areas of code that need to be massaged when modifying this lib for new target controllers.

		If you search for all instances of the term 'LPC1756' you'll be pointed to where you need to make
		changes or additions.  Namely:

		1) in the Preprocessor Hardware Specific section (to set IOs and ASM_delay value #defines)
			- each target/package has varying IO TO PIN definitions
			- each target mcu operates as a specific freq and the asm delay values for fixed delays need #defining
				- you can do the math for 12-14 cycles and then base the values there on, or use a tool to measure
				  and average the round-trip-time to make a series of calls to the tts_asmdly(count) proc
			- notionally, a 200MHz controller takes some 61.x nS for each loop through the delay proc
			- whereas, a 48MHz controller takes some 279.x nS for same
			- the ASMdelay proc is being used to implement short programmatic delays as interrupts are overtly
			  disabled when BB'g SPI, for non-corrupted communication purposes - the interrupts were corrupting comms...
		2) in the text_to_speech_hw.h plus other non_hw specific preprocessor stuff (for led state logic)
			- some boards sink LED current to illuminate it (active lo)
			- while others are active hi and source voltage to illuminate it (active hi - SAMd21s boards for example)
		3) in the interrupt sub timer1irq proc (controller specific timer interrupt clearing code)
			- each controller has specific interrupt clearing codes for the NVIC, depending on the peripherial employed
		4) in the code block following the ISR, the tts_on_timer procs (controller specific timer instantiation)
			- each controller has specific timer instantiation code, depending on the peripherial employed
		5) in the tts_hw_init() proc (controller specific timer start code)
			- each controller has specific timer start codes, depending on the peripherial employed
		*/

		#endif

	#if 0	// File info from the C source and header files that have been folded into this library

		/** text_to_speech.h
		* Text to Speech
		*
		* The device operates as a companion device. It is connected to a host using
		* the SPI. When connected to a host, the operation of the device is completely
		* determined by control and data information provided by the host. Control and
		* data information is transferred to and from device using a defined
		* message protocol.
		*
		* The features of the messaging protocol are presented below :
		* - The device is completely driven by the reception of messages from the
		*   host.
		* - The message set is byte oriented, with a fixed length header part,
		*   and variable length payload
		* - The messages follow a request –> response flow. All request messages are
		*   sent by the host processor. All response messages are generated by the
		*   device in response to a request message.
		* - The host processor is required to wait for a response to a request
		*   message, before issuing any subsequent request. Any request message sent
		*   before receiving the previous response will trigger an error state within
		*   the device.
		* - Some messages are termed indication messages. Such messages require no
		*   confirmation from the recipient. Indication messages can only be sent by
		*   the device.
		*
		* In general, a response message is sent immediately on receiving its
		* corresponding request message. The sending of a response informs the host
		* that the request has been received but not that it has been actioned.
		* However for some messages, the interval between the sending of a request and
		* receipt of a response can be considerable. In corner cases, the delay
		* between the sending of a request message by a host and the receipt of the
		* corresponding response message can be several hundred milliseconds.
		* Delay between request and response is guaranteed not to exceed
		* MAX_RESPONSE_TIME.
		*
		* The device have two working modes - boot and main mode. The device boot mode
		* is entered on hardware reset. The device requires the download of
		* initialisation data in boot mode before it is run in main mode.
		* This initialisation data is contained in the device binary file included
		* with this documentation.
		* @link text_to_speech_img.h @endlink
		* In order to enter the main work mode user should call execution of the loaded
		* image
		* @link tts_runtime_image_exec @endlink
		* and registration of the host with the device with
		* @link tts_interface_test @endlink.
		* After this steps device enters the main working mode.
		*
		* Any request message can be sent at any time after the last response message
		* has been received. If it is inappropriate to send a request message at a
		* certain point, then the device will indicate this with a non-fatal error
		* code in the response message.
		*
		* In the normal course of operation, the host should not receive a reserved
		* error from device. Non-fatal errors can be viewed as warnings, from which
		* the system recovers, and have no adverse effect on system behaviour.
		* Non-fatal errors are communicated to the host processor via the appropriate
		* response message, or, in an application specific error indication.
		* A response message that includes an error code indicates that the requested
		* action could not be completed. Fatal errors cannot be recovered by software.
		* The only recovery mechanism is to reset the device. Fore more informations
		* about error codes
		* @link TTS_ERROR_t @endlink.
		*
		* All functions inside this module returns recevied response from device so
		* sucessfull execution will return 0 and all other returned values means
		* that function is not executed properly.
		*/

		/** text_to_speech_hw.h
		* Hardware Layer
		*
		* Low level functions for
		* <a href="http://www.mikroe.com">MikroElektronika's</a> TextToSpeech click
		* board.
		* /

		// ** @page LIB_INFO Library Info
		* @date 28 Jan 2016
		* @author Milos Vidojevic
		* @copyright GNU Public License
		* @version 1.0.0 - Initial testing and verification
		* /

		/ ** @page TEST_CFG Test Configurations
		*
		* ### Test configuration 1 : ###
		* - <b>MCU</b> :             STM32F107VC
		* - <b>Dev.Board</b> :       EasyMx Pro v7
		* - <b>Oscillator</b> :      72 Mhz internal
		* - <b>Ext. Modules</b> :    TextToSpeech Click
		* - <b>SW</b> :              MikroC PRO for ARM 4.7.1
		*
		* ### Test configuration 2 : ###
		* - <b>MCU</b> :             PIC32MX795F512L
		* - <b>Dev. Board</b> :      EasyPIC Fusion v7
		* - <b>Oscillator</b> :      80 Mhz internal
		* - <b>Ext. Modules</b> :    TextToSpeech Click
		* - <b>SW</b> :              MikroC PRO for PIC32 3.6.0
		*
		* ### Test configuration 3 : ###
		* - <b>MCU</b> :             FT900Q
		* - <b>Dev. Board</b> :      EasyFT9&H v7
		* - <b>Oscillator</b> :      100 Mhz internal
		* - <b>Ext. Modules</b> :    TextToSpeech Click
		* - <b>SW</b> :              MikroC PRO for FT9&H 1.2.1
		*
		* /

		/ ** @page SCH Schematic
		*  not [Schematic](../tts_sch.png)
		* /

		/ ** @page PIN Pin Usage
		*  not [Pins](../tts_pins.png)
		* /

		/ ** @mainpage
		* ### General Desription ###
		*
		* The S1V30120 is a Speech Synthesis IC that provides a cost effective
		* solution for adding Text-To-Speech (TTS) and ADPCM speech processing
		* applications to a range of portable devices. The highly integrated design
		* reduces overall system cost and time-to-market. The S1V30120 contains all
		* the required analogue codecs, memory, and EPSON - supplied embedded
		* algorithms. All applications are controlled over a single serial interface
		* (SPI) allowing control from a wide range of hosts and rapid integration
		* into existing products.
		*
		* ### Features ###
		*
		* - Text To Speech Synthesis (TTS)
		*      + Fonix DECtalk v5, fully parametric speech synthesis
		*      + Languages: US English, Castilian Spanish, Latin American Spanish
		*      + Nine pre-defined voices
		*      + Sampling rate: 11.025kHz
		*
		* - Audio reproduction (ADPCM)
		*      + ADPCM decoding (in Epson’s original format)
		*      + Bit rate: 80kbps, 64kbps, 48kbps, 40kbps, 32kbps and 24kbps
		*      + Sampling rate: 16, 8 kHz
		*
		* - Host interface
		*      + Synchronous serial interface (SPI interface is supported)
		*      + Command control
		*
		* - 16-bit full-digital amplifier
		*      + Sampling rate (fs): 16, 11.025 and 8 kHz
		*      + Digital Input: 16 bits
		*      + Operating voltage: 3.3/1.8V
		*
		* - Clock
		*      + 32.768KHz
		*
		* - Package
		*      + 64-pin TQFP (10mm x 10mm) with 0.5mm-pitch pins
		*
		* - Supply voltage
		*      + 3.3V (I/O power supply)
		*      + 1.8V (Core power supply)
		*/

		/** text_to_speech_hal.h
		* HAL layer
		*
		* HAL layer for
		* <a href="http://www.mikroe.com">MikroElektronika's</a> TextToSpeech click
		* board.
		*/

		/** text_to_speech_img.h
		*  What is does
		*
		*  @date 25 Aug 2015
		*  @author Richard Lowe
		*  @copyright GNU Public License
		*
		*  @version .1 - Initial testing and verification
		*
		*  @note Test configuration:
		*   MCU:             STM32F107VC
		*   Dev.Board:       EasyMx Pro v7
		*   Oscillator:      72 Mhz internal
		*   Ext. Modules:    GPS Click
		*   SW:              ARM 4.5.2
		*
		*/

		/** text_to_speech.c
		* Text to speech click board higher level functions
		*/

		/** text_to_speech_hal.c
		* HAL layer
		*/

		/** text_to_speech_hw.c
		* This module contains the low level function for MikroElektronika 's
		* Text to Speech click board.
		*/

		#endif

	#include "memset.bas"		// I home brewed this to help with the porting aspects of getting the c source running in an AB context

	#if 1 // Preprocessor & Hardware Specific stuffs

		#define false (0)
		#define true (not(false))

		#define lo (0)
		#define hi (not (lo))

		// see https://i.imgur.com/5eEAGJt.png for initialization timing
		// see https://i.imgur.com/oB7zm86.png for reset:comms delay
		// see https://i.imgur.com/ezqjxNK.png for comms timing
		// see https://global.epson.com/products_and_drivers/semicon/products/speech/voice/s1v30120.html
		// for docs, guides, tools, encoders, etc.

		#if 1 	// Hardware defs and other stuffs
				// in addition to these elements, take a peek down below for other hardware specific #defs (search for timer_defs)

			#ifdef LPC1756 	// Hardware defs

				#define tts_reset_io							60
				#define tts_csel_io								0
				#define tts_sclk_io								10
				#define tts_mosi_io								68
				#define tts_mute_io								57
				#define tts_miso_io								70
				#define	tts_ready_io							22
				#define led0_io									74

				// delays in tts_asmdly context
				// RTT (Round Trip Time) to tts_asmdly is ~120.7408nS/call on 100MHz 1756

				#define csel_dwell_asmdly_cnt					&H02		// >=200nS
				#define sclk_dwell_asmdly_cnt					&H09		// 1us is min cycle time - 1MHz clock - were not close with BB'g att
				#define miso_ready_asmdly_cnt					&H02		// >=200ns
				#define mosi_setup_asmdly_cnt					&H01		// >=10nS
				#define mosi_hold_asmdly_cnt					&H02		// >=200nS
				#define reset_keepout_asmdly_cnt				&H000005FF	//keep-out window around reset - 2 Tosc (32.768K) 61.x uS - &H5FF nets about 200uS
				#define tts_10ms_asmdly_cnt						&H00014585
				#define tts_45ms_asmdly_cnt						&H0005B8D8
				#define tts_120ms_asmdly_cnt					&H000F2A49
				#define tts_140ms_asmdly_cnt					&H0011B156
				#define tts_150ms_asmdly_cnt					&H001312D0
				#define tts_500ms_asmdly_cnt					&H003F940A

			#elif defined SAMD21

// If you are using Extended BASICtools, I made recent enhancements to EBT and did
// away with having to manually define the sub-species of SAMD21 (board type) by way
// of having separate patched firmwares for each board and then having the tool chain
// query that during compilation, to set #defs via CLI when invoking the preprocessor
// i.e. -DSAMD21_uChip or -DSAMD21_Robotdyn or ...
// https://i.imgur.com/GsRwgEQ.png as of 23 Jun 2020...

				// #defs to make use of timer5
				#define R08_GCLK_STATUS            &H40000C01 ' REG8  GCLK Status
				#define R16_GCLK_CLKCTRL           &H40000C02 ' REG16 GCLK Generic Clock Control
				#define R16_TC5_CTRLA              &H42003400 ' REG16 TC5 Control A
				#define R08_TC5_INTENSET           &H4200340D ' REG8  TC5 Interrupt Enable Set
				#define R08_TC5_INTFLAG            &H4200340E ' REG8  TC5 Interrupt Flag Status and Clear
				#define R08_TC5_STATUS             &H4200340F ' REG8  TC5 Status

				#ifdef SAMD21_uChip

					#warning BUILDING FOR: uChip
					#define tts_mosi_io								16
					#define tts_miso_io								19
					#define	tts_ready_io							23
					#define tts_sclk_io								17
					#define tts_csel_io								18
					#define tts_reset_io							22
					#define tts_mute_io								10
					#define led0_io									7

					#define vext_select_io							15
					#define boot_enable_io							14

				#elif defined SAMD21_Robotdyn

					#warning BUILDING FOR: Robotdyn M0
					#define tts_mosi_io								17
					#define tts_miso_io								19
					#define	tts_ready_io							6
					#define tts_sclk_io								21
					#define tts_csel_io								20
					#define tts_reset_io							15
					#define tts_mute_io								14
					#define led0_io									17

				#elif defined SAMD21_Protoneer

					#warning BUILDING FOR: Prontoneer Nano
					#define tts_mosi_io								17
					#define tts_miso_io								19
					#define	tts_ready_io							6
					#define tts_sclk_io								21
					#define tts_csel_io								20
					#define tts_reset_io							15
					#define tts_mute_io								08
					#define led0_io									17

				#else
					#error need to #define a specific sub_species of the SAMD21
					#endif

				// delays in tts_asmdly context
				// RTT (Round Trip Time) to tts_asmdly is ~279.21771240nS/call on 48MHz SAMD21

				#define csel_dwell_asmdly_cnt					&H01		// >=200nS
				#define sclk_dwell_asmdly_cnt					&H04		// 1us is min cycle time - 1MHz clock - were not close with BB'g att
				#define miso_ready_asmdly_cnt					&H01		// >=200ns
				#define mosi_setup_asmdly_cnt					&H01		// >=10nS
				#define mosi_hold_asmdly_cnt					&H01		// >=200nS
				#define reset_keepout_asmdly_cnt				&H000000DB	//keep-out window around reset - 2 Tosc (32.768K) 61.x uS - &H5FF nets about 200uS
				#define tts_10ms_asmdly_cnt						&H00008C03
				#define tts_45ms_asmdly_cnt						&H0002760B
				#define tts_120ms_asmdly_cnt					&H0006901C
				#define tts_140ms_asmdly_cnt					&H0007A821
				#define tts_150ms_asmdly_cnt					&H00083423
				#define tts_500ms_asmdly_cnt					&H001B5873

			#else
				#error Need to modify the tts.lib to support your target

				#endif // host-specific defines

			#endif // Host-Specific stuffs

		#if 1 // text_to_speech_hw.h plus other non_hw specific #defs

			#define tts_reset_active						out(tts_reset_io) = lo
			#define tts_reset_idle							out(tts_reset_io) = hi

			#define tts_csel_active							out(tts_csel_io) = lo
			#define tts_csel_idle  							out(tts_csel_io) = hi

			#define tts_sclk_active							out(tts_sclk_io) = lo
			#define tts_sclk_idle  							out(tts_sclk_io) = hi

			#define tts_mosi_active							out(tts_mosi_io) = hi
			#define tts_mosi_idle  							out(tts_mosi_io) = lo

			#define tts_mute_active							out(tts_mute_io) = lo
			#define tts_mute_idle  							out(tts_mute_io) = hi

			#ifdef LPC1756  	// LED state defs
				#define tts_led_active						out(led0_io) = lo
				#define tts_led_idle						out(led0_io) = hi
			#elif defined SAMD21
				#define tts_led_active						out(led0_io) = hi
				#define tts_led_idle						out(led0_io) = lo
				#endif

			#define tts_ready								in(tts_ready_io)
			#define tts_cs_state							in(tts_csel_io)
			#define tts_miso								in(tts_miso_io)
			#define tts_mosi								out(tts_mosi_io)

			dim _pad_bytes_reqd as integer					// used by each comms routine to hold qty of padding bytes required - most 16, but 2 critical msgs are 8 pad bytes.

			#define tts_leave_cs_active						1  // used when calling tts_write_req proc to keep cs active vs. idle'g it when proc completes

			#define max_response_asmdly_period 				tts_500ms_asmdly_cnt	/* Max response time in ms - if there is no response after this amount
																					* of time user should restart the device */
			#define reset_to_boot_asmdly_period				tts_150ms_asmdly_cnt	// Time needed for module to gets into the boot mode after reset.
			#define boot_to_main_mode_asmdly_period 		tts_140ms_asmdly_cnt	// Time needed for module to gets from boot mode into main work mode.
			#define post_reset_asmdly_period				tts_120ms_asmdly_cnt	// 120ms see https://i.imgur.com/oB7zm86.png
			#define stby_mode_entry_asmdly_period  			tts_45ms_asmdly_cnt		// Time needed for module to enter the standby mode

			#define MAIN_MESSAGE_MAX  						2116				/* Maximum message size in main mode. Recomended size is 2116 but
																				* if needed it can be resized to save the RAM space. Note that
																				* MAIN_MESSAGE_MAX must be greater than BOOT_MESSAGE_MAX. This number
																				* decreased by 7 also represents the maximum size of the string that
																				* can be sent in one command. */
			#define BOOT_MESSAGE_MAX  						2048		/** Maximum message size in boot mode. Recomended size is 2048 but
																		* if needed it can be resized to save RAM space. Note that
																		* BOOT_MESSAGE_MAX must be smaller than MAIN_MESSAGE_MAX */
			#define RESP_MESSAGE_MAX  						24  		// Maximum response message max
			#define START_MESSAGE     						&HAA		// Mark for the start of message
			#define PADDING_BYTE      						&H00		// Pading data used to flash the channels

			#endif // text_to_speech_hw.h

		#if 1 // text_to_speech.h

			#define ISC_VERSION_REQ_BOOT                    &H0005
			#define ISC_VERSION_RESP_BOOT                   &H0006
			#define ISC_BOOT_LOAD_REQ                       &H1000
			#define ISC_BOOT_LOAD_RESP                      &H1001
			#define ISC_BOOT_RUN_REQ                        &H1002
			#define ISC_BOOT_RUN_RESP                       &H1003

			#define ISC_TEST_REQ                            &H0003
			#define ISC_TEST_RESP                           &H0004
			#define ISC_VERSION_REQ_MAIN                    &H0005
			#define ISC_VERSION_RESP_MAIN                   &H0006
			#define ISC_ERROR_IND                           &H0000
			#define ISC_MSG_BLOCKED_RESP                    &H0007

			#define ISC_AUDIO_CONFIG_REQ                    &H0008
			#define ISC_AUDIO_CONFIG_RESP                   &H0009
			#define ISC_AUDIO_VOULME_REQ                    &H000A
			#define ISC_AUDIO_VOLUME_RESP                   &H000B
			#define ISC_AUDIO_MUTE_REQ                      &H000C
			#define ISC_AUDIO_MUTE_RESP                     &H000D

			#define ISC_PMAN_CONFIG_REQ                     &H0062
			#define ISC_PMAN_CONFIG_RESP                    &H0063
			#define ISC_PMAN_STANDBY_ENTRY_REQ              &H0064
			#define ISC_PMAN_STANDBY_ENTRY_RESP             &H0065
			#define ISC_PMAN_STANDBY_EXIT_IND               &H0066

			#define ISC_SPCODEC_CONFIG_REQ                  &H0056
			#define ISC_SPCODEC_CONFIG_RESP                 &H0057
			#define ISC_SPCODEC_START_REQ                   &H0058
			#define ISC_SPCODEC_START_RESP                  &H0059
			#define ISC_SPCODEC_PAUSE_REQ                   &H005C
			#define ISC_SPCODEC_PAUSE_RESP                  &H005D
			#define ISC_SPCODEC_STOP_REQ                    &H005A
			#define ISC_SPCODEC_STOP_RESP                   &H005B
			#define ISC_SPCODEC_READY_IND                   &H0060
			#define ISC_SPCODEC_FINISHED_IND                &H0061

			#define ISC_TTS_CONFIG_REQ                      &H0012
			#define ISC_TTS_CONFIG_RESP                     &H0013
			#define ISC_TTS_SPEAK_REQ                       &H0014
			#define ISC_TTS_SPEAK_RESP                      &H0015
			#define ISC_tts_ready_IND                       &H0020
			#define ISC_TTS_FINISHED_IND                    &H0021
			#define ISC_TTS_PAUSE_REQ                       &H0016
			#define ISC_TTS_PAUSE_RESP                      &H0017
			#define ISC_TTS_STOP_REQ                        &H0018
			#define ISC_TTS_STOP_RESP                       &H0019
			#define ISC_TTS_UDICT_DATA_REQ                  &H00CE
			#define ISC_TTS_UDICT_DATA_RESP                 &H00D0

			// no gpio messages as they are not brought out on the ME Clik - may do so however,
			// as there are a number of unused IOs on the board - flying wire circus party.?.

			/* In the normal course of operation, the HOST should not receive a reserved error
			from S1V30120.  Non-fatal errors can be viewed as warnings, from which the system
			recovers, and have no adverse effect on system behaviour.  Non-fatal errors are
			communicated to the HOST processor via the appropriate RESPonse message, or, in an
			application specific error INDication.  A RESPonse message that includes an error code
			indicates that the requested action could not be completed.  Fatal errors cannot be
			recovered by software. The only recovery mechanism is to reset the S1V30120.  Fatal
			errors are communicated to the HOST using the ISC_ERROR_IND message.  The following
			tables summarise all non-fatal and fatal errors that may be triggered by the HOST: */

			// &H0000 = No Error
			#define	TTS_ERR_NO_ERROR                       	&H0000	// * No Error *

			// &H0001 to &H3FFF = Reserved (internal) non-fatal error

			// &H4000 to &H7FFF = Non-reserved (user) non-fatal error
			#define	TTS_ERR_GEN_INSUFF_RESOURCES           	&H4002	// * Insufficient system resource to perform request *
			#define	TTS_ERR_GEN_UNKNOWN_MSG                	&H4003	// * Unrecognised message ID *
			#define	TTS_ERR_GEN_APP_NO_SUPPORT             	&H4005	// * Application is not supported by device *
			#define	TTS_ERR_AUDIO_INVALID_CONF             	&H4020	// * Invalid audio configuration *
			#define	TTS_ERR_AUDIO_OUT_OF_RANGE             	&H4021	// * Out of range configuration value *
			#define	TTS_ERR_AUDIO_OUT_OF_SEQUENCE          	&H4026	// * Audio message out of sequence *
			#define	TTS_ERR_AUDIO_INVALID_ROUTING_CONF     	&H4028	// * Incompatible routing configuration *
			#define	TTS_ERR_AUDIO_INVALID_FREQUENCY_CONF   	&H4029	// * Incompatible frequency configuration *
			#define	TTS_ERR_PMAN_INVALID_CONF              	&H40C0	// * Power manager invalid configuration *
			#define	TTS_ERR_PMAN_NOT_READY                 	&H40C1	// * Device is not ready to enter standby mode *
			#define	TTS_ERR_TTS_INVALID_LANGUAGE           	&H4040	// * Invalid language *
			#define	TTS_ERR_TTS_INVALID_SAMPLE_RATE        	&H4041	// * Invalid sample rate *
			#define	TTS_ERR_TTS_INVALID_VOICE              	&H4042	// * Invalid voice selection *
			#define	TTS_ERR_TTS_INVALID_DATA_SRC           	&H4043	// * Invalid data source *
			#define	TTS_ERR_TTS_NOT_CONFIGURED             	&H4044	// * TTS not configured *
			#define	TTS_ERR_TTS_NOT_READY                  	&H4045	// * TTS not ready *
			#define	TTS_ERR_TTS_AUDIO_OPEN_FAIL            	&H4046	// * Audio output channel open failed *
			#define	TTS_ERR_TTS_AUDIO_CLOSE_FAIL           	&H4047	// * Audio output channel close failed *
			#define	TTS_ERR_TTS_STOP_ERR                   	&H4048	// * TTS already stopped *
			#define	TTS_ERR_TTS_CONF_REQUEST_ERR           	&H4049	// * Unexpected config request *
			#define	TTS_ERR_TTS_OPEN_ERR                   	&H404A	// * File already open *
			#define	TTS_ERR_TTS_OPEN_FAIL                  	&H404B	// * File open failed *
			#define	TTS_ERR_TTS_CLOSE_FAIL                 	&H404C	// * File close failed *
			#define	TTS_ERR_TTS_PAUSE_ERR                  	&H404F	// * Cannot pause *
			#define	TTS_ERR_TTS_DICT_ERR                   	&H4052	// * Invalid user dictionary file *
			#define	TTS_ERR_TTS_WHIILS_ERR                 	&H4053	// * Invalid whilst paused *
			#define	TTS_ERR_SPCODEC_START_ERR              	&H4101	// * Speech codec not configured before starting *
			#define	TTS_ERR_SPCODEC_PAUSE_ERR              	&H4102	// * Pause attempted when speech codec is inactive *
			#define	TTS_ERR_SPCODEC_CONFIG_ERR             	&H4103	// * Config attempted when speech codec is active *
			#define	TTS_ERR_SPCODEC_DATA_SRC_ERR           	&H4104	// * Invalid data source *
			#define	TTS_ERR_SPCODEC_ALREADY_PAUSED         	&H4106	// * Speech codec already paused *
			#define	TTS_ERR_SPCODEC_PAUSE_FAIL             	&H4107	// * Speech codec already active (not paused) *
			#define	TTS_ERR_SPCODEC_INVALID_CONF           	&H4108	// * Invalid codec configuration *
			#define	TTS_ERR_SPCODEC_INPUT_DATA_ERR         	&H4109	// * Too much input data*
			#define	TTS_ERR_SPCODEC_AUDIO_OPEN_ERR         	&H410B	// * Cannot open audio channel *
			#define	TTS_ERR_SPCODEC_AUDIO_CLOSE_ERR        	&H410C	// * Cannot close audio channel *

			// &H8000 to &HFFFF = Fatal error - no recovery
			#define	TTS_ERR_FATAL_ERR_UNEXPECTED_MSG       	&H80E0	// * Unexpected message *
			#define	TTS_ERR_FATAL_CODEC_ERR_1              	&H8104	// * Invalid SPCODEC file / CODEC error *
			#define	TTS_ERR_FATAL_CODEC_ERR_2              	&H8105	// * Invalid SPCODEC file / CODEC error *
			#define	TTS_ERR_FATAL_CODEC_ERR_3              	&H8106	// * Invalid SPCODEC file / CODEC error *

			// Firmware Features
			#define FF_TTS  								&H0001	// * Text to Speech *
			#define FF_ADPCM								&H0010	// * ADPCM *
			#define FF_GPIO 								&H0100	// * GPIO *

			// Extended Firmware Features * TTS language support.
			#define EFF_US									&H01	// * US English *
			#define EFF_D 									&H02	// * German *
			#define EFF_CS									&H04	// * Castilian Spanish *
			#define EFF_F 									&H08	// * French *
			#define EFF_UK									&H10	// * UK English *
			#define EFF_LS									&H20	// * Latin Spanish *

			// Audio Sample Rate
			#define ASR_8KHZ  								&H00	// * 8 kHz (usable) *
			#define ASR_11KHZ 								&H01	// * 11.025 kHz (usable) *
			#define ASR_12KHZ 								&H02	// * 12 kHz (reserved) *
			#define ASR_16KHZ 								&H03	// * 16 kHz (usable) *
			#define ASR_22KHZ 								&H04	// * 22.05 kHz (reserved) *
			#define ASR_24KHZ 								&H05	// * 24 kHz (reserved) *
			#define ASR_32KHZ 								&H06	// * 32 kHz (reserved) *
			#define ASR_44KHZ 								&H07	// * 44.1 kHz (reserved) *
			#define ASR_48KHZ 								&H08	// * 48 kHz (reserved) *
			#define ASR_AUTO  								&H09	// * Set by application *

			// Voice Configuration
			#define TTSV_US									&H00	// * UK English *
			#define TTSV_CS									&H01	// * Castilian Spanish *
			#define TTSV_LS									&H04	// * Latin Spanish *

			// added by TAW for C->AB porting purposes
			#define NULL									&H00

			#endif // text_to_speech.h

		#if 1 // text_to_speech_hal.h

			#define DUMMY_BYTE								&H00

			#endif // text_to_speech_hal.h

		#if 1 // text_to_speech_img.h

			// 0-31207 - manually calculated, considering a lack of sizeof() function in ARMbasic
			#define TTS_Runtime_Size 31208 	// bytes (0-31207)

			#endif // text_to_speech_img.h

		#endif // Preprocessor Stuffs

	#if 1 // Globals, Structures, Enumerations, and Constants - Structures (Byte? Arrays) and Enumerations (Byte? Constant Arrays)

		#if 1 // text_to_speech_hal.h/.c

			// no globals in text_to_speech_hal.h

			// text_to_speech_hal.c

			// static void         (*tts_write_byte_spi)(unsigned int data_out)
				 'dim tts_write_byte_spi as integer 	// pointer to a (callback?) sub to be called to output a buffer via spi tx
			// made a proper function - no param passing when calling via pointer in AB

			// static unsigned int (*tts_read_byte_spi)(unsigned int buffer)
				 'dim tts_read_byte_spi as integer 	// pointer to a (callback?) func to be called to read spi rx into a buffer
			// made a proper function - no param passing when calling via pointer in AB

			// these are non-standard C - a compiler extension in the MikroC domain - dealing with these separately via AB
			// see https://www.microchip.com/forums/m734261.aspx
			// extern sfr sbit TTS_CS
			// extern sfr sbit TTS_RST
			// extern sfr sbit TTS_RDY
			// extern sfr sbit TTS_MUTE

			#endif

		#if 1 // text_to_speech_hw.h/.c structures (no array enums therein)

			/** @struct ISC_REQ_t 'header + size + payload
			* Request Message Structure
			*
			* All messages that are received and sent by the device are termed ISC
			* (Inter-System-Communication) messages. An ISC message consists of a
			* fixed length header part and a variable length payload.
			*/
			#define ISC_max_req_len								2120 '2+2+2116 (msg_header+ msg_code + MAIN_MESSAGE_MAX)
			dim ISC_REQ_Struct(ISC_max_req_len) as byte
				 'byte offsets & field len (cnt (count))
			#define ISC_REQ_len_os								0 '1:0
			#define ISC_REQ_len_cnt								2		/** Header Part - Message length (including header)
																		* len(0) - LSB
																		* len(1) - MSB */
			#define ISC_REQ_idx_os								2 '3:2
			#define ISC_REQ_idx_cnt								2		/** Header Part - Message code (index)
																		* idx(0) - LSB
																		* idx(1) - MSB */
			#define ISC_REQ_pld_os	 							4 '2119:4
			#define ISC_REQ_pld_cnt	 							2116	// Payload Part - Message data

			/** @struct ISC_RESP_t 'header + size + payload
			* Response Message Structure
			*
			* All messages that are received and sent by the device are termed ISC
			* (Inter-System-Communication) messages. An ISC message consists of a
			* fixed length header part and a variable length payload.
			*/
			#define ISC_max_resp_len							28 '2+2+24 (msg_header+ msg_code + RESP_MESSAGE_MAX)
			dim ISC_RESP_Struct(ISC_max_resp_len) as byte
				 'byte offsets & field len (cnt (count))
			#define ISC_RESP_len_os								0 '1:0
			#define ISC_RESP_len_cnt							2		/** Header Part - Message length (including header)
																		* len(0) - LSB
																		* len(1) - MSB */
			#define ISC_RESP_idx_os								2 '3:2
			#define ISC_RESP_idx_cnt							2		/** Header Part - Message code (index)
																		* idx(0) - LSB
																		* idx(1) - MSB */
			#define ISC_RESP_pld_os	 							4 '27:4
			#define ISC_RESP_pld_cnt 							24		// Payload Part - Message data

			// text_to_speech_hw.c

			dim _ticker_f as integer 	// flag global - originally a bool
			dim _ticker as integer 		// flag global originally a uint16_t

			dim _last_req as integer	// pointers to structures above, I perceive...
			dim _last_rsp as integer	// will need to be initialized, I perceive...

			#endif

		#if 1 // text_to_speech.h/.c

			const tts_RegHostPayload as byte = { &H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00 }

			/** @struct VER_t
			* Device version
			*
			* @note
			* For the hardware version, the first number refers to the hardware  platform,
			* and the second number refers to the ROM revision number.
			*
			* @note
			* The firmware versions are defined as version X.Y.Z. where X is the major
			* release number, Y is the minor release number (typically associated with a
			* functionality enhancement), and Z is an incremental (bug fix) release.
			*/
			dim VER_Struct(16) as byte '5+8+2+1
			 'byte offsets (os) & field len count (cnt)
			#define VER_hwver_os								0	// Hardware version '4:0
			#define VER_hwver_cnt								5
			#define VER_fwver_os								5	// Firmware version '12:5
			#define VER_fwver_cnt								8
			#define VER_fwf_os									13	// Firmware features '13
			#define VER_fwf_cnt									2
			#define VER_fwef_os	 								15	// Firmware extended features '15
			#define VER_fwef_cnt	 							1

			/** @struct ACONF_t
			* Audio Configuration
			*
			* @note
			* If DAC permanently on is set and minimum delay time is required before
			* audio output after receiving a data bearing message, an asr must be
			* selected. It must not be set to ASR_AUTO.
			*
			*/
			dim ACONF_Struct(8) as byte
			dim cur_ACONF_Struct(8) as byte
			 'byte offsets (os) & field len count (cnt)
			#define ACONF_as_os									0	// Audio stereo (&H00)
			#define ACONF_as_cnt								1
			#define ACONF_ag_os									1	// Audio gain value (&H00 - &H43)
			#define ACONF_ag_cnt								1
			#define ACONF_amp_os								2	// Audio amplefier (&H00)
			#define ACONF_amp_cnt								1
			#define ACONF_asr_os								3	// Audio sample rate (&H00 / &H01 / &H03 / &H09)
			#define ACONF_asr_cnt								1
			#define ACONF_ar_os									4	// Audio routing (&H00)
			#define ACONF_ar_cnt								1
			#define ACONF_atc_os								5	// Audio tone control (&H00)
			#define ACONF_atc_cnt								1
			#define ACONF_acs_os								6	// Audio clock source (&H00)
			#define ACONF_acs_cnt								1
			#define ACONF_dc_os									7	// DAC control (&H00 / &H01)
			#define ACONF_dc_cnt								1

			/** @struct TTS_CONFIG_t
			* Text To Speech Configuration
			*
			* TTS configuration can only be used when the TTS system is inactive.
			*
			* @note
			* The valid range for speaking rate is &H004B to &H0258. A suitable default
			* value is 200 words/min (&H00C8).
			*/
			dim TTSCONF_Struct(8) as byte
			dim cur_TTSCONF_Struct(8) as byte
			 'byte offsets (os) & field len count (cnt)
			#define TTSCONF_sr_os								0	// Sample rate (&H01)
			#define TTSCONF_sr_cnt						  		1
			#define TTSCONF_voice_os							1	// Voice selection (&H01 - &H09)
			#define TTSCONF_voice_cnt							1
			#define TTSCONF_ep_os								2	// Epson parse (true / false)
			#define TTSCONF_ep_cnt						  		1
			#define TTSCONF_lang_os								3	// TTS language (&H01 / &H01 / &H04)
			#define TTSCONF_lang_cnt							1
			#define TTSCONF_sr_wpm_lsb_os						4	// Speaking rate in words per minute
			#define TTSCONF_sr_wpm_lsb_cnt						1
			#define TTSCONF_sr_wpm_msb_os						5	// Speaking rate in words per minute
			#define TTSCONF_sr_wpm_msb_cnt						1
			#define TTSCONF_ds_os								6	// Data Source (&H00)
			#define TTSCONF_ds_cnt						  		1
			#define TTSCONF_res_os								7	// Reserved (&H00)
			#define TTSCONF_res_cnt						  		1

			/**
			* @struct PMANCONF_t
			* Power Manager Configuration
			*/
			dim PMANCONF_Struct(8) as byte
			dim cur_PMANCONF_Struct(8) as byte
			 'byte offsets (os) & field len count (cnt)
			#define PMANCONF_am_lsb_os							0	// Audio mode (&H01)
			#define PMANCONF_am_lsb_cnt							1
			#define PMANCONF_am_msb_os							1	// Audio mode (&H01)
			#define PMANCONF_am_msb_cnt							1
			#define PMANCONF_spi_clk_os							2	// SPI bit clock frequency (&H01)
			#define PMANCONF_spi_clk_cnt						1
			#define PMANCONF_pad_os						    	3	// Padding byte
			#define PMANCONF_pad_cnt							1

			// text_to_speech.c

			dim _tts_rdy_f as integer 	// flag global - originally a bool
			dim _spc_rdy_f as integer 	// flag global - originally a bool
			dim _tts_fin_f as integer 	// flag global - originally a bool
			dim _spc_fin_f as integer 	// flag global - originally a bool

			dim _req_err as integer 	// error buffer global
			dim _err_code as integer 	// error buffer global

			dim _audio_conf as integer	// pointers to structures above, I perceive...
			dim _tts_conf as integer	// will need to be initialized, I perceive...
			dim _pman_conf as integer	// am on thin ice here, I perceive... :)

			dim _cur_audio_conf as integer	// pointers to structures above, I perceive...
			dim _cur_tts_conf as integer	// will need to be initialized, I perceive...
			dim _cur_pman_conf as integer	// am on thin ice here, I perceive... :)

			dim _speaking_flush_enable as integer // originally a bool

			dim _fatal_err_callback as integer 	// pointer to some callback func/sub to be called
			dim _err_callback as integer 		// pointer to some callback func/sub to be called
			dim _msg_block_callback as integer 	// pointer to some callback func/sub to be called

			#endif

		#if 1 // text_to_speech_img.h  // leave this folded... - it's not small :)

			const TTS_INIT_DATA_Size = TTS_Runtime_Size

			#if 1	// leave this folded... - it's not small :)
				#if 1	// Really, leave this folded... - it's big :)
					#if 1	// Really, leave this folded... - it's really bigly (~32K) :)
			const TTS_INIT_DATA as byte = {		// I've warned ya, get ready to break your scroll wheel
				&H18, &HF0, &H9F, &HE5, &H18, &HF0, &H9F, &HE5, &H18, &HF0, &H9F, &HE5,
				&H18, &HF0, &H9F, &HE5, &H18, &HF0, &H9F, &HE5, &H00, &H00, &HA0, &HE1,
				&H14, &HF0, &H9F, &HE5, &H14, &HF0, &H9F, &HE5, &H28, &H01, &HF0, &HBF,
				&H40, &H02, &HF0, &HBF, &H44, &H02, &HF0, &HBF, &H48, &H02, &HF0, &HBF,
				&H4C, &H02, &HF0, &HBF, &H50, &H02, &HF0, &HBF, &H54, &H02, &HF0, &HBF,
				&H00, &H00, &H00, &H00, &H08, &H00, &H9F, &HE5, &H08, &H20, &H9F, &HE5,
				&H00, &H20, &H82, &HE0, &H1E, &HFF, &H2F, &HE1, &HF8, &H7D, &HF0, &HBF,
				&H78, &H64, &H01, &H00, &H24, &H00, &H9F, &HE5, &H00, &H10, &HA0, &HE3,
				&H00, &H10, &H80, &HE5, &HC0, &H10, &H80, &HE5, &H18, &H10, &H9F, &HE5,
				&H08, &H10, &H80, &HE5, &HFF, &H10, &HA0, &HE3, &HC4, &H10, &H80, &HE5,
				&H00, &H10, &HA0, &HE3, &H10, &H10, &H80, &HE5, &H1E, &HFF, &H2F, &HE1,
				&H00, &H03, &H00, &HF8, &HFF, &HFF, &H01, &H00, &H00, &H00, &H00, &HEA,
				&H1B, &H0E, &H00, &HEA, &H28, &H00, &H8F, &HE2, &H00, &H0C, &H90, &HE8,
				&H00, &HA0, &H8A, &HE0, &H01, &H70, &H4A, &HE2, &H00, &HB0, &H8B, &HE0,
				&H0B, &H00, &H5A, &HE1, &H14, &H0E, &H00, &H0A, &H0F, &H00, &HBA, &HE8,
				&H14, &HE0, &H4F, &HE2, &H01, &H00, &H13, &HE3, &H03, &HF0, &H47, &H10,
				&H13, &HFF, &H2F, &HE1, &H3C, &H01, &H00, &H00, &H4C, &H01, &H00, &H00,
				&H00, &H00, &HA0, &HE3, &H00, &H50, &HA0, &HE1, &HB4, &H00, &H9F, &HE5,
				&H00, &H00, &H55, &HE3, &HCF, &H10, &HE0, &H03, &HFF, &H10, &HE0, &H13,
				&H00, &H10, &H80, &HE5, &H00, &H10, &HE0, &HE3, &H04, &H10, &H80, &HE5,
				&H0E, &H12, &HE0, &HE3, &H08, &H10, &H80, &HE5, &H94, &H10, &H9F, &H05,
				&H94, &H10, &H9F, &H15, &H0C, &H10, &H80, &HE5, &H90, &H00, &H9F, &HE5,
				&H01, &H10, &HA0, &HE3, &H08, &H10, &H80, &HE5, &H88, &HF0, &H9F, &HE5,
				&H74, &H00, &H9F, &HE5, &H00, &H00, &H55, &HE3, &HCE, &H10, &HE0, &H03,
				&HFE, &H10, &HE0, &H13, &H00, &H10, &H80, &HE5, &H74, &H10, &H9F, &HE5,
				&HFE, &H1F, &H91, &HE8, &H70, &H50, &H9F, &HE5, &HD1, &HF0, &H21, &HE3,
				&H00, &HD0, &H45, &HE2, &HD2, &HF0, &H21, &HE3, &H01, &HDC, &H45, &HE2,
				&HD7, &HF0, &H21, &HE3, &H02, &HDC, &H45, &HE2, &HDB, &HF0, &H21, &HE3,
				&H02, &HDC, &H45, &HE2, &HD3, &HF0, &H21, &HE3, &H02, &HDC, &H45, &HE2,
				&H13, &H00, &H00, &HEB, &H3C, &H00, &H00, &HEB, &H10, &HF0, &H21, &HE3,
				&H0E, &HDD, &H45, &HE2, &H01, &H08, &HA0, &HE3, &H34, &H10, &H9F, &HE5,
				&H24, &H20, &H91, &HE5, &H0F, &H28, &HC2, &HE3, &H00, &H20, &H82, &HE1,
				&H24, &H20, &H81, &HE5, &H02, &H20, &HA0, &HE3, &H2C, &H20, &H81, &HE5,
				&HBE, &HFF, &HFF, &HEA, &H00, &H00, &H00, &HF8, &HF0, &H1F, &HF4, &H2F,
				&HF3, &H1F, &HF4, &H2F, &H00, &H0C, &H00, &HF8, &H14, &H01, &HF0, &HBF,
				&H28, &H01, &HF0, &HBF, &HF8, &HFF, &HF1, &HBF, &H00, &H01, &H00, &HF8,
				&H1C, &H00, &H9F, &HE5, &H18, &H10, &H9F, &HE5, &H18, &H20, &H9F, &HE5,
				&H02, &H10, &H41, &HE0, &H14, &H20, &H9F, &HE5, &H01, &H00, &H50, &HE1,
				&H01, &H20, &H81, &H14, &HFC, &HFF, &HFF, &H1A, &H1E, &HFF, &H2F, &HE1,
				&HF8, &HFF, &HF1, &HBF, &H88, &H1D, &H00, &H00, &HD0, &HD0, &HAD, &HDE,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &HE4, &H79, &HF0, &HBF,
				&HF8, &HFF, &HF1, &HBF, &H04, &H00, &H00, &H00, &H10, &H21, &H00, &HC0,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H7C, &H11, &H04, &HEA, &HAF, &H4F, &H04, &HEA, &H79, &H11, &H04, &HEA,
				&H77, &H11, &H04, &HEA, &H88, &H4F, &H04, &HEA, &H78, &H11, &H04, &HEA,
				&H7E, &HFF, &HFF, &HEA, &HD2, &H4F, &H04, &HEA, &H9A, &H11, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H99, &H11, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H71, &H14, &H00, &HEA, &H71, &H14, &H00, &HEA, &H6F, &H14, &H00, &HEA,
				&H6F, &HFF, &HFF, &HEA, &HB8, &H33, &H04, &HEA, &H9A, &H11, &H04, &HEA,
				&H91, &H11, &H04, &HEA, &H78, &H47, &HC0, &H46, &H90, &H14, &H00, &HEA,
				&H78, &H47, &HC0, &H46, &H95, &H11, &H04, &HEA, &H4B, &H14, &H00, &HEA,
				&HCE, &H14, &H00, &HEA, &HE6, &H14, &H00, &HEA, &H04, &H15, &H00, &HEA,
				&H95, &H33, &H04, &HEA, &H93, &H32, &H04, &HEA, &HD3, &H29, &H04, &HEA,
				&HC5, &H4F, &H04, &HEA, &H9D, &H30, &H04, &HEA, &H09, &H1E, &H04, &HEA,
				&H97, &H33, &H04, &HEA, &HEC, &H15, &H04, &HEA, &HA4, &H13, &H04, &HEA,
				&H2E, &H15, &H04, &HEA, &H2B, &H14, &H04, &HEA, &HB4, &H14, &H04, &HEA,
				&HCC, &H15, &H04, &HEA, &H99, &H17, &H04, &HEA, &HE3, &H17, &H04, &HEA,
				&HFC, &H10, &H00, &HEA, &HC5, &H13, &H04, &HEA, &HCF, &H2D, &H04, &HEA,
				&H3D, &H17, &H04, &HEA, &H43, &H0E, &H00, &HEA, &H0E, &H0E, &H00, &HEA,
				&H8C, &H14, &H04, &HEA, &H4D, &H3E, &H04, &HEA, &H15, &H17, &H04, &HEA,
				&HF4, &H15, &H04, &HEA, &H97, &H2C, &H04, &HEA, &HE3, &H38, &H04, &HEA,
				&H84, &H13, &H04, &HEA, &H66, &H13, &H04, &HEA, &HA6, &H13, &H04, &HEA,
				&H23, &H2D, &H04, &HEA, &HBB, &H14, &H04, &HEA, &H02, &H12, &H04, &HEA,
				&H9F, &H0D, &H00, &HEA, &H98, &H11, &H04, &HEA, &HF5, &H2B, &H04, &HEA,
				&HBA, &H2B, &H04, &HEA, &HF2, &H3F, &H04, &HEA, &H3E, &H15, &H04, &HEA,
				&H5E, &H2E, &H04, &HEA, &HED, &H2C, &H04, &HEA, &HA7, &H2C, &H04, &HEA,
				&HF7, &H31, &H04, &HEA, &H03, &H32, &H04, &HEA, &H7D, &H11, &H04, &HEA,
				&H85, &H2E, &H04, &HEA, &H55, &H30, &H04, &HEA, &HC5, &H3E, &H04, &HEA,
				&H0C, &H0E, &H00, &HEA, &HD4, &H2B, &H04, &HEA, &H65, &H17, &H04, &HEA,
				&HD1, &H38, &H04, &HEA, &H31, &H39, &H04, &HEA, &HEA, &H2C, &H04, &HEA,
				&HC9, &H2B, &H04, &HEA, &HCE, &H3B, &H04, &HEA, &HC6, &H0D, &H00, &HEA,
				&H7E, &H3B, &H04, &HEA, &HD3, &H11, &H04, &HEA, &H1E, &H18, &H04, &HEA,
				&H15, &H15, &H04, &HEA, &H13, &H18, &H04, &HEA, &HCB, &H12, &H04, &HEA,
				&H08, &H18, &H04, &HEA, &H3A, &H14, &H04, &HEA, &H99, &H38, &H04, &HEA,
				&HAF, &H3B, &H04, &HEA, &H63, &H39, &H04, &HEA, &H52, &H39, &H04, &HEA,
				&HB6, &H13, &H04, &HEA, &H40, &H0E, &H00, &HEA, &HBA, &H16, &H04, &HEA,
				&H0F, &H13, &H04, &HEA, &H45, &H14, &H04, &HEA, &H66, &H11, &H04, &HEA,
				&HF1, &H12, &H04, &HEA, &H8C, &H12, &H04, &HEA, &HDC, &H30, &H04, &HEA,
				&HD2, &H35, &H04, &HEA, &H54, &H31, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA3, &H6D, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC1, &H69, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H71, &H6B, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF5, &H3E, &HF0, &HBF,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HFB, &H6D, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &H6A, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H31, &H66, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H91, &H66, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H4D, &H6A, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H49, &H42, &HF0, &HBF,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC9, &H69, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H91, &H75, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H35, &H76, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HA1, &H74, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HED, &H69, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC1, &H70, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H1D, &H6A, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF9, &H70, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H31, &H6D, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H21, &H74, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF9, &H42, &HF0, &HBF, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB5, &H72, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H69, &H76, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H43, &H6D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H47, &H6D, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H25, &H70, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H4D, &H6D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H8D, &H72, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H6D, &H73, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H29, &H72, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC9, &H71, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H35, &H73, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HBD, &H72, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HFD, &H72, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HED, &H6A, &H00, &HC0, &H78, &H47, &HC0, &H46, &H3D, &H13, &H00, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF5, &H64, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &H70, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H21, &H6E, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H51, &H6E, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H51, &H75, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF5, &H6B, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H4D, &H6C, &H00, &HC0, &H78, &H47, &HC0, &H46, &H1F, &H13, &H00, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H51, &H72, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF1, &H71, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD9, &H73, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB5, &H42, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H35, &H3E, &HF0, &HBF, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA1, &H3D, &HF0, &HBF,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC9, &H6B, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC1, &H40, &HF0, &HBF, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC5, &H76, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H51, &H76, &H00, &HC0, &H78, &H47, &HC0, &H46, &HCC, &H3A, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H3C, &H3D, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H3D, &H76, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H8A, &H3A, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H19, &H71, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H55, &H41, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HED, &H6E, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H91, &H6F, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H59, &H65, &H00, &HC0, &H78, &H47, &HC0, &H46, &HCB, &H1C, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H61, &H38, &H04, &HEA, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H8F, &H7D, &H00, &HC0, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H11, &H7F, &H00, &HC0, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H53, &H7F, &H00, &HC0, &H28, &H0F, &H00, &HEA,
				&HC0, &H46, &H04, &HEA, &H1F, &H17, &H04, &HEA, &H4F, &H2A, &H04, &HEA,
				&H80, &H2A, &H04, &HEA, &H70, &H2A, &H04, &HEA, &H41, &H2A, &H04, &HEA,
				&HC5, &H45, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H3B, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HBB, &H7C, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H74, &H3E, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H32, &H41, &H04, &HEA, &H78, &H47, &HC0, &H46, &HB2, &H3D, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H9F, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46, &H3C, &H41, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H7C, &H42, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H94, &H41, &H04, &HEA, &H78, &H47, &HC0, &H46, &HC9, &H41, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &HCE, &H41, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&HE7, &H41, &H04, &HEA, &H78, &H47, &HC0, &H46, &HFF, &H41, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H8D, &H3A, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H4D, &H30, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HBD, &H7E, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H39, &H87, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H8B, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB5, &H88, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H2D, &H80, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H8F, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H73, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H35, &H81, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD5, &H82, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H2D, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H9D, &H7C, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HFD, &H7C, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD3, &H7C, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE5, &H7C, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC3, &H7C, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H43, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H69, &H88, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB3, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H41, &H88, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HCB, &H7C, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H53, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H31, &H7D, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB9, &H7D, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H8D, &H88, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H3B, &H87, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HCD, &H7E, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE9, &H7E, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H97, &H7E, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE9, &H88, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H3D, &H89, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H11, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H9B, &H7F, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HAB, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HAF, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H89, &H7C, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &HEC, &H3C, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H03, &H87, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF1, &H86, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD1, &H7E, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H1D, &H89, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H55, &H30, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H34, &H30, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H41, &H87, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H3F, &H87, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H45, &H87, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF9, &H7F, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H68, &H37, &H04, &HEA, &H0A, &H22, &H04, &HEA, &H16, &H20, &H04, &HEA,
				&H82, &H21, &H04, &HEA, &H92, &H45, &H04, &HEA, &H13, &H22, &H04, &HEA,
				&H94, &H45, &H04, &HEA, &HE5, &H11, &H00, &HEA, &H15, &H2E, &H04, &HEA,
				&HCD, &H20, &H04, &HEA, &HC8, &H20, &H04, &HEA, &HC3, &H20, &H04, &HEA,
				&HB7, &H20, &H04, &HEA, &H41, &H2E, &H04, &HEA, &HAD, &H20, &H04, &HEA,
				&H00, &H22, &H04, &HEA, &H6E, &H21, &H04, &HEA, &H7F, &H2E, &H04, &HEA,
				&H77, &H2E, &H04, &HEA, &H11, &H3E, &H04, &HEA, &H00, &H20, &H04, &HEA,
				&H33, &H22, &H04, &HEA, &HA9, &H20, &H04, &HEA, &H64, &H21, &H04, &HEA,
				&HCE, &H25, &H04, &HEA, &H24, &H25, &H04, &HEA, &H74, &H24, &H04, &HEA,
				&HBF, &H20, &H04, &HEA, &H8A, &H0E, &H00, &HEA, &HAD, &H22, &H04, &HEA,
				&HE0, &H22, &H04, &HEA, &H41, &H31, &H04, &HEA, &H79, &H1B, &H04, &HEA,
				&H47, &H0F, &H04, &HEA, &H47, &H31, &H04, &HEA, &HBE, &H26, &H04, &HEA,
				&HFC, &H22, &H04, &HEA, &HF6, &H22, &H04, &HEA, &HD3, &H22, &H04, &HEA,
				&H63, &H0E, &H00, &HEA, &HE6, &H22, &H04, &HEA, &HD4, &H37, &H04, &HEA,
				&H6F, &H2F, &H04, &HEA, &H87, &H28, &H04, &HEA, &HD4, &H26, &H04, &HEA,
				&H2E, &H27, &H04, &HEA, &HDA, &H26, &H04, &HEA, &HCC, &H27, &H04, &HEA,
				&H02, &H0F, &H00, &HEA, &H1E, &H0F, &H00, &HEA, &HC1, &H0E, &H00, &HEA,
				&H92, &H0E, &H00, &HEA, &H57, &H28, &H04, &HEA, &HB9, &H27, &H04, &HEA,
				&HC8, &H26, &H04, &HEA, &H43, &H27, &H04, &HEA, &H5B, &H28, &H04, &HEA,
				&HE0, &H27, &H04, &HEA, &H28, &H28, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H07, &H28, &H04, &HEA, &H78, &H47, &HC0, &H46, &H1D, &H27, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H08, &H27, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H10, &H28, &H04, &HEA, &H78, &H47, &HC0, &H46, &H8A, &H27, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &HCD, &H27, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H26, &H28, &H04, &HEA, &H78, &H47, &HC0, &H46, &HE4, &H27, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &HDE, &H27, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H5F, &H27, &H04, &HEA, &H78, &H47, &HC0, &H46, &HFD, &H26, &H04, &HEA,
				&H9F, &H23, &H04, &HEA, &HC1, &H23, &H04, &HEA, &HF8, &H23, &H04, &HEA,
				&H24, &H24, &H04, &HEA, &HB6, &H29, &H04, &HEA, &H35, &H26, &H04, &HEA,
				&HDD, &H2B, &H04, &HEA, &HA8, &H2B, &H04, &HEA, &H8D, &H2B, &H04, &HEA,
				&H1D, &H2B, &H04, &HEA, &HEE, &H2A, &H04, &HEA, &H49, &H2B, &H04, &HEA,
				&H03, &H2B, &H04, &HEA, &H30, &H2B, &H04, &HEA, &H10, &H2C, &H04, &HEA,
				&H8B, &H2C, &H04, &HEA, &H94, &H2C, &H04, &HEA, &H3B, &H2C, &H04, &HEA,
				&HB0, &H2C, &H04, &HEA, &HA4, &H2D, &H04, &HEA, &H82, &H2C, &H04, &HEA,
				&H3D, &H0E, &H00, &HEA, &HD7, &H2C, &H04, &HEA, &H7D, &H2C, &H04, &HEA,
				&H80, &H2C, &H04, &HEA, &H82, &H11, &H00, &HEA, &H3E, &H0E, &H00, &HEA,
				&HE2, &H2F, &H04, &HEA, &H1F, &H30, &H04, &HEA, &H5B, &H2F, &H04, &HEA,
				&H13, &H2F, &H04, &HEA, &HEA, &H36, &H04, &HEA, &H29, &H36, &H04, &HEA,
				&H21, &H36, &H04, &HEA, &H75, &H30, &H04, &HEA, &H54, &H30, &H04, &HEA,
				&H70, &H39, &H04, &HEA, &H55, &H0F, &H00, &HEA, &H54, &H36, &H04, &HEA,
				&HDF, &H30, &H04, &HEA, &HF1, &H2E, &H04, &HEA, &H20, &H2E, &H04, &HEA,
				&HCB, &H15, &H04, &HEA, &HA4, &H0D, &H00, &HEA, &H09, &H0C, &H00, &HEA,
				&H40, &H2F, &H04, &HEA, &H26, &H2F, &H04, &HEA, &H5A, &H36, &H04, &HEA,
				&H1C, &H37, &H04, &HEA, &H5C, &H22, &H04, &HEA, &HE0, &H2D, &H04, &HEA,
				&H8C, &H2D, &H04, &HEA, &HE6, &H0E, &H00, &HEA, &H71, &H1B, &H04, &HEA,
				&H1D, &H31, &H04, &HEA, &H93, &H31, &H04, &HEA, &H87, &H31, &H04, &HEA,
				&H31, &H32, &H04, &HEA, &HAC, &H31, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H4A, &H32, &H04, &HEA, &H78, &H47, &HC0, &H46, &H9D, &H31, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H1E, &H0E, &H00, &HEA, &H78, &H47, &HC0, &H46,
				&H7A, &H37, &H04, &HEA, &H78, &H47, &HC0, &H46, &H26, &H31, &H04, &HEA,
				&H32, &H39, &H04, &HEA, &H8F, &H32, &H04, &HEA, &H6F, &H32, &H04, &HEA,
				&H47, &H33, &H04, &HEA, &HA6, &H32, &H04, &HEA, &H19, &H33, &H04, &HEA,
				&H5B, &H2C, &H04, &HEA, &H35, &H34, &H04, &HEA, &HD9, &H04, &H04, &HEA,
				&HDE, &H04, &H04, &HEA, &HC7, &H35, &H04, &HEA, &H9D, &H34, &H04, &HEA,
				&H68, &H35, &H04, &HEA, &H6C, &H34, &H04, &HEA, &H89, &H35, &H04, &HEA,
				&HFF, &H33, &H04, &HEA, &H94, &H33, &H04, &HEA, &H4F, &H33, &H04, &HEA,
				&H10, &H34, &H04, &HEA, &HCB, &H33, &H04, &HEA, &H67, &H33, &H04, &HEA,
				&H02, &H34, &H04, &HEA, &HBA, &H33, &H04, &HEA, &H62, &H33, &H04, &HEA,
				&HCA, &H35, &H04, &HEA, &H07, &H35, &H04, &HEA, &H2D, &H34, &H04, &HEA,
				&HCA, &H34, &H04, &HEA, &HF8, &H33, &H04, &HEA, &H97, &H33, &H04, &HEA,
				&H49, &H33, &H04, &HEA, &H80, &H33, &H04, &HEA, &H7B, &H36, &H04, &HEA,
				&HD3, &H2C, &H04, &HEA, &H99, &H1A, &H04, &HEA, &HA9, &H1A, &H04, &HEA,
				&H45, &H2C, &H04, &HEA, &H63, &H2C, &H04, &HEA, &H3D, &H36, &H04, &HEA,
				&HA0, &H2E, &H04, &HEA, &H9A, &H2C, &H04, &HEA, &HD7, &H2B, &H04, &HEA,
				&HFF, &H2C, &H04, &HEA, &H26, &H2D, &H04, &HEA, &H03, &H36, &H04, &HEA,
				&H15, &H2D, &H04, &HEA, &H94, &H2E, &H04, &HEA, &HFC, &H2C, &H04, &HEA,
				&HFB, &H35, &H04, &HEA, &HC5, &H35, &H04, &HEA, &H2F, &H3D, &H04, &HEA,
				&H60, &H38, &H04, &HEA, &H81, &H38, &H04, &HEA, &HB8, &H37, &H04, &HEA,
				&H38, &H39, &H04, &HEA, &HB0, &H3B, &H04, &HEA, &H0A, &H3B, &H04, &HEA,
				&H7B, &H39, &H04, &HEA, &HD7, &H44, &H04, &HEA, &H86, &H0F, &H00, &HEA,
				&H6C, &H4C, &H04, &HEA, &H40, &H37, &H04, &HEA, &H67, &H37, &H04, &HEA,
				&H11, &H38, &H04, &HEA, &H23, &H38, &H04, &HEA, &H0B, &H39, &H04, &HEA,
				&HDF, &H44, &H04, &HEA, &HF8, &H44, &H04, &HEA, &H8A, &H4C, &H04, &HEA,
				&H5E, &H4C, &H04, &HEA, &H79, &H37, &H04, &HEA, &H84, &H4C, &H04, &HEA,
				&H76, &H38, &H04, &HEA, &H83, &H3A, &H04, &HEA, &H35, &H3A, &H04, &HEA,
				&H37, &H3B, &H04, &HEA, &H92, &H39, &H04, &HEA, &H39, &H3D, &H04, &HEA,
				&H2F, &H39, &H04, &HEA, &H44, &H3D, &H04, &HEA, &HB1, &H39, &H04, &HEA,
				&H4B, &H3A, &H04, &HEA, &H6F, &H39, &H04, &HEA, &H24, &H39, &H04, &HEA,
				&H5B, &H3B, &H04, &HEA, &HB3, &H38, &H04, &HEA, &H39, &H39, &H04, &HEA,
				&HFD, &H38, &H04, &HEA, &H45, &H38, &H04, &HEA, &H26, &H38, &H04, &HEA,
				&HE2, &H3B, &H04, &HEA, &HD6, &H3C, &H04, &HEA, &H3E, &H4C, &H04, &HEA,
				&H17, &H3C, &H04, &HEA, &HDD, &H3E, &H04, &HEA, &H25, &H42, &H04, &HEA,
				&HC7, &H3D, &H04, &HEA, &H8C, &H1E, &H04, &HEA, &H9B, &H25, &H04, &HEA,
				&HBE, &H3E, &H04, &HEA, &H49, &H3F, &H04, &HEA, &HF2, &H3D, &H04, &HEA,
				&HB0, &H3E, &H04, &HEA, &HF3, &H3E, &H04, &HEA, &H9C, &H3E, &H04, &HEA,
				&H22, &H3F, &H04, &HEA, &H71, &H3E, &H04, &HEA, &H03, &H41, &H04, &HEA,
				&H7A, &H41, &H04, &HEA, &HF1, &H41, &H04, &HEA, &HBE, &H41, &H04, &HEA,
				&H3D, &H3D, &H04, &HEA, &H4E, &H3D, &H04, &HEA, &HAE, &H25, &H04, &HEA,
				&H28, &H3E, &H04, &HEA, &H93, &H41, &H04, &HEA, &H39, &H41, &H04, &HEA,
				&H86, &H3D, &H04, &HEA, &HBF, &H1E, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H15, &H1D, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H4B, &H1E, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H1D, &H1C, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H45, &H1C, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE1, &H18, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H7D, &H1E, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD5, &H1E, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H01, &H1C, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H79, &H1C, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE1, &H1C, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HA5, &H1B, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H35, &H19, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H34, &H32, &H04, &HEA, &H78, &H47, &HC0, &H46, &H41, &H0E, &H00, &HEA,
				&H78, &H47, &HC0, &H46, &H5E, &H0E, &H00, &HEA, &H78, &H47, &HC0, &H46,
				&H60, &H32, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HED, &H18, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD1, &H1B, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &HA5, &H2E, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&HB0, &H2E, &H04, &HEA, &H78, &H47, &HC0, &H46, &HD2, &H3C, &H04, &HEA,
				&H8F, &H43, &H04, &HEA, &H78, &H47, &HC0, &H46, &H62, &H0E, &H00, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE5, &H18, &H01, &HC0, &H78, &H47, &HC0, &H46, &H42, &H11, &H00, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H51, &H19, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H89, &H1A, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H1D, &H1E, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H55, &H1F, &H01, &HC0, &H78, &H47, &HC0, &H46, &H91, &H15, &H07, &HEA,
				&H78, &H47, &HC0, &H46, &H70, &H15, &H07, &HEA, &H78, &H47, &HC0, &H46,
				&H15, &H15, &H07, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H69, &H1F, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H38, &H15, &H07, &HEA, &H78, &H47, &HC0, &H46, &HA4, &H15, &H07, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H49, &H43, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H0D, &H78, &H00, &HC0, &HB7, &H2E, &H04, &HEA,
				&H29, &H0D, &H00, &HEA, &HA5, &H2E, &H04, &HEA, &H2D, &H44, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H0D, &H3E, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H61, &H3F, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA9, &H3A, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE5, &H51, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF1, &H34, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H7B, &H37, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H55, &H38, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &H37, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF1, &H4C, &HF0, &HBF,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF1, &H2C, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H09, &H28, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HFF, &H37, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H05, &H4E, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HCD, &H37, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB9, &H29, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC1, &H38, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H0F, &H39, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HDD, &H38, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H31, &H34, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HFD, &H2F, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA1, &H2F, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H9D, &H26, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H2B, &H39, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H9F, &H10, &H00, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H0D, &H52, &HF0, &HBF, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H2D, &H2C, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H11, &H3A, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H05, &H2B, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&HC7, &H19, &H04, &HEA, &H78, &H47, &HC0, &H46, &HD3, &H19, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &HB4, &H19, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H25, &H3A, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H1F, &H3A, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H5D, &H39, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H2B, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H85, &H38, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H97, &H37, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC1, &H2C, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H49, &H3A, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE5, &H33, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&HFD, &H76, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H6B, &H3E, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H4D, &H3E, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H80, &H77, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H0D, &H77, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H31, &H38, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H94, &H78, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HED, &H32, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H51, &H2D, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HA5, &H4F, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC1, &H50, &HF0, &HBF, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB5, &H28, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE1, &H24, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF5, &H3C, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H2F, &H79, &H04, &HEA, &H78, &H47, &HC0, &H46, &HCE, &H78, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC5, &H3E, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H83, &H3E, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD9, &H3D, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H69, &H3A, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H35, &H3C, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H11, &H23, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H8D, &H52, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE9, &H3E, &H01, &HC0, &H02, &H09, &H00, &HEA,
				&H2E, &H43, &H04, &HEA, &H1D, &H4B, &H04, &HEA, &HBB, &H3A, &H04, &HEA,
				&HEF, &H26, &H04, &HEA, &HEF, &H26, &H04, &HEA, &HB5, &H4A, &H04, &HEA,
				&HB5, &H4A, &H04, &HEA, &H97, &H1D, &H04, &HEA, &H97, &H1D, &H04, &HEA,
				&H00, &H2F, &H04, &HEA, &H00, &H2F, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H3D, &H21, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H57, &H20, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H0B, &H21, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H49, &H20, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF1, &H1F, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H07, &H21, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE7, &H20, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD9, &H20, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H6D, &H20, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H35, &H26, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H89, &H25, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB1, &H84, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H41, &H85, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB1, &H80, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H11, &H81, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H35, &H86, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H5D, &H83, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &H80, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE5, &H85, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H61, &H84, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE9, &H85, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H45, &H80, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H55, &H80, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H4D, &H80, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H80, &H00, &HC0,
				&H1D, &H2E, &H04, &HEA, &H28, &H2E, &H04, &HEA, &HE2, &H2D, &H04, &HEA,
				&HDB, &H0F, &H04, &HEA, &H09, &H11, &H04, &HEA, &HD7, &H0F, &H04, &HEA,
				&HC6, &H2E, &H04, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H71, &HD4, &H00, &HC0, &HB5, &H2E, &H04, &HEA,
				&H46, &H20, &H04, &HEA, &HA3, &H20, &H04, &HEA, &H42, &H20, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB1, &H86, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HAD, &H87, &H00, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HCD, &H7F, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H81, &HAE, &H00, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD9, &HAE, &H00, &HC0, &HAB, &H25, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H69, &H1B, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H99, &H1D, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H3F, &H19, &H01, &HC0,
				&H8D, &H32, &H04, &HEA, &HB7, &H32, &H04, &HEA, &H61, &H32, &H04, &HEA,
				&H94, &H18, &H04, &HEA, &H95, &H18, &H04, &HEA, &H90, &H18, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE9, &H4E, &HF0, &HBF, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H4D, &H34, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HAD, &H2C, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H65, &H21, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB5, &H21, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H51, &H21, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H85, &H19, &H01, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HDF, &H1A, &H01, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H29, &H1B, &H01, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H21, &H1A, &H01, &HC0, &HAD, &H23, &H05, &HEA, &H47, &H1A, &H05, &HEA,
				&H89, &H63, &H04, &HEA, &HB2, &H6A, &H04, &HEA, &HE3, &H68, &H04, &HEA,
				&H4B, &H1A, &H05, &HEA, &H3C, &H0F, &H00, &HEA, &H55, &H63, &H04, &HEA,
				&H76, &H78, &H04, &HEA, &HCB, &H73, &H04, &HEA, &H69, &H71, &H04, &HEA,
				&H36, &H63, &H04, &HEA, &H49, &H61, &H04, &HEA, &H36, &H62, &H04, &HEA,
				&H81, &H63, &H04, &HEA, &H62, &H78, &H05, &HEA, &H17, &HFF, &H04, &HEA,
				&H2C, &H75, &H05, &HEA, &HF9, &H62, &H04, &HEA, &HE0, &HFC, &H04, &HEA,
				&HC0, &H93, &H04, &HEA, &HDF, &H0E, &H00, &HEA, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H1D, &H8E, &H05, &HC0, &HB5, &H1C, &H04, &HEA,
				&H08, &H26, &H04, &HEA, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD1, &HD5, &H04, &HC0, &HCC, &H49, &H04, &HEA, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H15, &H6F, &H03, &HC0, &H17, &H2E, &H04, &HEA,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H8D, &HD2, &H05, &HC0,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB1, &H04, &H05, &HC0,
				&HEF, &H07, &H00, &HEA, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF1, &H9D, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H39, &HD0, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H02, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H9D, &H9B, &H03, &HC0, &HE9, &H73, &H05, &HEA, &HE2, &HE7, &H04, &HEA,
				&H4F, &H77, &H04, &HEA, &H86, &H24, &H05, &HEA, &H00, &H8B, &H04, &HEA,
				&H44, &H92, &H04, &HEA, &H8D, &H6A, &H04, &HEA, &H73, &H62, &H04, &HEA,
				&H49, &H62, &H04, &HEA, &H7A, &H71, &H04, &HEA, &HB1, &HB8, &H04, &HEA,
				&HC0, &H93, &H04, &HEA, &H27, &HB9, &H04, &HEA, &HDA, &HE9, &H04, &HEA,
				&HE2, &H98, &H04, &HEA, &H54, &H22, &H05, &HEA, &H4A, &H41, &H05, &HEA,
				&HB3, &HE4, &H04, &HEA, &HDE, &HB8, &H04, &HEA, &HC2, &H78, &H04, &HEA,
				&H2C, &H98, &H04, &HEA, &H80, &HE9, &H04, &HEA, &HBB, &H92, &H04, &HEA,
				&H58, &HA5, &H04, &HEA, &HE9, &HB6, &H04, &HEA, &H1B, &H2C, &H05, &HEA,
				&H6D, &HD2, &H04, &HEA, &H05, &HA3, &H04, &HEA, &HDE, &HA2, &H04, &HEA,
				&HD2, &H78, &H04, &HEA, &HF0, &H78, &H04, &HEA, &H8A, &H25, &H05, &HEA,
				&H5F, &HB7, &H04, &HEA, &H59, &HEA, &H04, &HEA, &H5C, &HB6, &H04, &HEA,
				&H8D, &HE9, &H04, &HEA, &H33, &H75, &H05, &HEA, &HD1, &H86, &H04, &HEA,
				&H38, &H8C, &H04, &HEA, &H13, &H87, &H04, &HEA, &H24, &H8C, &H04, &HEA,
				&H7C, &H8B, &H04, &HEA, &HBA, &H91, &H04, &HEA, &H30, &H91, &H04, &HEA,
				&H36, &H91, &H04, &HEA, &H23, &H62, &H04, &HEA, &H5F, &H77, &H04, &HEA,
				&HDD, &H6E, &H04, &HEA, &H41, &H77, &H04, &HEA, &H14, &H85, &H04, &HEA,
				&HE2, &H74, &H04, &HEA, &H42, &H71, &H04, &HEA, &H5B, &H91, &H04, &HEA,
				&H2F, &H91, &H04, &HEA, &HD3, &H91, &H04, &HEA, &H9F, &H8E, &H04, &HEA,
				&H0D, &H8E, &H04, &HEA, &HD2, &H8C, &H04, &HEA, &H73, &H8C, &H04, &HEA,
				&H3B, &H8D, &H04, &HEA, &H24, &H8D, &H04, &HEA, &H60, &H8E, &H04, &HEA,
				&HB5, &HF1, &H04, &HEA, &H71, &HF9, &H04, &HEA, &H36, &H98, &H04, &HEA,
				&HF1, &H8B, &H04, &HEA, &H4F, &H8D, &H04, &HEA, &HA9, &H88, &H04, &HEA,
				&H51, &H91, &H04, &HEA, &H16, &H27, &H05, &HEA, &HFE, &H8B, &H04, &HEA,
				&H53, &HA3, &H04, &HEA, &HD5, &HC5, &H04, &HEA, &HD6, &HC5, &H04, &HEA,
				&HE3, &HE8, &H04, &HEA, &H23, &HE9, &H04, &HEA, &H90, &H68, &H04, &HEA,
				&HDE, &H74, &H04, &HEA, &H4D, &H78, &H04, &HEA, &H24, &H75, &H04, &HEA,
				&H80, &H68, &H04, &HEA, &H63, &H68, &H04, &HEA, &H19, &H60, &H04, &HEA,
				&HB1, &H6E, &H05, &HEA, &HCC, &HA3, &H04, &HEA, &H5B, &H72, &H05, &HEA,
				&H7D, &HAF, &H04, &HEA, &H65, &HE6, &H04, &HEA, &H24, &H42, &H05, &HEA,
				&H5D, &HC0, &H04, &HEA, &HAD, &H55, &H05, &HEA, &H48, &H4C, &H05, &HEA,
				&H20, &HA8, &H04, &HEA, &H59, &HD2, &H04, &HEA, &H05, &H2C, &H05, &HEA,
				&HD7, &H9B, &H04, &HEA, &HF4, &HBB, &H04, &HEA, &HCE, &HC2, &H04, &HEA,
				&H3A, &H82, &H04, &HEA, &HF3, &HC7, &H04, &HEA, &HDF, &HB0, &H04, &HEA,
				&H3C, &HA3, &H04, &HEA, &HA7, &HBF, &H04, &HEA, &HED, &H98, &H04, &HEA,
				&HE4, &HB6, &H04, &HEA, &H70, &H23, &H05, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H95, &H47, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC1, &H47, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H79, &H48, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H45, &H4A, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H6F, &H7F, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HED, &H4A, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H81, &H4C, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H49, &H47, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD9, &H4C, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H25, &H4B, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H47, &H7F, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H41, &H4F, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H6D, &H4F, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H25, &H50, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF1, &H51, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H2B, &HE6, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H99, &H52, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H2D, &H54, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF5, &H4E, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H85, &H54, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD1, &H52, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H03, &HE6, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H1D, &H6D, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H31, &H6B, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H71, &H6E, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H15, &H6A, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &H9A, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H89, &H6D, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HCD, &H6E, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H51, &H6F, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H59, &H9B, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H01, &H82, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE5, &H9A, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H99, &H6F, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H31, &H70, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HFD, &H76, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H25, &H71, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H31, &H7F, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H11, &H73, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA9, &H7B, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H99, &H7C, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H35, &H97, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H9D, &H82, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD5, &H67, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H21, &H81, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H39, &H81, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE1, &H7F, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H91, &H7F, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB1, &H80, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H0D, &H4D, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD1, &H4B, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H80, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H49, &H81, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H1D, &H6F, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H45, &H8A, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H21, &H89, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB9, &H96, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF9, &H8F, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H39, &H95, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H6D, &H95, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE1, &H7C, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB1, &H71, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H6D, &H7E, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF1, &H7B, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HAF, &H7C, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC5, &H87, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB1, &H95, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H29, &H9A, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H8D, &H95, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HDD, &H7D, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H59, &H72, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC5, &H95, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H30, &H0D, &H00, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HDD, &H7A, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE5, &H96, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H61, &H96, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H25, &H9A, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H31, &H91, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC9, &H7F, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H25, &H9B, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H19, &H96, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HA9, &H81, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H8D, &H8F, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD9, &H97, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H83, &H95, &H03, &HC0, &H78, &H47, &HC0, &H46, &HB9, &H96, &H04, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H9D, &H8B, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H31, &H9E, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H7D, &H98, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H9D, &H97, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H4D, &H89, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB1, &H91, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HCD, &H88, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HAD, &H93, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H0D, &H8A, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HDD, &H89, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HA9, &H86, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H94, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB1, &H94, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H61, &H93, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H21, &H86, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE9, &H93, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H39, &H92, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H96, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H4D, &H91, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE9, &H82, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H51, &H85, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE7, &H88, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H09, &H8C, &H03, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA1, &H8B, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H15, &H8E, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H15, &H94, &H03, &HC0, &HC9, &HE3, &H04, &HEA,
				&H13, &H96, &H04, &HEA, &H0C, &HFD, &H04, &HEA, &H4C, &H26, &H05, &HEA,
				&H1D, &H23, &H05, &HEA, &H54, &HE8, &H04, &HEA, &H54, &HEB, &H04, &HEA,
				&H84, &HEC, &H04, &HEA, &H29, &HF1, &H04, &HEA, &HAA, &HED, &H04, &HEA,
				&HF4, &HEE, &H04, &HEA, &H84, &HF0, &H04, &HEA, &H46, &HEF, &H04, &HEA,
				&H61, &HF0, &H04, &HEA, &H7D, &HEF, &H04, &HEA, &HA3, &HF0, &H04, &HEA,
				&H37, &HF0, &H04, &HEA, &HC4, &HF9, &H04, &HEA, &H9F, &HF3, &H04, &HEA,
				&HD6, &HF1, &H04, &HEA, &HFA, &HF1, &H04, &HEA, &H0A, &HEE, &H04, &HEA,
				&HD5, &HF2, &H04, &HEA, &H0C, &HF6, &H04, &HEA, &H46, &HF5, &H04, &HEA,
				&HB5, &HF2, &H04, &HEA, &H6C, &HF1, &H04, &HEA, &H20, &HF2, &H04, &HEA,
				&HD4, &HEE, &H04, &HEA, &HF3, &HF6, &H04, &HEA, &HEB, &HEE, &H04, &HEA,
				&H6A, &HF7, &H04, &HEA, &HC2, &HF4, &H04, &HEA, &H2D, &HFA, &H04, &HEA,
				&H25, &HFA, &H04, &HEA, &HF4, &HEE, &H04, &HEA, &H67, &H76, &H04, &HEA,
				&H97, &H0C, &H00, &HEA, &H00, &H21, &H05, &HEA, &H0F, &H42, &H05, &HEA,
				&HF0, &H24, &H05, &HEA, &H44, &H91, &H04, &HEA, &H6B, &H21, &H05, &HEA,
				&HCF, &HE5, &H04, &HEA, &HCE, &HC3, &H04, &HEA, &H66, &H46, &H05, &HEA,
				&HC3, &H46, &H05, &HEA, &H8A, &H46, &H05, &HEA, &H20, &H21, &H05, &HEA,
				&HAD, &H76, &H04, &HEA, &HE2, &H1A, &H05, &HEA, &H6D, &H9A, &H04, &HEA,
				&H85, &HFD, &H04, &HEA, &HFA, &H6C, &H05, &HEA, &H5A, &H4B, &H05, &HEA,
				&H10, &H3C, &H05, &HEA, &H7A, &HDF, &H04, &HEA, &HEB, &H9D, &H04, &HEA,
				&HCB, &HAA, &H04, &HEA, &HCD, &HBA, &H04, &HEA, &H10, &HC2, &H04, &HEA,
				&H09, &HC7, &H04, &HEA, &HE4, &H80, &H04, &HEA, &HEA, &HAF, &H04, &HEA,
				&H60, &H9B, &H04, &HEA, &HF9, &HC0, &H04, &HEA, &H94, &HA7, &H04, &HEA,
				&H2F, &HE8, &H04, &HEA, &H1E, &H39, &H05, &HEA, &H79, &H12, &H05, &HEA,
				&H3F, &H6D, &H04, &HEA, &HC3, &H64, &H04, &HEA, &HC2, &H6C, &H04, &HEA,
				&H33, &H6F, &H04, &HEA, &H78, &H62, &H04, &HEA, &HFD, &H60, &H04, &HEA,
				&HC2, &H1F, &H05, &HEA, &H1B, &HA7, &H04, &HEA, &H27, &H21, &H05, &HEA,
				&HA3, &H6C, &H04, &HEA, &H9C, &HAE, &H04, &HEA, &H02, &H93, &H04, &HEA,
				&H92, &H92, &H04, &HEA, &H76, &H91, &H04, &HEA, &HF9, &H91, &H04, &HEA,
				&H17, &H93, &H04, &HEA, &HC4, &H91, &H04, &HEA, &HCB, &H27, &H05, &HEA,
				&H8C, &HB5, &H04, &HEA, &HC9, &HE5, &H04, &HEA, &H87, &H48, &H05, &HEA,
				&H8D, &HA4, &H04, &HEA, &H7B, &HCE, &H04, &HEA, &H27, &H28, &H05, &HEA,
				&H4D, &H98, &H04, &HEA, &H49, &HB8, &H04, &HEA, &HAC, &H7E, &H04, &HEA,
				&HBB, &H51, &H05, &HEA, &HDD, &H46, &H05, &HEA, &H01, &HA3, &H04, &HEA,
				&HCA, &HCC, &H04, &HEA, &H16, &H26, &H05, &HEA, &HDD, &H96, &H04, &HEA,
				&HAB, &HB6, &H04, &HEA, &H0B, &HBF, &H04, &HEA, &H3B, &HC4, &H04, &HEA,
				&H36, &H7D, &H04, &HEA, &HEC, &H4F, &H05, &HEA, &H52, &H70, &H05, &HEA,
				&HF3, &H4E, &H05, &HEA, &HB0, &HAD, &H04, &HEA, &H4C, &HE4, &H04, &HEA,
				&H0B, &H40, &H05, &HEA, &HA1, &H9F, &H04, &HEA, &H43, &HBE, &H04, &HEA,
				&H09, &HC3, &H04, &HEA, &HED, &HC5, &H04, &HEA, &H41, &H81, &H04, &HEA,
				&HFA, &HB2, &H04, &HEA, &HEC, &H9C, &H04, &HEA, &H81, &H76, &H04, &HEA,
				&H88, &H90, &H04, &HEA, &HBD, &H90, &H04, &HEA, &H9D, &H41, &H05, &HEA,
				&HAC, &H41, &H05, &HEA, &H52, &H82, &H04, &HEA, &H8F, &H17, &H05, &HEA,
				&H9F, &H1A, &H05, &HEA, &H69, &H02, &H05, &HEA, &H3D, &H21, &H05, &HEA,
				&H31, &HA1, &H04, &HEA, &HC0, &H75, &H05, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD1, &HD3, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE5, &HD1, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H2D, &HD5, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC9, &HD0, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H25, &H01, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H3D, &HD4, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H89, &HD5, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H0D, &HD6, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H19, &H02, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HBD, &HE8, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HA5, &H01, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H55, &HD6, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HED, &HD6, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB9, &HDD, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE1, &HD7, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HED, &HE5, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HCD, &HD9, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &HE2, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H55, &HE3, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF5, &HFD, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H59, &HE9, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H89, &HCE, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HDD, &HE7, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF5, &HE7, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H9D, &HE6, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H4D, &HE6, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H6D, &HE7, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB9, &H54, &H03, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H7D, &H53, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H19, &HE7, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H05, &HE8, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD9, &HD5, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H01, &HF1, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HDD, &HEF, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H79, &HFD, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB5, &HF6, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF9, &HFB, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H2D, &HFC, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H9D, &HE3, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H6D, &HD8, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H29, &HE5, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HAD, &HE2, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H6B, &HE3, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H81, &HEE, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H71, &HFC, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE9, &H00, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H4D, &HFC, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H99, &HE4, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H15, &HD9, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H85, &HFC, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H99, &HE1, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA5, &HFD, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H21, &HFD, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE5, &H00, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HED, &HF7, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H85, &HE6, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE5, &H01, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD9, &HFC, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H65, &HE8, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H49, &HF6, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H99, &HFE, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H43, &HFC, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H59, &HF2, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF1, &H04, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H3D, &HFF, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H5D, &HFE, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H09, &HF0, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H71, &HF8, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H89, &HEF, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H6D, &HFA, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC9, &HF0, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H99, &HF0, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H65, &HED, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H1D, &HFB, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H71, &HFB, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H21, &HFA, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HDD, &HEC, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HA9, &HFA, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF9, &HF8, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H1D, &HFD, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H09, &HF8, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA5, &HE9, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H0D, &HEC, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HA3, &HEF, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC5, &HF2, &H04, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H5D, &HF2, &H04, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HD1, &HF4, &H04, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD5, &HFA, &H04, &HC0,
				&HA3, &H93, &H04, &HEA, &H59, &H3F, &H05, &HEA, &HF5, &HE3, &H04, &HEA,
				&H18, &HE4, &H04, &HEA, &H71, &H00, &H05, &HEA, &HDB, &H8E, &H04, &HEA,
				&H3A, &H24, &H05, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H45, &H7B, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H1F, &H7A, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H95, &H7B, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HAD, &H7B, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H7D, &H7B, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB9, &H78, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H31, &HA3, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H19, &HA3, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE9, &H7F, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC5, &H7B, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD9, &HCB, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H15, &HCC, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HDD, &HCC, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &HCD, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H11, &HCF, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H8D, &HCD, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H6F, &H81, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H19, &H79, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H59, &H7A, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H81, &H79, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H5D, &H87, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H71, &H85, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF1, &HA5, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB9, &H88, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HF1, &H89, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H39, &H84, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC5, &HC6, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC9, &H87, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H15, &H89, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H2B, &H74, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H0C, &H44, &H05, &HEA, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H59, &H8E, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB9, &HC7, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H89, &HA4, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H45, &HC7, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HA1, &H8E, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H59, &H93, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H6D, &H8F, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H5D, &H9C, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD9, &H91, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC9, &H98, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H0D, &H8F, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC9, &H99, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H79, &HC3, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H41, &HA5, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HDF, &HC2, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H33, &H7A, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HC9, &HC8, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD7, &HCB, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H0D, &HA0, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H7D, &HA2, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HAD, &H9E, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H75, &H9C, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H41, &HA3, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H7D, &H9D, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H05, &HA4, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H1D, &H75, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H59, &H80, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB5, &H9D, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H19, &H7D, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB9, &H75, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H25, &H8E, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H8D, &HA5, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H55, &HC1, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H89, &HC6, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H8D, &HAF, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HFF, &HC2, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H45, &HBA, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H11, &HC1, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H41, &HB1, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H75, &HC0, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H11, &H9A, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H0D, &H90, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H9D, &H9B, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H1D, &H99, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HDF, &H99, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H99, &HAD, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H31, &HC1, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H0D, &H9B, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB5, &H92, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H69, &HC1, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H9D, &H81, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HBD, &HAE, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HB9, &H69, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H99, &HBB, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HFD, &H97, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H29, &HC3, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H3D, &HC6, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H65, &HC2, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H7D, &HBB, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H35, &H9E, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H85, &HC7, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HBD, &HC1, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB9, &HAF, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H09, &HA4, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HD9, &HB9, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H1D, &HC4, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H27, &HC1, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF9, &HC7, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HED, &H69, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HAD, &HCB, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H99, &HB2, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD5, &HD2, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HC1, &HC4, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE1, &HC3, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HE1, &HCA, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H4D, &HB0, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H99, &HBC, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HA1, &HAE, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HE9, &HBE, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H09, &HB1, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HD9, &HB0, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H7D, &HAC, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H99, &HBF, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HED, &HBF, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H9D, &HBE, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF5, &HAB, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H25, &HBF, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H41, &HBD, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H01, &HC2, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HB1, &HA7, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H35, &HBC, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HE9, &HA8, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H25, &HAB, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H51, &HAF, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HF9, &HB5, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H91, &HB5, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H55, &HB8, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H51, &HBF, &H05, &HC0,
				&H70, &H7E, &H04, &HEA, &H37, &H64, &H04, &HEA, &HB4, &H3E, &H05, &HEA,
				&HFA, &H68, &H04, &HEA, &H87, &H66, &H04, &HEA, &H60, &H1C, &H05, &HEA,
				&H9E, &HB0, &H04, &HEA, &H95, &H64, &H04, &HEA, &HD3, &H84, &H04, &HEA,
				&H92, &H81, &H04, &HEA, &HC1, &H83, &H04, &HEA, &H45, &H80, &H04, &HEA,
				&HDE, &H83, &H04, &HEA, &HB5, &H85, &H04, &HEA, &H09, &H86, &H04, &HEA,
				&H40, &H82, &H04, &HEA, &HFA, &H80, &H04, &HEA, &HF4, &H83, &H04, &HEA,
				&HC1, &H81, &H04, &HEA, &H46, &H83, &H04, &HEA, &H07, &H85, &H04, &HEA,
				&HAE, &H84, &H04, &HEA, &H40, &H85, &H04, &HEA, &HD1, &H83, &H04, &HEA,
				&H01, &H85, &H04, &HEA, &H83, &H80, &H04, &HEA, &H9C, &H85, &H04, &HEA,
				&H69, &H84, &H04, &HEA, &H64, &H81, &H04, &HEA, &H10, &H82, &H04, &HEA,
				&H6D, &H85, &H04, &HEA, &H4C, &H80, &H04, &HEA, &H41, &H80, &H04, &HEA,
				&H27, &H85, &H04, &HEA, &H8A, &H81, &H04, &HEA, &H42, &H81, &H04, &HEA,
				&H13, &H84, &H04, &HEA, &H77, &H62, &H04, &HEA, &H67, &H62, &H04, &HEA,
				&H2D, &HEB, &H04, &HEA, &HAA, &HF5, &H04, &HEA, &H85, &HF5, &H04, &HEA,
				&H7F, &HED, &H04, &HEA, &HB1, &HEA, &H04, &HEA, &HB3, &HEC, &H04, &HEA,
				&H63, &HF6, &H04, &HEA, &H88, &HEA, &H04, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H8D, &HD2, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&H35, &HD0, &H05, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &HB1, &H04, &H05, &HC0, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &H59, &H02, &H05, &HC0,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HF1, &H9D, &H03, &HC0, &H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5,
				&H1C, &HFF, &H2F, &HE1, &H99, &H9B, &H03, &HC0, &H77, &H0D, &H07, &HEA,
				&H96, &H0D, &H07, &HEA, &H7D, &H0D, &H07, &HEA, &H63, &H0D, &H07, &HEA,
				&H75, &H0D, &H07, &HEA, &HB4, &H0F, &H07, &HEA, &H77, &H0E, &H07, &HEA,
				&HD6, &H0D, &H07, &HEA, &H13, &H0F, &H07, &HEA, &HC6, &H0E, &H07, &HEA,
				&H26, &H0E, &H07, &HEA, &H62, &H0F, &H07, &HEA, &H0F, &H10, &H07, &HEA,
				&H00, &H10, &H07, &HEA, &H7D, &H10, &H07, &HEA, &H53, &H10, &H07, &HEA,
				&H11, &H11, &H07, &HEA, &H66, &H10, &H07, &HEA, &H8A, &H10, &H07, &HEA,
				&HC6, &H10, &H07, &HEA, &H40, &H0D, &H07, &HEA, &HFD, &H10, &H07, &HEA,
				&H2C, &H10, &H07, &HEA, &HBC, &H0F, &H07, &HEA, &HD7, &H0F, &H07, &HEA,
				&H00, &H00, &H00, &H00, &HE0, &H7D, &H0C, &HC0, &HFC, &H7F, &H0C, &H00,
				&H03, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H03, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H44, &H01, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H03, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H03, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H1B, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H03, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H03, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H02, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H06, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H61, &HD3, &H08, &H32, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &HCE, &H0C, &H00, &H00, &HCE, &H0C, &H00, &H00,
				&H0A, &H00, &H00, &H00, &H1F, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H01, &H00, &H00, &H00, &H05, &H00, &H00, &H00,
				&HA4, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H7C, &H00, &H0E, &H00,
				&H05, &H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H5F, &H5F, &H44, &H41, &H54, &H45, &H5F, &H5F,
				&H20, &H5F, &H5F, &H54, &H49, &H4D, &H45, &H5F, &H5F, &H00, &H00, &H00,
				&H02, &H00, &H00, &H00, &H01, &H00, &H00, &H00, &H06, &H00, &H00, &H00,
				&H84, &H34, &HF0, &HBF, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H01, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H02, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H01, &H00, &H00, &H00, &H01, &H00,
				&H01, &H00, &H00, &H00, &H0B, &H00, &H66, &H00, &HC4, &H34, &HF0, &HBF,
				&H20, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H0B, &H00, &H67, &H00,
				&H00, &H00, &H00, &H00, &H02, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H0B, &H00, &H68, &H00, &HE4, &H34, &HF0, &HBF, &H02, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H0B, &H00, &H69, &H00, &H00, &H00, &H00, &H00,
				&H06, &H00, &H00, &H00, &HFF, &HFF, &HFF, &HFF, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H0B, &H00, &H6A, &H00, &HEA, &H34, &HF0, &HBF, &H02, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H0B, &H00, &H6B, &H00, &H00, &H00, &H00, &H00,
				&H02, &H00, &H00, &H00, &HFF, &HFF, &HFF, &HFF, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H0B, &H00, &H6C, &H00, &HE6, &H34, &HF0, &HBF, &H02, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H0B, &H00, &H6D, &H00, &H00, &H00, &H00, &H00,
				&H04, &H00, &H00, &H00, &HFF, &HFF, &HFF, &HFF, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H01, &H00, &H00, &H00,
				&H0B, &H00, &H6C, &H00, &HE8, &H34, &HF0, &HBF, &H02, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H0B, &H00, &H6D, &H00, &H00, &H00, &H00, &H00,
				&H04, &H00, &H00, &H00, &HFF, &HFF, &HFF, &HFF, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H5C, &H02, &HF0, &HBF, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H14, &H97, &H01, &HC0, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H70, &H40, &H2D, &HE9,
				&H04, &H50, &H90, &HE5, &H00, &H40, &HA0, &HE1, &H05, &H00, &HA0, &HE1,
				&HF1, &H1E, &HA0, &HE3, &HF4, &HF7, &HFF, &HEB, &H04, &H00, &HA0, &HE1,
				&H04, &H50, &H84, &HE5, &H59, &HF8, &HFF, &HEB, &H04, &H00, &HA0, &HE1,
				&H59, &HF8, &HFF, &HEB, &H70, &H40, &HBD, &HE8, &H00, &H00, &HA0, &HE3,
				&H1E, &HFF, &H2F, &HE1, &HA4, &HFC, &H03, &HEA, &H78, &H47, &HC0, &H46,
				&H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1, &HBB, &H28, &H00, &HC0,
				&H78, &H47, &HC0, &H46, &HDC, &HFB, &H03, &HEA, &H1D, &HFB, &H03, &HEA,
				&H78, &H47, &HC0, &H46, &H00, &HC0, &H9F, &HE5, &H1C, &HFF, &H2F, &HE1,
				&HC9, &H23, &H00, &HC0, &H78, &H47, &HC0, &H46, &HD6, &H04, &H00, &HEA,
				&H6C, &H00, &H9F, &HE5, &H10, &H40, &H2D, &HE9, &H28, &H00, &H90, &HE5,
				&H02, &H0C, &H10, &HE3, &H09, &H00, &HA0, &H13, &H02, &H00, &H00, &H1A,
				&H01, &H0B, &H10, &HE3, &H03, &H00, &H00, &H0A, &H0A, &H00, &HA0, &HE3,
				&H52, &HF2, &HFF, &HEB, &H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H01, &H0C, &H10, &HE3, &H03, &H00, &H00, &H0A, &H08, &H00, &HA0, &HE3,
				&H4D, &HF2, &HFF, &HEB, &H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H02, &H00, &H10, &HE3, &H03, &H00, &H00, &H0A, &H01, &H00, &HA0, &HE3,
				&H48, &HF2, &HFF, &HEB, &H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H01, &H00, &H10, &HE3, &H00, &H00, &HA0, &H13, &H44, &HF2, &HFF, &H1B,
				&H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H00, &H03, &H00, &HF8,
				&HFE, &H43, &H2D, &HE9, &H01, &H70, &HA0, &HE1, &H9C, &H12, &HD0, &HE5,
				&H02, &H80, &HA0, &HE1, &H9D, &H22, &HD0, &HE5, &H03, &H60, &HA0, &HE1,
				&H00, &H30, &HA0, &HE3, &H0E, &H00, &H8D, &HE8, &H00, &H50, &HA0, &HE1,
				&H04, &H00, &HD6, &HE5, &H00, &H20, &HD6, &HE5, &H03, &H10, &HD6, &HE5,
				&H38, &HF2, &HFF, &HEB, &H00, &H40, &HB0, &HE1, &H27, &H00, &H00, &H1A,
				&H06, &H30, &HA0, &HE1, &H08, &H20, &HA0, &HE1, &H07, &H10, &HA0, &HE1,
				&H05, &H00, &HA0, &HE1, &H3B, &HF2, &HFF, &HEB, &H00, &H40, &HB0, &HE1,
				&H20, &H00, &H00, &H1A, &H04, &H00, &HD6, &HE5, &H02, &H00, &H50, &HE3,
				&H15, &H00, &H00, &H1A, &H9C, &H12, &HD5, &HE5, &H9D, &H22, &HD5, &HE5,
				&H00, &H30, &HA0, &HE3, &H0E, &H00, &H8D, &HE8, &H00, &H20, &HD6, &HE5,
				&H03, &H10, &HD6, &HE5, &H25, &H00, &HD5, &HE5, &H01, &H30, &HA0, &HE3,
				&H23, &HF2, &HFF, &HEB, &H00, &H40, &HB0, &HE1, &H12, &H00, &H00, &H1A,
				&H03, &H20, &HD6, &HE5, &H28, &H10, &HD5, &HE5, &H05, &H00, &HA0, &HE1,
				&H20, &HF2, &HFF, &HEB, &H00, &H40, &HB0, &HE1, &H0C, &H00, &H00, &H1A,
				&H05, &H00, &HA0, &HE1, &H69, &H00, &H00, &HEB, &H00, &H48, &HA0, &HE1,
				&H24, &H48, &HA0, &HE1, &H07, &H00, &H00, &HEA, &H38, &H00, &H95, &HE5,
				&H00, &H00, &H50, &HE3, &HF1, &HFF, &HFF, &H1A, &H05, &H00, &HA0, &HE1,
				&H2D, &H00, &H00, &HEB, &H00, &H40, &HA0, &HE1, &H05, &H00, &HA0, &HE1,
				&H1B, &HF2, &HFF, &HEB, &H04, &H30, &HA0, &HE1, &H06, &H20, &HA0, &HE1,
				&H0B, &H10, &HA0, &HE3, &H07, &H00, &HA0, &HE1, &H0E, &HF2, &HFF, &HEB,
				&HFE, &H43, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H30, &H40, &H2D, &HE9,
				&H14, &HD0, &H4D, &HE2, &H00, &H50, &HA0, &HE3, &H00, &H40, &HA0, &HE1,
				&H08, &H50, &H8D, &HE5, &H74, &H00, &H90, &HE5, &H00, &H00, &H50, &HE3,
				&H01, &H10, &HA0, &H13, &H04, &H00, &HA0, &H11, &H74, &H50, &H84, &H15,
				&H0B, &HF2, &HFF, &H1B, &H70, &H00, &H94, &HE5, &H00, &H00, &H50, &HE3,
				&H70, &H50, &H84, &H15, &H02, &H00, &H00, &HEA, &H10, &H10, &H9D, &HE5,
				&H04, &H00, &HA0, &HE1, &H05, &HF2, &HFF, &HEB, &H04, &H30, &H8D, &HE2,
				&H00, &H30, &H8D, &HE5, &H0C, &H30, &H8D, &HE2, &H08, &H20, &H8D, &HE2,
				&H10, &H10, &H8D, &HE2, &H90, &H00, &H84, &HE2, &HFF, &HF1, &HFF, &HEB,
				&H00, &H00, &H50, &HE3, &HF3, &HFF, &HFF, &H0A, &H08, &H00, &HDD, &HE5,
				&H00, &H00, &H50, &HE3, &H6C, &H20, &H94, &H15, &HBA, &H16, &HD4, &H11,
				&H04, &H00, &HA0, &H11, &HEE, &HF1, &HFF, &H1B, &H14, &HD0, &H8D, &HE2,
				&H30, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H70, &H40, &H2D, &HE9,
				&H00, &H40, &HA0, &HE1, &H0C, &H00, &H90, &HE5, &H00, &H50, &HA0, &HE3,
				&H00, &H00, &H50, &HE3, &H0F, &H00, &H00, &H0A, &H38, &H00, &H94, &HE5,
				&H00, &H00, &H50, &HE3, &H0C, &H00, &H00, &H1A, &H00, &H00, &HA0, &HE3,
				&H3B, &H02, &H00, &HEB, &H90, &H00, &H84, &HE2, &HEC, &HF1, &HFF, &HEB,
				&H00, &H00, &H50, &HE3, &H00, &H00, &HA0, &HE3, &H0C, &H00, &H84, &HE5,
				&H1C, &H50, &H9F, &H15, &H20, &H00, &H84, &HE5, &H02, &H00, &H00, &H1A,
				&H64, &H00, &HD4, &HE5, &HE5, &HF1, &HFF, &HEB, &H00, &H50, &HA0, &HE1,
				&H05, &H00, &HA0, &HE1, &H70, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H61, &H80, &H00, &H00, &H70, &H40, &H2D, &HE9, &H58, &H50, &H9F, &HE5,
				&H00, &H40, &HA0, &HE3, &H00, &H00, &H95, &HE5, &H90, &H00, &H80, &HE2,
				&HDF, &HF1, &HFF, &HEB, &H03, &H00, &H10, &HE3, &H00, &H10, &H95, &H15,
				&H01, &H20, &HA0, &HE3, &H01, &H40, &HA0, &H13, &H70, &H20, &H81, &H15,
				&H20, &H00, &H10, &HE3, &H04, &H00, &H00, &H0A, &H00, &H00, &H95, &HE5,
				&H00, &H10, &HD0, &HE5, &H02, &H00, &H51, &HE3, &H74, &H20, &H80, &H05,
				&H01, &H00, &H00, &HEA, &H00, &H00, &H54, &HE3, &H01, &H00, &H00, &H0A,
				&H01, &H00, &HA0, &HE3, &HD0, &HF1, &HFF, &HEB, &H70, &H40, &HBD, &HE8,
				&H01, &H00, &HA0, &HE3, &H1E, &HFF, &H2F, &HE1, &HC0, &H34, &HF0, &HBF,
				&H70, &H40, &H2D, &HE9, &H00, &H50, &HA0, &HE3, &H00, &H40, &HA0, &HE1,
				&H20, &H50, &H80, &HE5, &H0C, &H00, &H90, &HE5, &H00, &H00, &H50, &HE3,
				&H16, &H00, &H00, &H1A, &H00, &H20, &HA0, &HE3, &H30, &H10, &HE0, &HE3,
				&H04, &H00, &HA0, &HE1, &HCE, &HF1, &HFF, &HEB, &H04, &H00, &HA0, &HE3,
				&H34, &H01, &HC4, &HE5, &H90, &H00, &H84, &HE2, &HCD, &HF1, &HFF, &HEB,
				&H00, &H50, &HB0, &HE1, &H03, &H00, &H00, &H1A, &H64, &H00, &HD4, &HE5,
				&HB3, &HF1, &HFF, &HEB, &H00, &H00, &H50, &HE3, &H16, &H00, &H00, &H1A,
				&H01, &H00, &HA0, &HE3, &H0C, &H00, &H84, &HE5, &H10, &H00, &H94, &HE5,
				&H00, &H00, &H50, &HE3, &HF4, &H18, &HD4, &H01, &H01, &H20, &HA0, &H03,
				&H04, &H00, &HA0, &H01, &HBC, &HF1, &HFF, &H0B, &H09, &H00, &H00, &HEA,
				&H01, &H00, &H50, &HE3, &H07, &H00, &H00, &H1A, &H38, &H00, &H94, &HE5,
				&H00, &H00, &H50, &HE3, &H04, &H00, &H00, &H0A, &H24, &H00, &H9F, &HE5,
				&H00, &H00, &H90, &HE5, &H90, &H00, &H80, &HE2, &HA4, &HF1, &HFF, &HEB,
				&H1D, &H50, &H00, &HE2, &H01, &H00, &HA0, &HE3, &HE8, &H01, &H00, &HEB,
				&H05, &H00, &HB0, &HE1, &H08, &H00, &H9F, &H15, &H70, &H40, &HBD, &HE8,
				&H1E, &HFF, &H2F, &HE1, &HC0, &H34, &HF0, &HBF, &H61, &H80, &H00, &H00,
				&H70, &H40, &H2D, &HE9, &H01, &H50, &HA0, &HE1, &H0B, &H00, &H52, &HE3,
				&H02, &H10, &HA0, &HE1, &H03, &H60, &HA0, &HE1, &H00, &H40, &HA0, &HE1,
				&H15, &H00, &H00, &H0A, &H0D, &H00, &H51, &HE3, &H17, &H00, &H00, &H0A,
				&H11, &H00, &H51, &HE3, &H11, &H00, &H00, &H0A, &H86, &H00, &H51, &HE3,
				&H18, &H00, &H00, &H1A, &H06, &H10, &HA0, &HE1, &H04, &H00, &HA0, &HE1,
				&HB0, &HF1, &HFF, &HEB, &H27, &H00, &HD4, &HE5, &H02, &H00, &H50, &HE3,
				&H00, &H00, &H50, &H13, &H04, &H00, &H00, &H1A, &H04, &H00, &HA0, &HE1,
				&HB9, &HFF, &HFF, &HEB, &H00, &H00, &H50, &HE3, &H48, &H00, &H9F, &H15,
				&H63, &HF1, &HFF, &H1B, &H02, &H00, &HA0, &HE3, &H00, &H00, &HC4, &HE5,
				&H70, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H34, &H30, &H9F, &HE5,
				&H06, &H20, &HA0, &HE1, &H05, &H00, &HA0, &HE1, &H63, &HF1, &HFF, &HEB,
				&H06, &H20, &HA0, &HE1, &H05, &H10, &HA0, &HE1, &H04, &H00, &HA0, &HE1,
				&H9C, &HF1, &HFF, &HEB, &HF4, &HFF, &HFF, &HEA, &H14, &H30, &H9F, &HE5,
				&H06, &H20, &HA0, &HE1, &H05, &H00, &HA0, &HE1, &H5A, &HF1, &HFF, &HEB,
				&HEF, &HFF, &HFF, &HEA, &H61, &H80, &H00, &H00, &H22, &H40, &H00, &H00,
				&H26, &H40, &H00, &H00, &H10, &H40, &H2D, &HE9, &H01, &H00, &HA0, &HE3,
				&H94, &HF1, &HFF, &HEB, &H01, &H00, &HA0, &HE3, &H93, &HF1, &HFF, &HEB,
				&H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &HF8, &HB5, &H04, &H00,
				&H88, &H68, &H21, &H21, &H00, &H88, &H09, &H02, &H65, &H18, &H00, &H27,
				&H16, &H00, &H00, &H28, &H01, &HD0, &H1B, &H4E, &H00, &HE0, &HEF, &H70,
				&H1A, &H48, &H20, &H18, &H46, &H80, &H1A, &H48, &H20, &H18, &H00, &H7C,
				&H00, &H28, &H0A, &HD0, &H01, &H28, &H25, &HD1, &H28, &H78, &H00, &H28,
				&H03, &HD1, &HFF, &HF7, &HAD, &HFD, &H00, &H28, &H05, &HD1, &H27, &H73,
				&H07, &HE0, &H20, &H00, &HFC, &HF7, &H82, &HFB, &H17, &HE0, &H11, &H49,
				&H01, &H20, &H20, &H73, &H48, &H70, &H20, &H00, &HFC, &HF7, &H82, &HFB,
				&H0C, &H49, &H20, &H00, &H84, &H39, &H80, &H30, &HFC, &HF7, &H84, &HFB,
				&H83, &H20, &H80, &H01, &H20, &H18, &H47, &H63, &H87, &H63, &H68, &H78,
				&H00, &H28, &H03, &HD1, &H20, &H00, &HFC, &HF7, &H81, &HFB, &H06, &H00,
				&H30, &H00, &HF8, &HBC, &H08, &HBC, &H18, &H47, &H0C, &H41, &H00, &H00,
				&H60, &H31, &H00, &H00, &HE0, &H20, &H00, &H00, &HE0, &H79, &HF0, &HBF,
				&HF8, &HB5, &H04, &H00, &H88, &H68, &H21, &H21, &H00, &H88, &H09, &H02,
				&H66, &H18, &H00, &H28, &H01, &HD0, &H27, &H4A, &H01, &HE0, &H01, &H20,
				&HF0, &H70, &H26, &H48, &H20, &H18, &H02, &H80, &H24, &H48, &H28, &H30,
				&H21, &H18, &H20, &H00, &H00, &H23, &H00, &HF0, &H4B, &HFA, &H05, &H00,
				&H21, &H48, &H00, &H21, &H01, &H70, &H21, &H48, &H27, &H18, &H79, &H7C,
				&H08, &H00, &H28, &H43, &H03, &HD1, &H20, &H00, &HFC, &HF7, &H60, &HFB,
				&H05, &H00, &H78, &H7C, &H01, &H28, &H05, &HD1, &H00, &H2D, &H08, &HD1,
				&H20, &H00, &HFC, &HF7, &H5F, &HFB, &H05, &H00, &H00, &H2D, &H02, &HD1,
				&H04, &H20, &H20, &H73, &H1F, &HE0, &H38, &H7C, &H00, &H28, &H06, &HD0,
				&H01, &H28, &H1A, &HD1, &H30, &H78, &H00, &H28, &H06, &HD0, &H00, &H20,
				&H05, &HE0, &H20, &H00, &HFC, &HF7, &H1C, &HFB, &H05, &H00, &H10, &HE0,
				&H01, &H20, &H20, &H73, &H20, &H00, &HFC, &HF7, &H1D, &HFB, &H0B, &H49,
				&H20, &H00, &H84, &H39, &H80, &H30, &HFC, &HF7, &H1F, &HFB, &H83, &H21,
				&H89, &H01, &H00, &H20, &H61, &H18, &H48, &H63, &H88, &H63, &H28, &H00,
				&HF8, &HBC, &H08, &HBC, &H18, &H47, &H00, &H00, &H0B, &H41, &H00, &H00,
				&H60, &H31, &H00, &H00, &HE0, &H79, &HF0, &HBF, &HE0, &H20, &H00, &H00,
				&H6D, &H4B, &HF7, &HB5, &H9D, &H44, &H6D, &H4B, &H00, &H20, &H6B, &H44,
				&HD8, &H60, &H58, &H6A, &H17, &H00, &H80, &H68, &H98, &H60, &H19, &H6A,
				&H69, &H48, &H08, &H18, &HD8, &H61, &H40, &H7C, &H01, &H28, &H06, &HD0,
				&H67, &H48, &H65, &H4B, &H2C, &H33, &H9D, &H44, &HF0, &HBC, &H08, &HBC,
				&H18, &H47, &H62, &H4B, &H6B, &H44, &H18, &H6A, &H80, &H30, &H98, &H61,
				&HFC, &HF7, &H14, &HFB, &H5E, &H4B, &HC5, &H22, &H6B, &H44, &H1B, &H6A,
				&H92, &H01, &H9D, &H18, &HEA, &H6A, &H01, &H26, &H31, &H00, &H82, &H42,
				&H00, &HD8, &H00, &H21, &H58, &H4B, &H21, &H20, &H6B, &H44, &H1A, &H6A,
				&H00, &H02, &H14, &H18, &HA1, &H71, &H98, &H69, &HFC, &HF7, &H06, &HFB,
				&H01, &H21, &H09, &H03, &H88, &H42, &H01, &HDA, &H01, &H20, &H00, &HE0,
				&H00, &H20, &H50, &H4B, &H6B, &H44, &H18, &H61, &HE1, &H79, &H01, &H20,
				&H00, &H29, &H0C, &HD1, &HE1, &H78, &H00, &H29, &H09, &HD0, &H61, &H78,
				&H00, &H29, &H06, &HD1, &HA1, &H79, &H00, &H29, &H03, &HD1, &H61, &H7A,
				&H00, &H29, &H00, &HD1, &H00, &H20, &H46, &H4B, &H83, &H21, &H6B, &H44,
				&H1A, &H6A, &H89, &H01, &H52, &H18, &H00, &H28, &H5A, &H61, &H04, &HD0,
				&H20, &H33, &H03, &HCB, &HFC, &HF7, &HE6, &HFA, &H29, &HE0, &HE8, &H6B,
				&H43, &H1C, &H05, &HD0, &H3D, &H4B, &H6B, &H44, &H5A, &H69, &H91, &H6B,
				&H81, &H42, &H21, &HD2, &H3A, &H4B, &HE9, &H6A, &H6B, &H44, &H9A, &H69,
				&H02, &HA8, &HFC, &HF7, &HDD, &HFA, &H37, &H4B, &HE8, &H6A, &H6B, &H44,
				&H5A, &H69, &H91, &H6B, &H09, &H18, &H91, &H63, &H19, &H6A, &H8A, &H68,
				&H00, &H92, &H2E, &H6B, &H0F, &H6E, &H02, &H00, &H99, &H68, &H33, &H00,
				&H02, &HA8, &HFF, &HF7, &H89, &HFC, &H00, &H28, &H16, &HD0, &H2D, &H4B,
				&H6B, &H44, &H58, &H6A, &H19, &H6A, &HFC, &HF7, &HCB, &HFA, &H07, &H00,
				&H00, &H2F, &H16, &HD1, &H28, &H4B, &H6B, &H44, &HD8, &H69, &H00, &H7C,
				&H00, &H28, &H0A, &HD0, &H01, &H28, &H0E, &HD1, &H18, &H69, &H00, &H28,
				&H0B, &HD0, &H01, &H20, &HD8, &H60, &H08, &HE0, &H23, &H48, &H40, &H1D,
				&H04, &HE0, &H20, &H4B, &H6B, &H44, &H18, &H6A, &HFC, &HF7, &HBA, &HFA,
				&H07, &H00, &HE8, &H6B, &H43, &H1C, &H08, &HD0, &H1B, &H4B, &H01, &H21,
				&H6B, &H44, &H5A, &H69, &H92, &H6B, &H82, &H42, &H11, &HD2, &H00, &H21,
				&H0F, &HE0, &H17, &H4B, &H6B, &H44, &H98, &H69, &HFC, &HF7, &H80, &HFA,
				&H22, &H78, &H00, &H21, &H00, &H2A, &H02, &HD1, &H62, &H79, &H00, &H2A,
				&H03, &HD0, &HEA, &H6A, &H82, &H42, &H00, &HD9, &H01, &H21, &H61, &H72,
				&H60, &H7A, &H00, &H28, &H0C, &HD0, &H10, &H4C, &H20, &H78, &H00, &H28,
				&H08, &HD1, &H0B, &H4B, &H6B, &H44, &H18, &H6A, &HFC, &HF7, &H20, &HFA,
				&H07, &H00, &H01, &H26, &H26, &H70, &H08, &HE0, &H06, &H4B, &H6B, &H44,
				&HD8, &H68, &H00, &H28, &H03, &HD0, &H18, &H6A, &HFC, &HF7, &H0C, &HFA,
				&H07, &H00, &H38, &H00, &H37, &HE7, &H00, &H00, &HE0, &HF7, &HFF, &HFF,
				&H00, &H08, &H00, &H00, &HE0, &H20, &H00, &H00, &H01, &H81, &H00, &H00,
				&HE0, &H79, &HF0, &HBF, &HF7, &HB5, &H04, &H00, &H88, &H68, &H21, &H21,
				&H00, &H88, &H09, &H02, &H67, &H18, &H00, &H26, &H00, &H25, &H00, &H28,
				&H02, &HD0, &H1B, &H48, &H02, &H90, &H00, &HE0, &HBE, &H70, &H1A, &H48,
				&H02, &H99, &H20, &H18, &HC1, &H80, &HFF, &HF7, &H25, &HFC, &H00, &H28,
				&H00, &HD1, &H01, &H25, &H78, &H78, &H16, &H4F, &H00, &H28, &H03, &HD0,
				&H01, &H20, &H20, &H73, &H78, &H70, &H0B, &HE0, &H00, &H2D, &H04, &HD1,
				&H20, &H00, &HFC, &HF7, &H09, &HFA, &H02, &H90, &HF4, &HE7, &H20, &H00,
				&HFC, &HF7, &H04, &HFA, &H02, &H90, &H26, &H73, &H0D, &H48, &H20, &H18,
				&H86, &H83, &H20, &H00, &HFC, &HF7, &HEC, &HF9, &H0A, &H49, &H20, &H00,
				&H84, &H39, &H80, &H30, &HFC, &HF7, &HEE, &HF9, &H83, &H20, &H80, &H01,
				&H20, &H18, &H46, &H63, &H86, &H63, &H02, &H98, &HFE, &HBC, &H08, &HBC,
				&H18, &H47, &H00, &H00, &H0E, &H41, &H00, &H00, &H60, &H31, &H00, &H00,
				&HE0, &H79, &HF0, &HBF, &HE0, &H20, &H00, &H00, &H70, &HB5, &H06, &H00,
				&H0C, &H00, &H00, &H25, &HFC, &HF7, &HEE, &HFA, &H00, &H23, &HE1, &H5E,
				&H04, &H23, &HE0, &H5E, &H76, &H28, &H13, &HD0, &H08, &HDC, &H0E, &H28,
				&H10, &HD0, &H12, &H28, &H0E, &HD0, &H13, &H28, &H0C, &HD0, &H16, &H28,
				&H0D, &HD1, &H09, &HE0, &H78, &H28, &H07, &HD0, &H9A, &H28, &H03, &HD0,
				&H9C, &H28, &H01, &HD0, &H9E, &H28, &H04, &HD1, &H29, &H4C, &H36, &HE0,
				&H28, &H4C, &H64, &H1E, &H33, &HE0, &H31, &H00, &HFC, &HF7, &H46, &HF9,
				&H01, &H04, &H25, &H48, &H09, &H14, &HFF, &H22, &H13, &H32, &H40, &H1C,
				&H91, &H42, &HA1, &H80, &H3E, &HD0, &HCB, &H1F, &HFF, &H3B, &HFF, &HF7,
				&HAF, &HFB, &H09, &H06, &H0B, &H0C, &H0B, &H12, &H0B, &H18, &H0B, &H1E,
				&H0B, &H00, &H2A, &H00, &H21, &H00, &H30, &H00, &HFC, &HF7, &H36, &HF9,
				&H16, &HE0, &H2A, &H00, &H21, &H00, &H30, &H00, &HFC, &HF7, &H4C, &HFA,
				&H10, &HE0, &H2A, &H00, &H21, &H00, &H30, &H00, &HFC, &HF7, &H4E, &HFA,
				&H0A, &HE0, &H2A, &H00, &H21, &H00, &H30, &H00, &HFC, &HF7, &H3C, &HF9,
				&H04, &HE0, &H21, &H00, &H10, &H4A, &H30, &H00, &H00, &HF0, &H24, &HF8,
				&H04, &H00, &HFF, &HF7, &H97, &HFB, &H00, &H28, &H11, &HD1, &H0D, &H48,
				&H41, &H78, &H01, &H29, &H0D, &HD1, &H00, &H25, &H45, &H70, &HC5, &H20,
				&H80, &H01, &H30, &H18, &HC5, &H61, &H85, &H61, &H45, &H61, &H30, &H00,
				&H07, &H49, &H80, &H30, &HFC, &HF7, &H70, &HF9, &H35, &H73, &H20, &H00,
				&H70, &HBC, &H08, &HBC, &H18, &H47, &H00, &H00, &H02, &H81, &H00, &H00,
				&H02, &H41, &H00, &H00, &HE0, &H79, &HF0, &HBF, &H5C, &H20, &H00, &H00,
				&H70, &HB5, &H0E, &H00, &H05, &H00, &H8C, &H68, &H10, &H00, &H22, &HD1,
				&H21, &H21, &H09, &H02, &H69, &H18, &HCA, &H79, &H00, &H2A, &H22, &H88,
				&H14, &HD0, &H00, &H2A, &H01, &HD0, &H11, &H48, &H17, &HE0, &H00, &H22,
				&HCA, &H71, &H10, &H49, &H69, &H18, &H49, &H7C, &H00, &H29, &H05, &HD0,
				&H01, &H29, &H0E, &HD1, &H28, &H00, &HFC, &HF7, &H65, &HF9, &H0A, &HE0,
				&H28, &H00, &HFC, &HF7, &H59, &HF9, &H06, &HE0, &H00, &H2A, &H02, &HD0,
				&H01, &H22, &HCA, &H71, &H01, &HE0, &H05, &H48, &H40, &H1C, &H02, &H00,
				&H31, &H00, &H23, &H88, &H28, &H00, &H00, &HF0, &H07, &HF8, &H70, &HBC,
				&H08, &HBC, &H18, &H47, &H06, &H41, &H00, &H00, &HE0, &H20, &H00, &H00,
				&H70, &HB5, &H06, &H00, &H88, &H68, &H0C, &H00, &H02, &H80, &H43, &H80,
				&HFF, &H20, &H31, &H00, &H15, &H00, &H10, &H30, &HFC, &HF7, &H30, &HFA,
				&H01, &H04, &H08, &H48, &H09, &H14, &H30, &H18, &H1E, &H23, &HC0, &H5E,
				&HA2, &H68, &H04, &H23, &HFC, &HF7, &H32, &HFA, &H00, &H28, &H00, &HD0,
				&H03, &H4D, &H28, &H00, &H70, &HBC, &H08, &HBC, &H18, &H47, &H00, &H00,
				&HE0, &H20, &H00, &H00, &H07, &H81, &H00, &H00, &HF8, &HB5, &H07, &H00,
				&H88, &H68, &H16, &H00, &H0D, &H00, &H00, &H24, &H02, &H80, &H02, &H2B,
				&H43, &H80, &H02, &HD9, &H9B, &H1E, &H1C, &H04, &H24, &H0C, &H39, &H00,
				&HFF, &H20, &H0A, &H30, &HFC, &HF7, &H08, &HFA, &H01, &H04, &H08, &H48,
				&H1E, &H23, &H38, &H18, &HC0, &H5E, &H09, &H14, &HAA, &H68, &HA3, &H1D,
				&HFC, &HF7, &H0A, &HFA, &H00, &H28, &H00, &HD0, &H03, &H4E, &H30, &H00,
				&HF8, &HBC, &H08, &HBC, &H18, &H47, &H00, &H00, &HE0, &H20, &H00, &H00,
				&H07, &H81, &H00, &H00, &HFF, &HB5, &H81, &HB0, &H0A, &HAE, &HC0, &HCE,
				&H00, &H25, &H23, &H49, &H04, &H00, &H05, &H73, &H45, &H73, &H01, &H20,
				&H61, &H18, &H08, &H74, &H48, &H74, &H20, &H48, &H83, &H22, &H20, &H18,
				&H05, &H80, &H45, &H80, &H85, &H80, &HC5, &H80, &HC5, &H20, &H80, &H01,
				&H20, &H18, &H85, &H62, &HC5, &H62, &H05, &H63, &H92, &H01, &H45, &H63,
				&HA2, &H18, &H85, &H63, &H55, &H63, &H95, &H63, &HC5, &H61, &H85, &H61,
				&H45, &H61, &H21, &H20, &H00, &H02, &H20, &H18, &H85, &H72, &H02, &H20,
				&H8D, &H83, &HC8, &H83, &H10, &H49, &H20, &H00, &H84, &H39, &H80, &H30,
				&HFC, &HF7, &HB2, &HF8, &H20, &H00, &HFC, &HF7, &HA7, &HF8, &H30, &H22,
				&H20, &H00, &H02, &H99, &H50, &H30, &HFC, &HF7, &H31, &HF9, &H30, &H22,
				&H20, &H00, &H03, &H99, &H20, &H30, &HFC, &HF7, &H2B, &HF9, &H04, &H98,
				&H21, &H1D, &H41, &HC1, &H06, &H48, &H27, &H70, &H05, &H70, &H45, &H70,
				&H05, &HB0, &HF0, &HBC, &H08, &HBC, &H00, &H20, &H18, &H47, &H00, &H00,
				&HE0, &H20, &H00, &H00, &H60, &H31, &H00, &H00, &HE0, &H79, &HF0, &HBF,
				&H5C, &H00, &H9F, &HE5, &H00, &H20, &HE0, &HE3, &H08, &H20, &H80, &HE5,
				&H54, &H10, &H9F, &HE5, &H04, &H30, &H91, &HE5, &H08, &H30, &H83, &HE3,
				&H04, &H30, &H81, &HE5, &H00, &H30, &HA0, &HE3, &H08, &H30, &H80, &HE5,
				&H08, &H20, &H80, &HE5, &H04, &HC0, &H91, &HE5, &H08, &HC0, &H8C, &HE3,
				&H04, &HC0, &H81, &HE5, &H08, &H30, &H80, &HE5, &H08, &H20, &H80, &HE5,
				&H04, &HC0, &H91, &HE5, &H10, &HC0, &HCC, &HE3, &H04, &HC0, &H81, &HE5,
				&H08, &H30, &H80, &HE5, &H08, &H20, &H80, &HE5, &H04, &H20, &H91, &HE5,
				&H02, &H2B, &H82, &HE3, &H04, &H20, &H81, &HE5, &H08, &H30, &H80, &HE5,
				&H1E, &HFF, &H2F, &HE1, &H00, &H03, &H00, &HF8, &H00, &H06, &H00, &HF8,
				&H2C, &H20, &H9F, &HE5, &H24, &H10, &H9F, &HE5, &H00, &H30, &HE0, &HE3,
				&H00, &H00, &H50, &HE3, &H00, &HC0, &HA0, &HE3, &H08, &H30, &H82, &HE5,
				&H00, &H00, &H91, &HE5, &H02, &H0B, &HC0, &H03, &H02, &H0B, &H80, &H13,
				&H00, &H00, &H81, &HE5, &H08, &HC0, &H82, &HE5, &H1E, &HFF, &H2F, &HE1,
				&H00, &H06, &H00, &HF8, &H00, &H03, &H00, &HF8, &HF0, &H47, &H2D, &HE9,
				&HB8, &HD0, &H4D, &HE2, &H0C, &H50, &H8D, &HE2, &H01, &HA0, &HA0, &HE1,
				&H00, &H70, &HA0, &HE3, &H00, &H40, &HA0, &HE1, &HCF, &HF0, &HFF, &HEB,
				&HDC, &H60, &H9F, &HE5, &H00, &H00, &HA0, &HE3, &H01, &H00, &H80, &HE2,
				&H06, &H00, &H50, &HE1, &HFC, &HFF, &HFF, &HBA, &H00, &H00, &H00, &HEF,
				&HC9, &HF0, &HFF, &HEB, &H06, &H00, &H50, &HE3, &H00, &H00, &H00, &H1A,
				&HFE, &HFF, &HFF, &HEA, &H8C, &H00, &H8D, &HE2, &HC5, &HF0, &HFF, &HEB,
				&H06, &H80, &HA0, &HE3, &H00, &H90, &HA0, &HE3, &H15, &H00, &H00, &HEA,
				&HB4, &H80, &HCD, &HE1, &H04, &H10, &H8D, &HE2, &H8C, &H00, &H8D, &HE2,
				&HB6, &H90, &HCD, &HE1, &HB8, &H40, &HCD, &HE1, &HBD, &HF0, &HFF, &HEB,
				&H80, &H20, &HA0, &HE3, &H0C, &H10, &H8D, &HE2, &H8C, &H00, &H8D, &HE2,
				&HBA, &HF0, &HFF, &HEB, &H00, &H00, &H50, &HE3, &H06, &H00, &H00, &H0A,
				&H00, &H00, &HA0, &HE3, &H01, &H00, &H80, &HE2, &H06, &H00, &H50, &HE1,
				&HFC, &HFF, &HFF, &HBA, &H8C, &H00, &H8D, &HE2, &HB0, &HF0, &HFF, &HEB,
				&H02, &H00, &H00, &HEA, &HB2, &H00, &HD5, &HE1, &H01, &H00, &H50, &HE3,
				&H03, &H00, &H00, &H0A, &H00, &H00, &H57, &HE3, &H01, &H00, &H00, &H1A,
				&H00, &H00, &H54, &HE3, &HE5, &HFF, &HFF, &H1A, &H04, &H00, &HA0, &HE3,
				&HB0, &H00, &HCD, &HE1, &H02, &H00, &HA0, &HE3, &HB2, &H00, &HCD, &HE1,
				&H8C, &H00, &H8D, &HE2, &H0D, &H10, &HA0, &HE1, &HA2, &HF0, &HFF, &HEB,
				&H8C, &H00, &H8D, &HE2, &HA2, &HF0, &HFF, &HEB, &H00, &H00, &H54, &HE3,
				&H04, &H00, &HD5, &H15, &H0A, &H00, &HA0, &H01, &H9F, &HF0, &HFF, &HEB,
				&HB8, &HD0, &H8D, &HE2, &HF0, &H47, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H20, &HA1, &H07, &H00, &H70, &H40, &H2D, &HE9, &H00, &H40, &HA0, &HE1,
				&H00, &H00, &H90, &HE5, &H00, &H50, &HA0, &HE3, &H34, &H10, &H90, &HE5,
				&H02, &H0A, &H11, &HE3, &H02, &H50, &HA0, &H03, &H0D, &H00, &H00, &H0A,
				&H02, &H1C, &HA0, &HE3, &H3C, &H10, &H80, &HE5, &H00, &H10, &H94, &HE5,
				&H02, &H0A, &HA0, &HE3, &H3C, &H00, &H81, &HE5, &H10, &H00, &H94, &HE5,
				&H71, &HF1, &HFF, &HEB, &H10, &H00, &H94, &HE5, &H6F, &HF1, &HFF, &HEB,
				&H18, &H00, &H94, &HE5, &H1C, &H10, &H94, &HE5, &HB0, &H00, &HD0, &HE1,
				&H00, &H00, &H51, &HE1, &H01, &H50, &HA0, &H33, &H05, &H00, &HA0, &HE1,
				&H70, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H00, &H00, &H9F, &HE5,
				&H1E, &HFF, &H2F, &HE1, &H38, &H34, &HF0, &HBF, &H00, &H00, &H9F, &HE5,
				&H1E, &HFF, &H2F, &HE1, &H18, &H33, &HF0, &HBF, &H00, &H00, &H9F, &HE5,
				&H1E, &HFF, &H2F, &HE1, &H54, &H34, &HF0, &HBF, &H00, &H00, &H9F, &HE5,
				&H1E, &HFF, &H2F, &HE1, &H64, &H34, &HF0, &HBF, &H70, &H40, &H2D, &HE9,
				&H10, &H60, &H8D, &HE2, &H40, &HC0, &H9F, &HE5, &H70, &H00, &H96, &HE8,
				&H00, &HE0, &H9C, &HE5, &H00, &HE0, &HC0, &HE5, &H04, &H00, &H9C, &HE5,
				&H00, &H00, &HC1, &HE5, &H08, &H00, &H9C, &HE5, &H00, &H00, &HC2, &HE5,
				&H04, &H00, &HA0, &HE3, &H00, &H00, &HC3, &HE5, &H02, &H00, &HA0, &HE3,
				&H00, &H00, &HC4, &HE5, &H14, &H00, &H9F, &HE5, &H00, &H00, &H85, &HE5,
				&H25, &H00, &HA0, &HE3, &H00, &H00, &H86, &HE5, &H70, &H40, &HBD, &HE8,
				&H1E, &HFF, &H2F, &HE1, &H98, &H34, &HF0, &HBF, &H51, &H25, &H00, &H00,
				&H3C, &H40, &H2D, &HE9, &H00, &H50, &HA0, &HE1, &H00, &H40, &HA0, &HE3,
				&H84, &H00, &H84, &HE0, &H80, &H00, &H85, &HE0, &H00, &H10, &HA0, &HE3,
				&H5D, &HF1, &HFF, &HEB, &H01, &H40, &H84, &HE2, &H0C, &H00, &H54, &HE3,
				&HF8, &HFF, &HFF, &HBA, &H00, &H00, &HA0, &HE3, &H53, &H00, &HC5, &HE5,
				&HB0, &H05, &HC5, &HE1, &H48, &H00, &HC5, &HE5, &HC8, &H30, &HA0, &HE3,
				&H00, &H20, &HA0, &HE3, &H52, &H00, &HC5, &HE5, &H0C, &H00, &H8D, &HE8,
				&H0A, &H30, &HA0, &HE3, &H05, &H00, &HA0, &HE1, &H02, &H10, &HA0, &HE3,
				&H4F, &HF1, &HFF, &HEB, &H3C, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H34, &H20, &H90, &HE5, &H30, &H30, &H90, &HE5, &H24, &H10, &H80, &HE2,
				&H03, &H00, &H52, &HE1, &H03, &HC0, &H42, &HE0, &H00, &H30, &H91, &H35,
				&H00, &H30, &HA0, &H23, &H03, &H30, &H9C, &HE0, &H10, &H00, &HA0, &H03,
				&H1E, &HFF, &H2F, &H01, &H08, &H30, &H91, &HE5, &H04, &HC0, &H91, &HE5,
				&H00, &H00, &H52, &HE3, &H00, &H10, &H91, &H05, &H01, &H10, &H42, &H12,
				&H01, &H10, &H41, &H02, &H01, &H20, &HA0, &HE3, &H9C, &H31, &H21, &HE0,
				&H08, &H20, &H81, &HE5, &H0E, &H21, &HC0, &HE5, &H00, &H00, &HA0, &HE3,
				&H1E, &HFF, &H2F, &HE1, &H70, &H40, &H2D, &HE9, &H10, &H00, &H80, &HE3,
				&H02, &H5B, &HC0, &HE3, &H18, &H50, &HC5, &HE3, &H05, &H00, &H01, &HE0,
				&HD8, &H10, &H9F, &HE5, &HD8, &HC0, &H9F, &HE5, &H10, &H00, &HD0, &HE3,
				&H00, &HE0, &HE0, &HE3, &H00, &H40, &HA0, &HE3, &H1C, &H00, &H00, &H0A,
				&H00, &H00, &H52, &HE3, &H08, &HE0, &H8C, &HE5, &H38, &H20, &H91, &HE5,
				&H2E, &H6A, &H00, &HE0, &H06, &H20, &HC2, &H01, &H06, &H20, &H82, &H11,
				&H38, &H20, &H81, &HE5, &H08, &H40, &H8C, &HE5, &H00, &H00, &H53, &HE3,
				&H08, &HE0, &H8C, &HE5, &H3C, &H20, &H91, &HE5, &H00, &H3A, &HA0, &HE1,
				&H23, &H3A, &HA0, &HE1, &H03, &H20, &HC2, &H01, &H03, &H20, &H82, &H11,
				&H3C, &H20, &H81, &HE5, &H08, &H40, &H8C, &HE5, &H08, &HE0, &H8C, &HE5,
				&H30, &H20, &H91, &HE5, &H00, &H0A, &HA0, &HE1, &H20, &H0A, &HA0, &HE1,
				&H00, &H20, &H82, &HE1, &H30, &H20, &H81, &HE5, &H08, &H40, &H8C, &HE5,
				&H08, &HE0, &H8C, &HE5, &H34, &H20, &H91, &HE5, &H00, &H00, &HC2, &HE1,
				&H34, &H00, &H81, &HE5, &H08, &H40, &H8C, &HE5, &H08, &HE0, &H8C, &HE5,
				&H04, &H00, &H91, &HE5, &H05, &H2A, &HA0, &HE1, &H22, &H2A, &HA0, &HE1,
				&H02, &H00, &HC0, &HE1, &H04, &H00, &H81, &HE5, &H08, &H40, &H8C, &HE5,
				&H08, &HE0, &H8C, &HE5, &H10, &H00, &H91, &HE5, &H10, &H00, &H81, &HE5,
				&H08, &H40, &H8C, &HE5, &H08, &HE0, &H8C, &HE5, &H1C, &H00, &H91, &HE5,
				&H1C, &H00, &H81, &HE5, &H08, &H40, &H8C, &HE5, &H08, &HE0, &H8C, &HE5,
				&H28, &H00, &H91, &HE5, &H28, &H00, &H81, &HE5, &H08, &H40, &H8C, &HE5,
				&H70, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H00, &H06, &H00, &HF8,
				&H00, &H03, &H00, &HF8, &H10, &H00, &HC0, &HE3, &H02, &HCB, &H80, &HE3,
				&H5C, &H00, &H9F, &HE5, &H00, &H20, &HE0, &HE3, &H08, &HC0, &H8C, &HE3,
				&H08, &H20, &H80, &HE5, &H50, &H10, &H9F, &HE5, &H04, &H30, &H91, &HE5,
				&H02, &H36, &H03, &HE0, &H22, &HCA, &H0C, &HE0, &H03, &H30, &H8C, &HE1,
				&H04, &H30, &H81, &HE5, &H00, &H30, &HA0, &HE3, &H08, &H30, &H80, &HE5,
				&H08, &H20, &H80, &HE5, &H10, &HC0, &H91, &HE5, &H10, &HC0, &H81, &HE5,
				&H08, &H30, &H80, &HE5, &H08, &H20, &H80, &HE5, &H1C, &HC0, &H91, &HE5,
				&H1C, &HC0, &H81, &HE5, &H08, &H30, &H80, &HE5, &H08, &H20, &H80, &HE5,
				&H28, &H20, &H91, &HE5, &H28, &H20, &H81, &HE5, &H08, &H30, &H80, &HE5,
				&H1E, &HFF, &H2F, &HE1, &H00, &H03, &H00, &HF8, &H00, &H06, &H00, &HF8,
				&H02, &HCB, &HC0, &HE3, &H5C, &H00, &H9F, &HE5, &H00, &H20, &HE0, &HE3,
				&H18, &HC0, &HCC, &HE3, &H08, &H20, &H80, &HE5, &H50, &H10, &H9F, &HE5,
				&H00, &H30, &H91, &HE5, &H02, &H36, &H03, &HE0, &H22, &HCA, &H0C, &HE0,
				&H03, &H30, &H8C, &HE1, &H00, &H30, &H81, &HE5, &H00, &H30, &HA0, &HE3,
				&H08, &H30, &H80, &HE5, &H08, &H20, &H80, &HE5, &H0C, &HC0, &H91, &HE5,
				&H0C, &HC0, &H81, &HE5, &H08, &H30, &H80, &HE5, &H08, &H20, &H80, &HE5,
				&H18, &HC0, &H91, &HE5, &H18, &HC0, &H81, &HE5, &H08, &H30, &H80, &HE5,
				&H08, &H20, &H80, &HE5, &H24, &H20, &H91, &HE5, &H24, &H20, &H81, &HE5,
				&H08, &H30, &H80, &HE5, &H1E, &HFF, &H2F, &HE1, &H00, &H03, &H00, &HF8,
				&H00, &H06, &H00, &HF8, &H44, &H20, &H9F, &HE5, &H00, &H10, &HA0, &HE3,
				&H00, &H00, &HA0, &HE3, &H01, &H30, &HA0, &HE3, &H00, &HC1, &H92, &HE7,
				&H00, &H00, &H5C, &HE3, &H13, &H10, &H81, &H11, &H01, &H00, &H80, &HE2,
				&H11, &H00, &H50, &HE3, &HF9, &HFF, &HFF, &H3A, &H20, &H00, &H9F, &HE5,
				&H00, &H20, &HA0, &HE3, &H00, &H10, &H80, &HE5, &HC0, &H20, &H80, &HE5,
				&H08, &H20, &H80, &HE5, &HC4, &H20, &H80, &HE5, &H0C, &H00, &H9F, &HE5,
				&H06, &H00, &H80, &HE8, &H1E, &HFF, &H2F, &HE1, &H44, &H57, &HF0, &HBF,
				&H00, &H03, &H00, &HF8, &HB0, &H34, &HF0, &HBF, &HF0, &H41, &H2D, &HE9,
				&H00, &H40, &HA0, &HE1, &HD0, &H00, &HD0, &HE1, &H02, &H70, &HA0, &HE1,
				&H01, &H60, &HA0, &HE1, &H01, &H00, &H50, &HE3, &H01, &H00, &H70, &H13,
				&H00, &H50, &HE0, &HE3, &H11, &H00, &H00, &H0A, &H02, &H0C, &H84, &HE2,
				&H52, &H00, &H80, &HE2, &H14, &H20, &HA0, &HE3, &H06, &H10, &HA0, &HE1,
				&HDD, &HFB, &HFF, &HEB, &H25, &H0E, &HA0, &HE3, &HB4, &H70, &H80, &HE1,
				&H06, &H00, &HA0, &HE1, &H01, &HF1, &HFF, &HEB, &H01, &H00, &H50, &HE3,
				&H06, &H00, &H00, &H1A, &H4E, &H02, &HC4, &HE5, &H1C, &H10, &H9F, &HE5,
				&H04, &H00, &HA0, &HE1, &HFC, &HF0, &HFF, &HEB, &HD0, &H00, &HD4, &HE1,
				&HF0, &H41, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H00, &H00, &HE0, &HE3,
				&H00, &H50, &HC4, &HE5, &HFA, &HFF, &HFF, &HEA, &HEC, &H34, &HF0, &HBF,
				&H10, &H40, &H2D, &HE9, &H00, &H40, &HA0, &HE1, &HD0, &H00, &HD0, &HE1,
				&H00, &H20, &HE0, &HE3, &H00, &H00, &H50, &HE3, &H01, &H00, &H70, &H13,
				&H0A, &H00, &H00, &H0A, &H4E, &H02, &HD4, &HE5, &H01, &H00, &H50, &HE3,
				&H07, &H00, &H00, &H1A, &H00, &H00, &H51, &HE3, &H20, &H10, &H9F, &H05,
				&H20, &H10, &H9F, &H15, &H04, &H00, &HA0, &HE1, &HE6, &HF0, &HFF, &HEB,
				&HD0, &H00, &HD4, &HE1, &H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H00, &H00, &HE0, &HE3, &H00, &H20, &HC4, &HE5, &HFA, &HFF, &HFF, &HEA,
				&H9C, &H35, &HF0, &HBF, &H6C, &H35, &HF0, &HBF, &H10, &H40, &H2D, &HE9,
				&H00, &H40, &HA0, &HE1, &HD0, &H00, &HD0, &HE1, &H00, &H10, &HE0, &HE3,
				&H00, &H00, &H50, &HE3, &H01, &H00, &H70, &H13, &H08, &H00, &H00, &H0A,
				&H4E, &H02, &HD4, &HE5, &H01, &H00, &H50, &HE3, &H05, &H00, &H00, &H1A,
				&H1C, &H10, &H9F, &HE5, &H04, &H00, &HA0, &HE1, &HD1, &HF0, &HFF, &HEB,
				&HD0, &H00, &HD4, &HE1, &H10, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H00, &H00, &HE0, &HE3, &H00, &H10, &HC4, &HE5, &HFA, &HFF, &HFF, &HEA,
				&H3C, &H35, &HF0, &HBF, &HF8, &H4F, &H2D, &HE9, &HDC, &H41, &H9F, &HE5,
				&H00, &H00, &HA0, &HE3, &H01, &H70, &HA0, &HE3, &H4C, &H00, &H84, &HE5,
				&H9E, &HF0, &HFF, &HEB, &H00, &H00, &H50, &HE3, &H58, &H00, &H00, &H0A,
				&HC4, &H51, &H9F, &HE5, &H03, &H00, &HA0, &HE3, &H01, &HBA, &HA0, &HE3,
				&H00, &H00, &HC4, &HE5, &H3C, &HB0, &H85, &HE5, &H30, &H00, &H95, &HE5,
				&H01, &H0A, &H80, &HE3, &H30, &H00, &H85, &HE5, &H05, &H00, &HA0, &HE3,
				&H20, &HEE, &HFF, &HEB, &HA0, &H11, &H9F, &HE5, &H00, &H62, &H81, &HE0,
				&H0C, &H00, &H96, &HE5, &H03, &H00, &HC0, &HE3, &H0C, &H00, &H86, &HE5,
				&H20, &H00, &H94, &HE5, &H41, &H10, &H4B, &HE2, &H01, &H90, &H00, &HE0,
				&HD9, &HF0, &HFF, &HEB, &H24, &H10, &H84, &HE2, &H09, &H00, &HA0, &HE1,
				&HCB, &HF0, &HFF, &HEB, &H74, &H71, &H9F, &HE5, &H01, &HA0, &H00, &HE2,
				&H08, &H00, &H87, &HE2, &H00, &H80, &HE0, &HE3, &H68, &H21, &H9F, &HE5,
				&H98, &H10, &H00, &HE1, &H02, &H10, &H81, &HE1, &H08, &H10, &H87, &HE5,
				&HC4, &H00, &H87, &HE2, &H98, &H10, &H00, &HE1, &HFF, &H10, &H81, &HE3,
				&HC4, &H10, &H87, &HE5, &H10, &H10, &H94, &HE5, &H24, &H00, &H84, &HE2,
				&HC8, &HF0, &HFF, &HEB, &H0A, &HA0, &H00, &HE0, &HC7, &HF0, &HFF, &HEB,
				&H10, &H10, &H94, &HE5, &H24, &H00, &H84, &HE2, &HC5, &HF0, &HFF, &HEB,
				&H0A, &HA0, &H00, &HE0, &HC4, &H00, &H87, &HE2, &H98, &H10, &H00, &HE1,
				&HFF, &H10, &HC1, &HE3, &HC4, &H10, &H87, &HE5, &H08, &H00, &H87, &HE2,
				&H14, &H21, &H9F, &HE5, &H98, &H10, &H00, &HE1, &H02, &H10, &H01, &HE0,
				&H08, &H10, &H87, &HE5, &HBB, &HF0, &HFF, &HEB, &H24, &H10, &H84, &HE2,
				&H09, &H00, &HA0, &HE1, &HB0, &HF0, &HFF, &HEB, &H0A, &H70, &H00, &HE0,
				&H3C, &HB0, &H85, &HE5, &H30, &H00, &H95, &HE5, &H01, &H0A, &HC0, &HE3,
				&H30, &H00, &H85, &HE5, &H00, &H00, &H95, &HE5, &H01, &H00, &H80, &HE3,
				&H00, &H00, &H85, &HE5, &H00, &H00, &H95, &HE5, &H02, &H00, &H80, &HE3,
				&H00, &H00, &H85, &HE5, &H00, &H00, &H95, &HE5, &H04, &H00, &H80, &HE3,
				&H00, &H00, &H85, &HE5, &H00, &H00, &H95, &HE5, &H0A, &H00, &HC0, &HE3,
				&H00, &H00, &H85, &HE5, &H00, &H00, &H95, &HE5, &H14, &H00, &HC0, &HE3,
				&H00, &H00, &H85, &HE5, &H00, &H00, &H95, &HE5, &H01, &H00, &HC0, &HE3,
				&H00, &H00, &H85, &HE5, &H02, &H1A, &HA0, &HE3, &H3C, &H10, &H85, &HE5,
				&H0C, &H00, &H96, &HE5, &H01, &H00, &H80, &HE3, &H0C, &H00, &H86, &HE5,
				&H01, &H00, &HA0, &HE3, &H4C, &H00, &H84, &HE5, &H24, &H00, &H95, &HE5,
				&H3C, &H10, &H85, &HE5, &H13, &H00, &H00, &HEA, &H97, &HF0, &HFF, &HEB,
				&H00, &H00, &H50, &HE3, &H0D, &H00, &H00, &H0A, &H02, &H00, &HA0, &HE3,
				&H00, &H00, &HC4, &HE5, &H04, &H00, &HD4, &HE5, &H00, &H20, &HA0, &HE3,
				&H24, &H10, &H84, &HE2, &H89, &HF0, &HFF, &HEB, &H01, &H50, &H00, &HE2,
				&H8A, &HF0, &HFF, &HEB, &H03, &H00, &HD4, &HE5, &H00, &H20, &HA0, &HE3,
				&H24, &H10, &H84, &HE2, &H83, &HF0, &HFF, &HEB, &H05, &H70, &H00, &HE0,
				&H02, &H00, &H00, &HEA, &H01, &H00, &HA0, &HE3, &H00, &H00, &HC4, &HE5,
				&H81, &HF0, &HFF, &HEB, &H00, &H00, &HA0, &HE3, &H00, &H00, &HC4, &HE5,
				&H07, &H00, &HA0, &HE1, &HF8, &H4F, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&HD4, &H36, &HF0, &HBF, &H00, &H0D, &H00, &HF8, &H00, &H02, &H00, &HF8,
				&H00, &H03, &H00, &HF8, &HFD, &HFF, &H01, &H00, &H02, &H00, &HFE, &HFF,
				&H04, &HE0, &H2D, &HE5, &HC4, &HED, &HFF, &HEB, &H1D, &H10, &HA0, &HE3,
				&H91, &H00, &H00, &HE0, &H14, &H10, &H9F, &HE5, &H00, &H10, &H91, &HE5,
				&H00, &H01, &H81, &HE0, &H01, &H0C, &H80, &HE2, &HF4, &H04, &HD0, &HE1,
				&H04, &HE0, &H9D, &HE4, &H1E, &HFF, &H2F, &HE1, &HF0, &H35, &HF0, &HBF,
				&H14, &H30, &H9F, &HE5, &H00, &H30, &H80, &HE5, &H10, &H00, &H9F, &HE5,
				&H00, &H00, &H81, &HE5, &H0C, &H00, &H9F, &HE5, &H00, &H00, &H82, &HE5,
				&H1E, &HFF, &H2F, &HE1, &HDC, &H78, &HF0, &HBF, &HD0, &H9A, &H01, &HC0,
				&HE0, &H9A, &H01, &HC0, &HFE, &HB5, &H04, &H00, &H40, &H69, &H0E, &H00,
				&H00, &H25, &H00, &H28, &H0D, &HD0, &HA0, &H69, &H00, &H28, &H02, &HD1,
				&HB0, &H68, &HA0, &H61, &H6F, &HE0, &HE0, &H69, &H00, &H28, &H02, &HD1,
				&HB0, &H68, &HE0, &H61, &H69, &HE0, &H37, &H4D, &H67, &HE0, &H31, &H20,
				&H80, &H01, &H27, &H18, &H78, &H7B, &H00, &H28, &H01, &H90, &H04, &HD1,
				&H29, &H00, &H30, &H00, &H00, &HF0, &H5A, &HFA, &H2E, &HE0, &HB1, &H68,
				&H20, &H00, &HFC, &HF7, &H41, &HFA, &H05, &H00, &H55, &HD1, &H21, &H00,
				&H30, &H00, &HFC, &HF7, &H43, &HFA, &H05, &H00, &H78, &H7B, &H01, &H99,
				&H88, &H42, &H4C, &HD0, &H29, &H49, &H61, &H18, &H02, &H91, &HA3, &H21,
				&H49, &H01, &H67, &H18, &H27, &H49, &H66, &H18, &H00, &H28, &H17, &HD0,
				&H01, &H28, &H3E, &HD1, &HB8, &H7D, &H00, &H28, &H34, &HD0, &H01, &H28,
				&H3B, &HD1, &HB0, &H7A, &H00, &H28, &H38, &HD1, &H21, &H20, &H80, &H01,
				&H20, &H18, &H42, &H68, &H01, &H21, &H8B, &H02, &HD2, &H18, &H91, &H72,
				&H41, &H68, &H20, &H00, &HFC, &HF7, &H26, &HFA, &H05, &H00, &H2A, &HE0,
				&HB8, &H7D, &H00, &H28, &H02, &HD0, &HB0, &H7A, &H00, &H28, &H24, &HD0,
				&H17, &H48, &H21, &H18, &H20, &H00, &HFC, &HF7, &H21, &HFA, &H05, &H00,
				&H01, &H20, &HF0, &H72, &H02, &H20, &HA0, &H70, &HB8, &H7D, &H00, &H28,
				&H08, &HD1, &H01, &H98, &H02, &H28, &H05, &HD1, &H00, &H23, &HE0, &H5E,
				&H02, &H9A, &H29, &H21, &HFB, &HF7, &HBC, &HFC, &HB0, &H7A, &H00, &H28,
				&H0B, &HD0, &H00, &H20, &H70, &H72, &H08, &HE0, &H00, &H23, &HE0, &H5E,
				&H02, &H9A, &H29, &H21, &HFB, &HF7, &HB0, &HFC, &H01, &HE0, &H03, &H4D,
				&H0B, &H3D, &H28, &H00, &HFE, &HBC, &H08, &HBC, &H18, &H47, &H00, &H00,
				&H31, &H80, &H00, &H00, &H70, &H1E, &H01, &H00, &H40, &H16, &H01, &H00,
				&H50, &H14, &H00, &H00, &HF3, &HB5, &H81, &HB0, &H02, &H99, &H04, &H00,
				&H8E, &H68, &H33, &H49, &H00, &H20, &H65, &H18, &HA3, &H21, &H2A, &H88,
				&H49, &H01, &H67, &H18, &HA9, &H88, &H00, &H2A, &H1D, &HD1, &H00, &H29,
				&H1D, &HD1, &H61, &H69, &H00, &H29, &H1C, &HD1, &HB9, &H7D, &H00, &H29,
				&H1E, &HD1, &H30, &H78, &H00, &H28, &H0C, &HD0, &H20, &H00, &HFC, &HF7,
				&H2F, &HFA, &H20, &H00, &HFC, &HF7, &H34, &HFA, &H00, &H28, &H11, &HD1,
				&H20, &H00, &HFC, &HF7, &H37, &HFA, &H00, &H28, &H0C, &HD1, &H01, &H22,
				&H71, &H1C, &H20, &H00, &HFC, &HF7, &H38, &HFA, &H04, &HE0, &H00, &H29,
				&H01, &HD0, &H08, &H00, &H00, &HE0, &H10, &H00, &H00, &H28, &H01, &HD0,
				&H01, &H21, &HA1, &H70, &H69, &H7A, &H00, &H29, &H00, &HD0, &H1A, &H48,
				&H61, &H69, &H00, &H29, &H01, &HD0, &H18, &H48, &H09, &H30, &H02, &H00,
				&H02, &H98, &H21, &H00, &HFC, &HF7, &H28, &HFA, &H06, &H00, &H12, &HD1,
				&HB8, &H7D, &H00, &H28, &H13, &HD0, &H01, &H28, &H0D, &HD1, &H21, &H20,
				&H80, &H01, &H20, &H18, &H41, &H68, &H01, &H27, &HBA, &H02, &H89, &H18,
				&H8F, &H72, &H41, &H68, &H20, &H00, &HFC, &HF7, &H95, &HF9, &H06, &H00,
				&H6F, &H72, &H30, &H00, &HFE, &HBC, &H08, &HBC, &H18, &H47, &H31, &H20,
				&H80, &H01, &H20, &H18, &H40, &H7B, &H01, &H28, &HF5, &HD1, &H06, &H49,
				&H00, &H23, &H62, &H18, &HE0, &H5E, &H29, &H21, &HFB, &HF7, &H36, &HFC,
				&HED, &HE7, &H00, &H00, &H40, &H16, &H01, &H00, &H4A, &H40, &H00, &H00,
				&H70, &H1E, &H01, &H00, &H38, &HB5, &H2C, &H48, &HFE, &HF7, &H1A, &HFD,
				&H04, &H00, &H03, &HD1, &H01, &H20, &H38, &HBC, &H08, &HBC, &H18, &H47,
				&H28, &H49, &H00, &H20, &H61, &H18, &HA0, &H70, &H08, &H80, &H48, &H80,
				&H88, &H80, &HA3, &H22, &HC8, &H80, &H52, &H01, &H08, &H72, &HA2, &H18,
				&H01, &H23, &HC8, &H72, &H13, &H73, &H50, &H73, &H90, &H73, &HD0, &H73,
				&HC8, &H23, &H10, &H82, &H53, &H82, &H90, &H82, &H29, &H22, &HD2, &H01,
				&HA2, &H18, &HD0, &H62, &H1B, &H4A, &H48, &H72, &H20, &H32, &HA2, &H18,
				&H10, &H70, &H50, &H80, &H88, &H72, &H20, &H00, &HFC, &HF7, &H44, &HFA,
				&H15, &H49, &H02, &H20, &H38, &H39, &H20, &H80, &H04, &H20, &H61, &H18,
				&H88, &H62, &H13, &H48, &HC8, &H38, &H20, &H18, &H05, &H00, &HFC, &HF7,
				&H3F, &HFA, &H00, &H20, &H8B, &H22, &H52, &H02, &H81, &H00, &H09, &H19,
				&H89, &H18, &H40, &H1C, &H0A, &H28, &H8D, &H61, &HF8, &HD3, &H20, &H00,
				&HFB, &HF7, &HA8, &HFD, &H09, &H48, &H00, &H21, &H28, &H38, &H22, &H18,
				&H34, &H30, &H00, &H92, &HC8, &H22, &H20, &H18, &H01, &H23, &HFC, &HF7,
				&H2B, &HFA, &H04, &H48, &H24, &H30, &H20, &H18, &HFC, &HF7, &HE2, &HF9,
				&H00, &H20, &HAC, &HE7, &H78, &H1E, &H01, &H00, &H40, &H16, &H01, &H00,
				&HF8, &HB5, &H04, &H23, &HCF, &H5E, &H05, &H00, &H08, &H00, &H00, &H24,
				&H4C, &H2F, &H12, &HD0, &H16, &HDC, &H25, &H2F, &H29, &HD0, &H08, &HDC,
				&H3B, &H49, &H6E, &H18, &H0E, &H2F, &H33, &HD0, &H12, &H2F, &H28, &HD0,
				&H13, &H2F, &H6B, &HD0, &H68, &HE0, &H27, &H2F, &H03, &HD0, &H2A, &H2F,
				&H01, &HD0, &H2C, &H2F, &H62, &HD1, &H21, &H00, &H00, &HF0, &H02, &HF9,
				&H04, &H00, &H5F, &HE0, &H9A, &H2F, &H4F, &HD0, &H0B, &HDC, &H31, &H49,
				&H5F, &H2F, &H51, &HD0, &H61, &H2F, &H52, &HD0, &H64, &H2F, &H53, &HD1,
				&H0A, &H00, &H29, &H00, &HFC, &HF7, &H06, &HF9, &HEE, &HE7, &H9C, &H2F,
				&H43, &HD0, &H9E, &H2F, &H4A, &HD1, &H2A, &H4C, &H4A, &HE0, &H28, &H4A,
				&H12, &H1F, &H29, &H00, &HFC, &HF7, &H0A, &HF9, &HE2, &HE7, &H80, &H68,
				&H00, &H88, &H00, &H28, &H01, &HD0, &H23, &H4C, &HE4, &H1F, &H04, &H20,
				&H34, &H80, &H15, &HE0, &H80, &H68, &H00, &H88, &H00, &H28, &H01, &HD0,
				&H1E, &H4C, &HA4, &H1F, &HA3, &H20, &H40, &H01, &H28, &H18, &H74, &H80,
				&H80, &H7D, &H00, &H28, &H0A, &HD0, &H01, &H28, &H2C, &HD1, &H1B, &H48,
				&H29, &H18, &H28, &H00, &HFC, &HF7, &HE0, &HF9, &H04, &H00, &H03, &H20,
				&HA8, &H70, &H23, &HE0, &H31, &H7A, &H01, &H20, &H00, &H27, &H00, &H29,
				&H03, &HD0, &H37, &H72, &HF0, &H72, &HAF, &H70, &H03, &HE0, &HA8, &H70,
				&HF0, &H7A, &H00, &H28, &H16, &HD0, &H11, &H49, &H00, &H23, &H6A, &H18,
				&HE8, &H5E, &H63, &H21, &HFB, &HF7, &H60, &HFB, &HF7, &H72, &H0D, &HE0,
				&H0A, &H4C, &H64, &H1E, &H0A, &HE0, &H09, &H4C, &HA4, &H1C, &H07, &HE0,
				&HFC, &HF7, &HEA, &HF8, &HA2, &HE7, &HFC, &HF7, &HEF, &HF8, &H9F, &HE7,
				&H04, &H4C, &H0E, &H3C, &H20, &H00, &HF8, &HBC, &H08, &HBC, &H18, &H47,
				&H40, &H16, &H01, &H00, &H4D, &H40, &H00, &H00, &H2E, &H80, &H00, &H00,
				&H54, &H14, &H00, &H00, &H74, &H1E, &H01, &H00, &HF8, &HB5, &H04, &H23,
				&HCF, &H5E, &H05, &H00, &H08, &H00, &H00, &H24, &H4C, &H2F, &H10, &HD0,
				&H14, &HDC, &H25, &H2F, &H29, &HD0, &H06, &HDC, &H0E, &H2F, &H2F, &HD0,
				&H12, &H2F, &H2A, &HD0, &H13, &H2F, &H70, &HD0, &H6D, &HE0, &H27, &H2F,
				&H03, &HD0, &H2A, &H2F, &H01, &HD0, &H2C, &H2F, &H67, &HD1, &H21, &H00,
				&H00, &HF0, &H76, &HF8, &H04, &H00, &H64, &HE0, &H34, &H49, &H6E, &H18,
				&H9A, &H2F, &H1E, &HD0, &H0B, &HDC, &H33, &H49, &H5F, &H2F, &H54, &HD0,
				&H61, &H2F, &H55, &HD0, &H64, &H2F, &H56, &HD1, &H0A, &H00, &H29, &H00,
				&HFC, &HF7, &H78, &HF8, &HEC, &HE7, &H9C, &H2F, &H2B, &HD0, &H9E, &H2F,
				&H4D, &HD1, &H2C, &H4C, &H4D, &HE0, &H2A, &H4A, &H12, &H1F, &H29, &H00,
				&HFC, &HF7, &H7C, &HF8, &HE0, &HE7, &H28, &H4C, &H0B, &H3C, &H44, &HE0,
				&H26, &H4C, &HE4, &H1E, &H41, &HE0, &H80, &H68, &H22, &H49, &H00, &H90,
				&H00, &H88, &H20, &H31, &H6F, &H18, &H00, &H28, &H06, &HD0, &H20, &H4C,
				&H04, &H20, &HA4, &H1E, &H00, &H21, &HA8, &H70, &H79, &H80, &H0A, &HE0,
				&H1E, &H48, &H29, &H18, &H28, &H00, &HFC, &HF7, &H19, &HF9, &H04, &H00,
				&H02, &H20, &HA8, &H70, &H00, &H98, &H40, &H88, &H78, &H80, &HB4, &H80,
				&H25, &HE0, &H80, &H68, &H00, &H88, &H00, &H28, &H01, &HD0, &H14, &H4C,
				&H64, &H1E, &H31, &H7A, &H01, &H20, &H00, &H29, &H05, &HD0, &H00, &H21,
				&H31, &H72, &HB1, &H72, &HF0, &H72, &HA9, &H70, &H03, &HE0, &HA8, &H70,
				&HF0, &H7A, &H00, &H28, &HE9, &HD0, &H0F, &H49, &H00, &H23, &H6A, &H18,
				&HE8, &H5E, &H63, &H21, &HFB, &HF7, &HCA, &HFA, &H00, &H21, &HF1, &H72,
				&HDF, &HE7, &HFC, &HF7, &H59, &HF8, &H9D, &HE7, &HFC, &HF7, &H5E, &HF8,
				&H9A, &HE7, &H05, &H4C, &H0E, &H3C, &H20, &H00, &HF8, &HBC, &H08, &HBC,
				&H18, &H47, &H00, &H00, &H40, &H16, &H01, &H00, &H4D, &H40, &H00, &H00,
				&H2E, &H80, &H00, &H00, &H50, &H14, &H00, &H00, &H74, &H1E, &H01, &H00,
				&H70, &HB5, &H04, &H00, &H80, &H68, &H0D, &H00, &H00, &H28, &H08, &HD0,
				&HFB, &HF7, &HA4, &HFA, &H04, &H23, &HE1, &H5E, &H08, &H34, &H44, &HCC,
				&H33, &H00, &HFB, &HF7, &HA1, &HFA, &H28, &H00, &H70, &HBC, &H08, &HBC,
				&H18, &H47, &H00, &H00, &HA3, &H22, &H52, &H01, &H82, &H18, &H10, &HB4,
				&H13, &H7B, &HD2, &H7B, &H02, &H2B, &H0B, &HD1, &H00, &H2A, &H05, &HD0,
				&H03, &H2A, &H05, &HD0, &H06, &H2A, &H0C, &HD1, &H11, &H49, &H0A, &HE0,
				&H11, &H49, &H08, &HE0, &H11, &H49, &H06, &HE0, &H00, &H2A, &H08, &HD0,
				&H03, &H2A, &H08, &HD0, &H06, &H2A, &H00, &HD1, &H0E, &H49, &H00, &H22,
				&H8B, &H24, &H64, &H02, &H03, &HE0, &H0D, &H49, &HF9, &HE7, &H0D, &H49,
				&HF7, &HE7, &H93, &H00, &H1B, &H18, &H1B, &H19, &H99, &H61, &H9E, &H31,
				&H52, &H1C, &H09, &H2A, &HF7, &HD3, &H09, &H49, &H41, &H18, &H00, &H19,
				&HC1, &H63, &H10, &HBC, &H70, &H47, &H00, &H00, &H16, &H5D, &HF0, &HBF,
				&H4E, &H73, &HF0, &HBF, &H32, &H68, &HF0, &HBF, &H88, &H57, &HF0, &HBF,
				&HC0, &H6D, &HF0, &HBF, &HA4, &H62, &HF0, &HBF, &H78, &H15, &H01, &H00,
				&HFF, &HB5, &H0E, &H00, &H14, &H00, &H00, &H25, &H83, &HB0, &H1F, &H4F,
				&H02, &H95, &H2D, &HE0, &H01, &H78, &H49, &H00, &H79, &H5A, &H89, &H07,
				&H08, &HD5, &H69, &H46, &HFC, &HF7, &H18, &HF9, &H00, &H28, &H03, &HD0,
				&H68, &H46, &HFC, &HF7, &H1B, &HF9, &H02, &H90, &H31, &H68, &H08, &H78,
				&H42, &H00, &HBA, &H5A, &HD2, &H05, &H13, &HD5, &H14, &H4B, &H00, &H21,
				&H02, &HE0, &H49, &H1C, &H09, &H29, &H03, &HDA, &H8A, &H00, &H9A, &H5C,
				&H82, &H42, &HF8, &HD1, &H88, &H00, &HC2, &H18, &H31, &H00, &H02, &H9B,
				&H20, &H00, &HFC, &HF7, &H0B, &HF9, &H2D, &H18, &H24, &H18, &H05, &HE0,
				&H48, &H1C, &H30, &H60, &H08, &H78, &H20, &H70, &H64, &H1C, &H6D, &H1C,
				&H30, &H00, &H03, &HC8, &H88, &H42, &H02, &HD8, &H03, &H99, &H8D, &H42,
				&HCA, &HDB, &H00, &H20, &H20, &H70, &H28, &H00, &H07, &HB0, &HF0, &HBC,
				&H08, &HBC, &H18, &H47, &H70, &H6F, &H01, &HC0, &H14, &H6D, &H01, &HC0,
				&H03, &H00, &H52, &HE3, &H3D, &H00, &H00, &H9A, &H03, &HC0, &H10, &HE2,
				&H08, &H00, &H00, &H0A, &H01, &H30, &HD1, &HE4, &H02, &H00, &H5C, &HE3,
				&H0C, &H20, &H82, &HE0, &H01, &HC0, &HD1, &H94, &H01, &H30, &HC0, &HE4,
				&H01, &H30, &HD1, &H34, &H04, &H20, &H42, &HE2, &H01, &HC0, &HC0, &H94,
				&H01, &H30, &HC0, &H34, &H03, &H30, &H11, &HE2, &H1D, &H00, &H00, &H0A,
				&H04, &H20, &H52, &HE2, &H2E, &H00, &H00, &H3A, &H03, &HC0, &H31, &HE7,
				&H02, &H00, &H53, &HE3, &H08, &H00, &H00, &H0A, &H0F, &H00, &H00, &H8A,
				&H2C, &H34, &HA0, &HE1, &H04, &HC0, &HB1, &HE5, &H04, &H20, &H52, &HE2,
				&H0C, &H3C, &H83, &HE1, &H04, &H30, &H80, &HE4, &HF9, &HFF, &HFF, &H2A,
				&H01, &H10, &H81, &HE2, &H22, &H00, &H00, &HEA, &H2C, &H38, &HA0, &HE1,
				&H04, &HC0, &HB1, &HE5, &H04, &H20, &H52, &HE2, &H0C, &H38, &H83, &HE1,
				&H04, &H30, &H80, &HE4, &HF9, &HFF, &HFF, &H2A, &H02, &H10, &H81, &HE2,
				&H1A, &H00, &H00, &HEA, &H2C, &H3C, &HA0, &HE1, &H04, &HC0, &HB1, &HE5,
				&H04, &H20, &H52, &HE2, &H0C, &H34, &H83, &HE1, &H04, &H30, &H80, &HE4,
				&HF9, &HFF, &HFF, &H2A, &H03, &H10, &H81, &HE2, &H12, &H00, &H00, &HEA,
				&H10, &H40, &H2D, &HE9, &H20, &H20, &H52, &HE2, &H05, &H00, &H00, &H3A,
				&H18, &H50, &HB1, &H28, &H18, &H50, &HA0, &H28, &H18, &H50, &HB1, &H28,
				&H18, &H50, &HA0, &H28, &H20, &H20, &H52, &H22, &HF9, &HFF, &HFF, &H2A,
				&H02, &HCE, &HB0, &HE1, &H18, &H50, &HB1, &H28, &H18, &H50, &HA0, &H28,
				&H18, &H00, &HB1, &H48, &H18, &H00, &HA0, &H48, &H10, &H40, &HBD, &HE8,
				&H02, &HCF, &HB0, &HE1, &H04, &H30, &H91, &H24, &H04, &H30, &H80, &H24,
				&H1E, &HFF, &H2F, &H01, &H82, &H2F, &HB0, &HE1, &H01, &H20, &HD1, &H44,
				&H01, &H30, &HD1, &H24, &H01, &HC0, &HD1, &H24, &H01, &H20, &HC0, &H44,
				&H01, &H30, &HC0, &H24, &H01, &HC0, &HC0, &H24, &H1E, &HFF, &H2F, &HE1,
				&H00, &H20, &HA0, &HE3, &H04, &H00, &H51, &HE3, &H08, &H00, &H00, &H3A,
				&H03, &HC0, &H10, &HE2, &H0C, &H00, &H00, &H0A, &H04, &HC0, &H6C, &HE2,
				&H02, &H00, &H5C, &HE3, &H01, &H20, &HC0, &HE4, &H01, &H20, &HC0, &HA4,
				&H01, &H20, &HC0, &HC4, &H0C, &H10, &H41, &HE0, &H05, &H00, &H00, &HEA,
				&H81, &HCF, &HB0, &HE1, &H01, &H20, &HC0, &H24, &H01, &H20, &HC0, &H24,
				&H01, &H20, &HC0, &H44, &H1E, &HFF, &H2F, &HE1, &H00, &H20, &HA0, &HE3,
				&H00, &H40, &H2D, &HE9, &H02, &H30, &HA0, &HE1, &H02, &HC0, &HA0, &HE1,
				&H02, &HE0, &HA0, &HE1, &H20, &H10, &H51, &HE2, &H0C, &H50, &HA0, &H28,
				&H0C, &H50, &HA0, &H28, &H20, &H10, &H51, &H22, &HFB, &HFF, &HFF, &H2A,
				&H01, &H1E, &HB0, &HE1, &H0C, &H50, &HA0, &H28, &H0C, &H00, &HA0, &H48,
				&H00, &H40, &HBD, &HE8, &H01, &H11, &HB0, &HE1, &H04, &H20, &H80, &H24,
				&H1E, &HFF, &H2F, &H01, &H01, &H20, &HC0, &H44, &H01, &H20, &HC0, &H44,
				&H40, &H04, &H11, &HE3, &H01, &H20, &HC0, &H14, &H1E, &HFF, &H2F, &HE1,
				&H03, &H00, &H10, &HE3, &H03, &H00, &H11, &H03, &H17, &H00, &H00, &H1A,
				&H00, &H40, &H2D, &HE9, &H50, &HE2, &H9F, &HE5, &H04, &H20, &H90, &HE4,
				&H04, &H30, &H91, &HE4, &H0E, &HC0, &H42, &HE0, &H02, &HC0, &HCC, &HE1,
				&H8E, &HC3, &H1C, &HE0, &H03, &H00, &H52, &H01, &HF8, &HFF, &HFF, &H0A,
				&H00, &H40, &HBD, &HE8, &H03, &H0C, &HA0, &HE1, &H02, &H0C, &H50, &HE0,
				&HFF, &H0E, &H1C, &H03, &H07, &H00, &H00, &H1A, &H03, &H08, &HA0, &HE1,
				&H02, &H08, &H50, &HE0, &HFF, &H0C, &H1C, &H03, &H03, &H00, &H00, &H1A,
				&H03, &H04, &HA0, &HE1, &H02, &H04, &H50, &HE0, &HFF, &H08, &H1C, &H03,
				&H02, &H00, &H53, &H00, &H60, &H00, &HA0, &H11, &H1E, &HFF, &H2F, &HE1,
				&H01, &H20, &HD0, &HE4, &H01, &H30, &HD1, &HE4, &H01, &H00, &H52, &HE3,
				&H03, &H00, &H52, &H21, &H04, &H00, &H00, &H1A, &H01, &H20, &HD0, &HE4,
				&H01, &H30, &HD1, &HE4, &H01, &H00, &H52, &HE3, &H03, &H00, &H52, &H21,
				&HF5, &HFF, &HFF, &H0A, &H03, &H00, &H42, &HE0, &H1E, &HFF, &H2F, &HE1,
				&H01, &H30, &H80, &HE1, &H03, &H00, &H13, &HE3, &H04, &HE0, &H2D, &HE5,
				&H00, &H20, &HA0, &HE1, &H0B, &H00, &H00, &H1A, &HB0, &HC1, &H9F, &HE5,
				&H04, &H30, &H91, &HE4, &H0C, &HE0, &H43, &HE0, &H03, &HE0, &HCE, &HE1,
				&H8C, &H03, &H1E, &HE1, &H04, &H30, &H82, &H04, &HF9, &HFF, &HFF, &H0A,
				&HFF, &H10, &H13, &HE2, &H01, &H10, &HC2, &HE4, &H23, &H34, &HA0, &H11,
				&HFB, &HFF, &HFF, &H1A, &H07, &H00, &H00, &HEA, &H01, &H30, &HD1, &HE4,
				&H01, &H30, &HC2, &HE4, &H00, &H00, &H53, &HE3, &H03, &H00, &H00, &H0A,
				&H01, &H30, &HD1, &HE4, &H01, &H30, &HC2, &HE4, &H00, &H00, &H53, &HE3,
				&HF7, &HFF, &HFF, &H1A, &H00, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1,
				&H01, &HC0, &H80, &HE2, &H03, &H00, &H10, &HE3, &H05, &H00, &H00, &H0A,
				&H01, &H10, &HD0, &HE4, &H00, &H00, &H51, &HE3, &H0C, &H00, &H40, &H00,
				&H1E, &HFF, &H2F, &H01, &H03, &H00, &H10, &HE3, &HF9, &HFF, &HFF, &H1A,
				&H34, &H21, &H9F, &HE5, &H04, &H10, &H90, &HE4, &H02, &H30, &H41, &HE0,
				&H01, &H30, &HC3, &HE1, &H82, &H03, &H13, &HE1, &HFA, &HFF, &HFF, &H0A,
				&H0C, &H00, &H40, &HE0, &HFF, &H00, &H11, &HE3, &H03, &H00, &H40, &H02,
				&H1E, &HFF, &H2F, &H01, &HFF, &H0C, &H11, &HE3, &H02, &H00, &H40, &H02,
				&H1E, &HFF, &H2F, &H01, &HFF, &H08, &H11, &HE3, &H01, &H00, &H40, &H02,
				&H1E, &HFF, &H2F, &HE1, &H01, &H30, &H80, &HE1, &H03, &H00, &H13, &HE3,
				&H04, &HE0, &H2D, &HE5, &H0D, &H00, &H00, &H1A, &HE4, &HC0, &H9F, &HE5,
				&H02, &H00, &H00, &HEA, &H04, &H00, &H80, &HE2, &H04, &H10, &H81, &HE2,
				&H04, &H20, &H42, &HE2, &H04, &H00, &H52, &HE3, &H00, &H30, &H90, &H25,
				&H00, &HE0, &H91, &H25, &H0E, &H00, &H53, &H21, &H03, &H00, &H00, &H1A,
				&H0C, &HE0, &H43, &HE0, &H03, &H30, &HCE, &HE1, &H8C, &H03, &H13, &HE1,
				&HF3, &HFF, &HFF, &H0A, &H00, &H00, &H52, &HE3, &H00, &H00, &HA0, &H03,
				&H07, &H00, &H00, &H0A, &H01, &H30, &HD0, &HE4, &H01, &HC0, &HD1, &HE4,
				&H01, &H00, &H53, &HE3, &H0C, &H00, &H53, &H21, &H01, &H00, &H00, &H1A,
				&H01, &H20, &H52, &HE2, &HF8, &HFF, &HFF, &H1A, &H0C, &H00, &H43, &HE0,
				&H00, &H40, &HBD, &HE8, &H1E, &HFF, &H2F, &HE1, &H04, &H00, &H52, &HE3,
				&H01, &H30, &H80, &H21, &H03, &H00, &H13, &H23, &H09, &H00, &H00, &H1A,
				&H04, &H30, &H90, &HE4, &H04, &HC0, &H91, &HE4, &H0C, &H00, &H53, &HE1,
				&H02, &H00, &H00, &H1A, &H04, &H20, &H42, &HE2, &H04, &H00, &H52, &HE3,
				&HF8, &HFF, &HFF, &H2A, &H0C, &H00, &H53, &HE1, &H04, &H00, &H40, &H12,
				&H04, &H10, &H41, &H12, &H00, &H00, &H52, &HE3, &H00, &H00, &HA0, &H03,
				&H1E, &HFF, &H2F, &H01, &H01, &H00, &H12, &HE3, &H01, &H20, &H82, &H12,
				&H03, &H00, &H00, &H1A, &H01, &H30, &HD0, &HE4, &H01, &HC0, &HD1, &HE4,
				&H0C, &H00, &H53, &HE1, &H05, &H00, &H00, &H1A, &H01, &H30, &HD0, &HE4,
				&H01, &HC0, &HD1, &HE4, &H0C, &H00, &H53, &HE1, &H01, &H00, &H00, &H1A,
				&H02, &H20, &H52, &HE2, &HF5, &HFF, &HFF, &H1A, &H0C, &H00, &H43, &HE0,
				&H1E, &HFF, &H2F, &HE1, &H01, &H01, &H01, &H01, &HBC, &H02, &HF0, &HBF,
				&HB8, &H02, &HF0, &HBF, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &HB4, &H02, &HF0, &HBF, &HB0, &H02, &HF0, &HBF,
				&HB0, &H02, &HF0, &HBF, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H01, &H00, &H00, &H00, &H64, &H00, &H64, &H00,
				&H64, &H00, &H00, &H00, &H19, &H00, &H04, &H00, &H00, &H00, &H64, &H00,
				&HAC, &H0D, &HFA, &H00, &H3C, &H0F, &HE8, &H03, &HAC, &H0D, &H94, &H11,
				&H3C, &H00, &H41, &H00, &H41, &H00, &H57, &H00, &H48, &H00, &H42, &H00,
				&H3D, &H00, &H3C, &H00, &H4F, &H00, &H49, &H00, &H12, &H00, &H00, &H00,
				&H5A, &H00, &H0A, &H00, &H1C, &H00, &H90, &H01, &H14, &H05, &H8C, &H0A,
				&HF4, &H01, &H14, &H00, &H46, &H00, &HF9, &H2A, &HE9, &H03, &H01, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H92, &H02, &H46, &H00, &H6E, &H00,
				&HA0, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01,
				&H0E, &H01, &HC0, &H12, &H58, &H02, &H1E, &H00, &H50, &H00, &HC8, &H00,
				&H20, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H0A, &H00, &H05, &H00,
				&H9C, &H04, &H58, &H02, &H26, &H00, &H9C, &HFF, &H6A, &HFF, &H01, &H00,
				&HC8, &H00, &H64, &H00, &H96, &H00, &HFA, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H68, &H10, &H01, &H00, &H00, &H00, &H64, &H00,
				&H57, &H00, &H50, &H00, &H00, &H00, &H46, &H00, &H14, &H00, &H00, &H00,
				&H6B, &H00, &HAC, &H0D, &H18, &H01, &H74, &H0E, &H90, &H01, &H80, &H0C,
				&H10, &H13, &H41, &H00, &H3A, &H00, &H41, &H00, &H57, &H00, &H44, &H00,
				&H3C, &H00, &H3C, &H00, &H3D, &H00, &H55, &H00, &H0A, &H00, &H05, &H00,
				&H00, &H00, &H5F, &H00, &H0A, &H00, &H16, &H00, &HF4, &H01, &HE8, &H03,
				&HFC, &H08, &HE8, &H03, &H00, &H00, &H5A, &H00, &H33, &H26, &H8A, &H02,
				&H01, &H00, &H02, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H3C, &H00,
				&H6E, &H00, &H6E, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H04, &H01, &H7E, &H13, &HB0, &H04, &H32, &H00, &H50, &H00,
				&H90, &H01, &H20, &H03, &H64, &H00, &H00, &H00, &H00, &H00, &H02, &H00,
				&H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &HC8, &H00, &H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H00, &H00,
				&H64, &H00, &HB4, &H00, &H64, &H00, &H00, &H00, &H14, &H00, &H0A, &H00,
				&H00, &H00, &H64, &H00, &HCC, &H10, &HA0, &H00, &H5C, &H12, &H58, &H02,
				&H68, &H10, &H24, &H13, &H49, &H00, &H41, &H00, &H46, &H00, &H77, &H00,
				&H67, &H00, &H44, &H00, &H29, &H00, &H46, &H00, &H6A, &H00, &H1E, &H00,
				&H0F, &H00, &H32, &H00, &H55, &H00, &H00, &H00, &H23, &H00, &H7C, &H01,
				&H4C, &H04, &HC4, &H09, &H58, &H02, &H14, &H00, &H50, &H00, &HAC, &H71,
				&HD4, &H49, &H01, &H00, &H01, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H50, &H00, &H62, &H00, &H91, &H00, &H2C, &H01, &H58, &H02, &HFA, &H00,
				&H40, &H01, &H04, &H01, &H72, &H01, &H5C, &H12, &H58, &H02, &H14, &H00,
				&H1E, &H00, &HA0, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H03, &H00,
				&H17, &H00, &H05, &H00, &H46, &H05, &H5E, &H01, &H23, &H00, &HB4, &H00,
				&HB4, &H00, &H07, &H00, &HC2, &H01, &H9C, &HFF, &HDC, &H00, &HC2, &H01,
				&H64, &H00, &HCC, &H00, &H5E, &H01, &H28, &H00, &H94, &H11, &H00, &H00,
				&H3C, &H00, &H64, &H00, &HDC, &H00, &H64, &H00, &H00, &H00, &H3C, &H00,
				&H05, &H00, &H00, &H00, &H64, &H00, &H62, &H11, &H04, &H01, &H56, &H13,
				&H58, &H02, &H62, &H11, &H24, &H13, &H40, &H00, &H3B, &H00, &H40, &H00,
				&H57, &H00, &H49, &H00, &H42, &H00, &H2D, &H00, &H3A, &H00, &H53, &H00,
				&H3C, &H00, &H12, &H00, &H32, &H00, &H1E, &H00, &H01, &H00, &H20, &H00,
				&H5E, &H01, &HE8, &H03, &HDC, &H05, &HBC, &H02, &H00, &H00, &H41, &H00,
				&H10, &H72, &H4C, &H04, &H01, &H00, &H06, &H00, &H00, &H00, &H00, &H00,
				&HB6, &H01, &H78, &H00, &H82, &H00, &H8C, &H00, &HE6, &H00, &H54, &H01,
				&HFA, &H00, &HDC, &H00, &HFA, &H00, &HC8, &H00, &HC0, &H12, &HB0, &H04,
				&H14, &H00, &H50, &H00, &H64, &H00, &H84, &H03, &H6E, &H00, &H00, &H00,
				&H01, &H00, &H08, &H00, &H05, &H00, &H00, &H05, &H8A, &H02, &H1E, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &HFA, &H00, &H9C, &HFF, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H2A, &H12,
				&H01, &H00, &H41, &H00, &H64, &H00, &H6E, &H00, &H64, &H00, &H1E, &H00,
				&H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &HF0, &H00,
				&HD8, &H0E, &HB4, &H00, &H04, &H10, &H24, &H13, &H41, &H00, &H34, &H00,
				&H41, &H00, &H57, &H00, &H49, &H00, &H3E, &H00, &H41, &H00, &H3E, &H00,
				&H4D, &H00, &H64, &H00, &H09, &H00, &H46, &H00, &H32, &H00, &H0A, &H00,
				&H16, &H00, &H90, &H01, &HE8, &H03, &HB0, &H04, &HBC, &H02, &H00, &H00,
				&H32, &H00, &H5C, &H2B, &HF4, &H01, &H01, &H00, &H04, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H46, &H00, &H5A, &H00, &H82, &H00, &HB4, &H00,
				&HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12,
				&H58, &H02, &H0A, &H00, &H50, &H00, &H64, &H00, &H20, &H03, &H64, &H00,
				&H00, &H00, &H01, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02,
				&H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H90, &H01, &H64, &H00,
				&H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00,
				&H94, &H11, &H00, &H00, &H32, &H00, &H41, &H00, &H1D, &H01, &H78, &H00,
				&H00, &H00, &H28, &H00, &H0A, &H00, &H00, &H00, &H60, &H00, &H5C, &H12,
				&HF4, &H01, &H70, &H17, &H70, &H17, &H62, &H11, &HC0, &H12, &H41, &H00,
				&H3C, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H49, &H00, &H39, &H00,
				&H3D, &H00, &H40, &H00, &H4B, &H00, &H0A, &H00, &H4B, &H00, &H32, &H00,
				&H14, &H00, &H14, &H00, &H2C, &H01, &HE8, &H03, &H34, &H08, &HBC, &H02,
				&H00, &H00, &H1E, &H00, &H1C, &H25, &H40, &H06, &H01, &H00, &H05, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H5F, &H00, &H82, &H00, &HA0, &H00,
				&HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01,
				&HC0, &H12, &HB0, &H04, &H0A, &H00, &H50, &H00, &H64, &H00, &H20, &H03,
				&H64, &H00, &H00, &H00, &H00, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04,
				&HB6, &H03, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H2C, &H01,
				&H2C, &H01, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01,
				&H00, &H00, &H5C, &H12, &H01, &H00, &H1E, &H00, &H64, &H00, &H6E, &H00,
				&H64, &H00, &H00, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00,
				&HAC, &H0D, &H5E, &H01, &H94, &H11, &HF4, &H01, &H48, &H0D, &HC0, &H12,
				&H41, &H00, &H37, &H00, &H41, &H00, &H57, &H00, &H48, &H00, &H43, &H00,
				&H3E, &H00, &H3D, &H00, &H4D, &H00, &H49, &H00, &H12, &H00, &H00, &H00,
				&H28, &H00, &H12, &H00, &H05, &H00, &H90, &H01, &HE8, &H03, &H34, &H08,
				&HBC, &H02, &H00, &H00, &H50, &H00, &H3F, &H30, &H2F, &H09, &H01, &H00,
				&H03, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H64, &H00, &H78, &H00,
				&H96, &H00, &HB4, &H00, &H5E, &H01, &HFA, &H00, &H40, &H01, &H04, &H01,
				&H0E, &H01, &HC0, &H12, &H58, &H02, &H0A, &H00, &H50, &H00, &H64, &H00,
				&H52, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H01, &H00, &H05, &H00,
				&H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00, &H08, &H00,
				&H64, &H00, &H0A, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H46, &H00, &H64, &H00,
				&HBE, &H00, &H64, &H00, &H0A, &H00, &H28, &H00, &H00, &H00, &H00, &H00,
				&H64, &H00, &HEC, &H0F, &HF0, &H00, &H70, &H17, &H70, &H17, &HC8, &H0F,
				&H70, &H17, &H4B, &H00, &H3C, &H00, &H41, &H00, &H43, &H00, &H57, &H00,
				&H46, &H00, &H32, &H00, &H39, &H00, &H4D, &H00, &H1E, &H00, &H0A, &H00,
				&H3C, &H00, &H2D, &H00, &H05, &H00, &H32, &H00, &HC2, &H01, &HE8, &H03,
				&H08, &H07, &H90, &H01, &H00, &H00, &H49, &H00, &HCE, &H31, &H4C, &H04,
				&H01, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H8C, &H00,
				&HDC, &H00, &HF0, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H04, &H01, &H7E, &H13, &H58, &H02, &H14, &H00, &H50, &H00,
				&H64, &H00, &H8A, &H02, &H78, &H00, &H00, &H00, &H01, &H00, &H05, &H00,
				&H05, &H00, &H9C, &H04, &H8A, &H02, &H2D, &H00, &H00, &H00, &HC2, &H01,
				&H00, &H00, &H12, &H02, &H4B, &H00, &HC8, &H00, &HC2, &H01, &H2C, &H01,
				&H3C, &H00, &HBC, &H02, &H00, &H00, &H50, &H14, &H00, &H00, &H14, &H00,
				&H32, &H00, &HC3, &H00, &H64, &H00, &H0A, &H00, &H14, &H00, &H0A, &H00,
				&H00, &H00, &H64, &H00, &HF8, &H11, &H2C, &H01, &H70, &H17, &H70, &H17,
				&H68, &H10, &HC0, &H12, &H3D, &H00, &H3D, &H00, &H41, &H00, &H57, &H00,
				&H57, &H00, &H49, &H00, &H3B, &H00, &H3C, &H00, &H44, &H00, &H64, &H00,
				&H0A, &H00, &H50, &H00, &H14, &H00, &H12, &H00, &H16, &H00, &HC2, &H01,
				&HE8, &H03, &HC4, &H09, &H84, &H03, &H3C, &H00, &H3C, &H00, &HB4, &H2D,
				&H4C, &H04, &H01, &H00, &H08, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H78, &H00, &H82, &H00, &H8C, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00,
				&HDC, &H00, &HFA, &H00, &HC8, &H00, &HC0, &H12, &HB0, &H04, &H14, &H00,
				&H50, &H00, &H64, &H00, &H84, &H03, &H6E, &H00, &H00, &H00, &H02, &H00,
				&H02, &H00, &H05, &H00, &H46, &H05, &H5E, &H01, &H1E, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H90, &H01, &H64, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00, &HF2, &H12, &H01, &H00,
				&H00, &H00, &H64, &H00, &H64, &H00, &H64, &H00, &H00, &H00, &H19, &H00,
				&H04, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &HFA, &H00, &H3C, &H0F,
				&HE8, &H03, &HAC, &H0D, &H94, &H11, &H3C, &H00, &H41, &H00, &H41, &H00,
				&H57, &H00, &H57, &H00, &H3F, &H00, &H39, &H00, &H39, &H00, &H53, &H00,
				&H49, &H00, &H12, &H00, &H00, &H00, &H5A, &H00, &H0A, &H00, &H1C, &H00,
				&H90, &H01, &H14, &H05, &H8C, &H0A, &HF4, &H01, &H14, &H00, &H46, &H00,
				&HF9, &H2A, &HE9, &H03, &H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H92, &H02, &H46, &H00, &H6E, &H00, &HA0, &H00, &HB4, &H00, &HC8, &H00,
				&HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02,
				&H1E, &H00, &H50, &H00, &HC8, &H00, &H20, &H03, &H64, &H00, &H00, &H00,
				&H01, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04, &H58, &H02, &H26, &H00,
				&H9C, &HFF, &H6A, &HFF, &H01, &H00, &HC8, &H00, &H64, &H00, &H96, &H00,
				&HFA, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H68, &H10,
				&H01, &H00, &H00, &H00, &H64, &H00, &H57, &H00, &H50, &H00, &H00, &H00,
				&H46, &H00, &H14, &H00, &H00, &H00, &H6B, &H00, &HAC, &H0D, &H18, &H01,
				&H74, &H0E, &H90, &H01, &H80, &H0C, &H10, &H13, &H41, &H00, &H3A, &H00,
				&H41, &H00, &H57, &H00, &H3F, &H00, &H38, &H00, &H37, &H00, &H3E, &H00,
				&H57, &H00, &H0A, &H00, &H05, &H00, &H00, &H00, &H5F, &H00, &H0A, &H00,
				&H16, &H00, &HF4, &H01, &HE8, &H03, &HFC, &H08, &HE8, &H03, &H00, &H00,
				&H5A, &H00, &H33, &H26, &H8A, &H02, &H01, &H00, &H02, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H3C, &H00, &H6E, &H00, &H6E, &H00, &HE6, &H00,
				&H54, &H01, &HFA, &H00, &H40, &H01, &H04, &H01, &H04, &H01, &H7E, &H13,
				&HB0, &H04, &H32, &H00, &H50, &H00, &H90, &H01, &H20, &H03, &H64, &H00,
				&H00, &H00, &H00, &H00, &H02, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02,
				&H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &HC8, &H00, &H64, &H00,
				&H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00,
				&H94, &H11, &H00, &H00, &H00, &H00, &H64, &H00, &HB4, &H00, &H64, &H00,
				&H00, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HCC, &H10,
				&HA0, &H00, &H5C, &H12, &H58, &H02, &H68, &H10, &H24, &H13, &H47, &H00,
				&H3F, &H00, &H44, &H00, &H77, &H00, &H76, &H00, &H59, &H00, &H27, &H00,
				&H3F, &H00, &H61, &H00, &H1E, &H00, &H0F, &H00, &H32, &H00, &H55, &H00,
				&H00, &H00, &H23, &H00, &H7C, &H01, &H4C, &H04, &HC4, &H09, &H58, &H02,
				&H14, &H00, &H50, &H00, &HAC, &H71, &HD4, &H49, &H01, &H00, &H01, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H50, &H00, &H62, &H00, &H91, &H00,
				&H2C, &H01, &H58, &H02, &HFA, &H00, &H40, &H01, &H04, &H01, &H72, &H01,
				&H5C, &H12, &H58, &H02, &H14, &H00, &H1E, &H00, &HA0, &H00, &H20, &H03,
				&H64, &H00, &H00, &H00, &H03, &H00, &H17, &H00, &H05, &H00, &H46, &H05,
				&H5E, &H01, &H23, &H00, &HB4, &H00, &HB4, &H00, &H07, &H00, &HC2, &H01,
				&H9C, &HFF, &HDC, &H00, &HC2, &H01, &H64, &H00, &HCC, &H00, &H5E, &H01,
				&H28, &H00, &H94, &H11, &H00, &H00, &H3C, &H00, &H64, &H00, &HDC, &H00,
				&H64, &H00, &H00, &H00, &H3C, &H00, &H05, &H00, &H00, &H00, &H64, &H00,
				&H62, &H11, &H04, &H01, &H56, &H13, &H58, &H02, &H62, &H11, &H24, &H13,
				&H3F, &H00, &H3A, &H00, &H3F, &H00, &H57, &H00, &H57, &H00, &H57, &H00,
				&H2A, &H00, &H31, &H00, &H4F, &H00, &H3C, &H00, &H12, &H00, &H32, &H00,
				&H1E, &H00, &H01, &H00, &H20, &H00, &H5E, &H01, &HE8, &H03, &HDC, &H05,
				&HBC, &H02, &H00, &H00, &H41, &H00, &H10, &H72, &H4C, &H04, &H01, &H00,
				&H06, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H78, &H00, &H82, &H00,
				&H8C, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &HDC, &H00, &HFA, &H00,
				&HC8, &H00, &HC0, &H12, &HB0, &H04, &H14, &H00, &H50, &H00, &H64, &H00,
				&H84, &H03, &H6E, &H00, &H00, &H00, &H01, &H00, &H08, &H00, &H05, &H00,
				&H00, &H05, &H8A, &H02, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&HFA, &H00, &H9C, &HFF, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H2A, &H12, &H01, &H00, &H41, &H00, &H64, &H00,
				&H6E, &H00, &H64, &H00, &H1E, &H00, &H14, &H00, &H0A, &H00, &H00, &H00,
				&H64, &H00, &HAC, &H0D, &HF0, &H00, &HD8, &H0E, &HB4, &H00, &H04, &H10,
				&H24, &H13, &H41, &H00, &H34, &H00, &H41, &H00, &H57, &H00, &H3F, &H00,
				&H33, &H00, &H3E, &H00, &H3D, &H00, &H57, &H00, &H64, &H00, &H09, &H00,
				&H46, &H00, &H32, &H00, &H0A, &H00, &H16, &H00, &H90, &H01, &HE8, &H03,
				&HB0, &H04, &HBC, &H02, &H00, &H00, &H32, &H00, &H5C, &H2B, &HF4, &H01,
				&H01, &H00, &H04, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H46, &H00,
				&H5A, &H00, &H82, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02, &H0A, &H00, &H50, &H00,
				&H64, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H0A, &H00,
				&H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H90, &H01, &H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H32, &H00,
				&H41, &H00, &H1D, &H01, &H78, &H00, &H00, &H00, &H28, &H00, &H0A, &H00,
				&H00, &H00, &H60, &H00, &H5C, &H12, &HF4, &H01, &H70, &H17, &H70, &H17,
				&H62, &H11, &HC0, &H12, &H40, &H00, &H3B, &H00, &H40, &H00, &H55, &H00,
				&H57, &H00, &H57, &H00, &H36, &H00, &H38, &H00, &H42, &H00, &H4B, &H00,
				&H0A, &H00, &H4B, &H00, &H32, &H00, &H14, &H00, &H14, &H00, &H2C, &H01,
				&HE8, &H03, &H34, &H08, &HBC, &H02, &H00, &H00, &H1E, &H00, &H1C, &H25,
				&H40, &H06, &H01, &H00, &H05, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H5F, &H00, &H82, &H00, &HA0, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00,
				&H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &HB0, &H04, &H0A, &H00,
				&H50, &H00, &H64, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H00, &H00,
				&H0A, &H00, &H05, &H00, &H9C, &H04, &HB6, &H03, &H1E, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H2C, &H01, &H2C, &H01, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00, &H5C, &H12, &H01, &H00,
				&H1E, &H00, &H64, &H00, &H6E, &H00, &H64, &H00, &H00, &H00, &H14, &H00,
				&H0A, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &H5E, &H01, &H94, &H11,
				&HF4, &H01, &H48, &H0D, &HC0, &H12, &H41, &H00, &H37, &H00, &H41, &H00,
				&H57, &H00, &H57, &H00, &H40, &H00, &H3A, &H00, &H3A, &H00, &H51, &H00,
				&H49, &H00, &H12, &H00, &H00, &H00, &H28, &H00, &H12, &H00, &H05, &H00,
				&H90, &H01, &HE8, &H03, &H34, &H08, &HBC, &H02, &H00, &H00, &H50, &H00,
				&H3F, &H30, &H2F, &H09, &H01, &H00, &H03, &H00, &H00, &H00, &H00, &H00,
				&HB6, &H01, &H64, &H00, &H78, &H00, &H96, &H00, &HB4, &H00, &H5E, &H01,
				&HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02,
				&H0A, &H00, &H50, &H00, &H64, &H00, &H52, &H03, &H64, &H00, &H00, &H00,
				&H01, &H00, &H01, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00,
				&H00, &H00, &H00, &H00, &H08, &H00, &H64, &H00, &H0A, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H94, &H11,
				&H00, &H00, &H46, &H00, &H64, &H00, &HBE, &H00, &H64, &H00, &H0A, &H00,
				&H28, &H00, &H00, &H00, &H00, &H00, &H64, &H00, &HEC, &H0F, &HF0, &H00,
				&H70, &H17, &H70, &H17, &HC8, &H0F, &H70, &H17, &H4B, &H00, &H3C, &H00,
				&H41, &H00, &H43, &H00, &H57, &H00, &H57, &H00, &H2E, &H00, &H35, &H00,
				&H4B, &H00, &H1E, &H00, &H0A, &H00, &H3C, &H00, &H2D, &H00, &H05, &H00,
				&H32, &H00, &HC2, &H01, &HE8, &H03, &H08, &H07, &H90, &H01, &H00, &H00,
				&H49, &H00, &HCE, &H31, &H4C, &H04, &H01, &H00, &H07, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H8C, &H00, &HDC, &H00, &HF0, &H00, &HE6, &H00,
				&H54, &H01, &HFA, &H00, &H40, &H01, &H04, &H01, &H04, &H01, &H7E, &H13,
				&H58, &H02, &H14, &H00, &H50, &H00, &H64, &H00, &H8A, &H02, &H78, &H00,
				&H00, &H00, &H01, &H00, &H05, &H00, &H05, &H00, &H9C, &H04, &H8A, &H02,
				&H2D, &H00, &H00, &H00, &HC2, &H01, &H00, &H00, &H12, &H02, &H4B, &H00,
				&HC8, &H00, &HC2, &H01, &H2C, &H01, &H3C, &H00, &HBC, &H02, &H00, &H00,
				&H50, &H14, &H00, &H00, &H14, &H00, &H32, &H00, &HC3, &H00, &H64, &H00,
				&H0A, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HF8, &H11,
				&H2C, &H01, &H70, &H17, &H70, &H17, &H68, &H10, &HC0, &H12, &H3D, &H00,
				&H3D, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H57, &H00, &H37, &H00,
				&H37, &H00, &H45, &H00, &H64, &H00, &H0A, &H00, &H50, &H00, &H14, &H00,
				&H12, &H00, &H16, &H00, &HC2, &H01, &HE8, &H03, &HC4, &H09, &H84, &H03,
				&H3C, &H00, &H3C, &H00, &HB4, &H2D, &H4C, &H04, &H01, &H00, &H08, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H78, &H00, &H82, &H00, &H8C, &H00,
				&HE6, &H00, &H54, &H01, &HFA, &H00, &HDC, &H00, &HFA, &H00, &HC8, &H00,
				&HC0, &H12, &HB0, &H04, &H14, &H00, &H50, &H00, &H64, &H00, &H84, &H03,
				&H6E, &H00, &H00, &H00, &H02, &H00, &H02, &H00, &H05, &H00, &H46, &H05,
				&H5E, &H01, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H90, &H01,
				&H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01,
				&H00, &H00, &HF2, &H12, &H01, &H00, &H00, &H00, &H64, &H00, &H64, &H00,
				&H64, &H00, &H00, &H00, &H19, &H00, &H04, &H00, &H00, &H00, &H64, &H00,
				&HAC, &H0D, &HFA, &H00, &H3C, &H0F, &HE8, &H03, &HAC, &H0D, &H94, &H11,
				&H3C, &H00, &H41, &H00, &H41, &H00, &H57, &H00, &H48, &H00, &H42, &H00,
				&H3D, &H00, &H3C, &H00, &H4F, &H00, &H49, &H00, &H12, &H00, &H00, &H00,
				&H5A, &H00, &H0A, &H00, &H1C, &H00, &H90, &H01, &H14, &H05, &H8C, &H0A,
				&HF4, &H01, &H14, &H00, &H46, &H00, &HF9, &H2A, &HE9, &H03, &H01, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H92, &H02, &H46, &H00, &H6E, &H00,
				&HA0, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01,
				&H0E, &H01, &HC0, &H12, &H58, &H02, &H1E, &H00, &H50, &H00, &HC8, &H00,
				&H20, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H0A, &H00, &H05, &H00,
				&H9C, &H04, &H58, &H02, &H26, &H00, &H9C, &HFF, &H6A, &HFF, &H01, &H00,
				&HC8, &H00, &H64, &H00, &H96, &H00, &HFA, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H68, &H10, &H01, &H00, &H00, &H00, &H64, &H00,
				&H57, &H00, &H50, &H00, &H00, &H00, &H46, &H00, &H14, &H00, &H00, &H00,
				&H6B, &H00, &HAC, &H0D, &H18, &H01, &H74, &H0E, &H90, &H01, &H80, &H0C,
				&H10, &H13, &H41, &H00, &H3A, &H00, &H41, &H00, &H57, &H00, &H44, &H00,
				&H3B, &H00, &H3C, &H00, &H3F, &H00, &H54, &H00, &H0A, &H00, &H05, &H00,
				&H00, &H00, &H5F, &H00, &H0A, &H00, &H16, &H00, &HF4, &H01, &HE8, &H03,
				&HFC, &H08, &HE8, &H03, &H00, &H00, &H5A, &H00, &H33, &H26, &H8A, &H02,
				&H01, &H00, &H02, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H3C, &H00,
				&H6E, &H00, &H6E, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H04, &H01, &H7E, &H13, &HB0, &H04, &H32, &H00, &H50, &H00,
				&H90, &H01, &H20, &H03, &H64, &H00, &H00, &H00, &H00, &H00, &H02, &H00,
				&H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &HC8, &H00, &H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H00, &H00,
				&H64, &H00, &HB4, &H00, &H64, &H00, &H00, &H00, &H14, &H00, &H0A, &H00,
				&H00, &H00, &H64, &H00, &HCC, &H10, &HA0, &H00, &H5C, &H12, &H58, &H02,
				&H68, &H10, &H24, &H13, &H49, &H00, &H41, &H00, &H46, &H00, &H77, &H00,
				&H67, &H00, &H43, &H00, &H29, &H00, &H47, &H00, &H6A, &H00, &H1E, &H00,
				&H0F, &H00, &H32, &H00, &H55, &H00, &H00, &H00, &H23, &H00, &H7C, &H01,
				&H4C, &H04, &HC4, &H09, &H58, &H02, &H14, &H00, &H50, &H00, &HAC, &H71,
				&HD4, &H49, &H01, &H00, &H01, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H50, &H00, &H62, &H00, &H91, &H00, &H2C, &H01, &H58, &H02, &HFA, &H00,
				&H40, &H01, &H04, &H01, &H72, &H01, &H5C, &H12, &H58, &H02, &H14, &H00,
				&H1E, &H00, &HA0, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H03, &H00,
				&H17, &H00, &H05, &H00, &H46, &H05, &H5E, &H01, &H23, &H00, &HB4, &H00,
				&HB4, &H00, &H07, &H00, &HC2, &H01, &H9C, &HFF, &HDC, &H00, &HC2, &H01,
				&H64, &H00, &HCC, &H00, &H5E, &H01, &H28, &H00, &H94, &H11, &H00, &H00,
				&H3C, &H00, &H64, &H00, &HDC, &H00, &H64, &H00, &H00, &H00, &H3C, &H00,
				&H05, &H00, &H00, &H00, &H64, &H00, &H62, &H11, &H04, &H01, &H56, &H13,
				&H58, &H02, &H62, &H11, &H24, &H13, &H41, &H00, &H3C, &H00, &H41, &H00,
				&H57, &H00, &H49, &H00, &H42, &H00, &H2D, &H00, &H39, &H00, &H52, &H00,
				&H3C, &H00, &H12, &H00, &H32, &H00, &H1E, &H00, &H01, &H00, &H20, &H00,
				&H5E, &H01, &HE8, &H03, &HDC, &H05, &HBC, &H02, &H00, &H00, &H41, &H00,
				&H10, &H72, &H4C, &H04, &H01, &H00, &H06, &H00, &H00, &H00, &H00, &H00,
				&HB6, &H01, &H78, &H00, &H82, &H00, &H8C, &H00, &HE6, &H00, &H54, &H01,
				&HFA, &H00, &HDC, &H00, &HFA, &H00, &HC8, &H00, &HC0, &H12, &HB0, &H04,
				&H14, &H00, &H50, &H00, &H64, &H00, &H84, &H03, &H6E, &H00, &H00, &H00,
				&H01, &H00, &H08, &H00, &H05, &H00, &H00, &H05, &H8A, &H02, &H1E, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &HFA, &H00, &H9C, &HFF, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H2A, &H12,
				&H01, &H00, &H41, &H00, &H64, &H00, &H6E, &H00, &H64, &H00, &H1E, &H00,
				&H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &HF0, &H00,
				&HD8, &H0E, &HB4, &H00, &H04, &H10, &H24, &H13, &H41, &H00, &H34, &H00,
				&H41, &H00, &H57, &H00, &H49, &H00, &H3F, &H00, &H40, &H00, &H3E, &H00,
				&H4C, &H00, &H64, &H00, &H09, &H00, &H46, &H00, &H32, &H00, &H0A, &H00,
				&H16, &H00, &H90, &H01, &HE8, &H03, &HB0, &H04, &HBC, &H02, &H00, &H00,
				&H32, &H00, &H5C, &H2B, &HF4, &H01, &H01, &H00, &H04, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H46, &H00, &H5A, &H00, &H82, &H00, &HB4, &H00,
				&HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12,
				&H58, &H02, &H0A, &H00, &H50, &H00, &H64, &H00, &H20, &H03, &H64, &H00,
				&H00, &H00, &H01, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02,
				&H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H90, &H01, &H64, &H00,
				&H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00,
				&H94, &H11, &H00, &H00, &H32, &H00, &H41, &H00, &H1D, &H01, &H78, &H00,
				&H00, &H00, &H28, &H00, &H0A, &H00, &H00, &H00, &H60, &H00, &H5C, &H12,
				&HF4, &H01, &H70, &H17, &H70, &H17, &H62, &H11, &HC0, &H12, &H41, &H00,
				&H3C, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H48, &H00, &H3A, &H00,
				&H3C, &H00, &H41, &H00, &H4B, &H00, &H0A, &H00, &H4B, &H00, &H32, &H00,
				&H14, &H00, &H14, &H00, &H2C, &H01, &HE8, &H03, &H34, &H08, &HBC, &H02,
				&H00, &H00, &H1E, &H00, &H1C, &H25, &H40, &H06, &H01, &H00, &H05, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H5F, &H00, &H82, &H00, &HA0, &H00,
				&HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01,
				&HC0, &H12, &HB0, &H04, &H0A, &H00, &H50, &H00, &H64, &H00, &H20, &H03,
				&H64, &H00, &H00, &H00, &H00, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04,
				&HB6, &H03, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H2C, &H01,
				&H2C, &H01, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01,
				&H00, &H00, &H5C, &H12, &H01, &H00, &H1E, &H00, &H64, &H00, &H6E, &H00,
				&H64, &H00, &H00, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00,
				&HAC, &H0D, &H5E, &H01, &H94, &H11, &HF4, &H01, &H48, &H0D, &HC0, &H12,
				&H41, &H00, &H37, &H00, &H41, &H00, &H57, &H00, &H48, &H00, &H43, &H00,
				&H3E, &H00, &H3C, &H00, &H4E, &H00, &H49, &H00, &H12, &H00, &H00, &H00,
				&H28, &H00, &H12, &H00, &H05, &H00, &H90, &H01, &HE8, &H03, &H34, &H08,
				&HBC, &H02, &H00, &H00, &H50, &H00, &H3F, &H30, &H2F, &H09, &H01, &H00,
				&H03, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H64, &H00, &H78, &H00,
				&H96, &H00, &HB4, &H00, &H5E, &H01, &HFA, &H00, &H40, &H01, &H04, &H01,
				&H0E, &H01, &HC0, &H12, &H58, &H02, &H0A, &H00, &H50, &H00, &H64, &H00,
				&H52, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H01, &H00, &H05, &H00,
				&H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00, &H08, &H00,
				&H64, &H00, &H0A, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H46, &H00, &H64, &H00,
				&HBE, &H00, &H64, &H00, &H0A, &H00, &H28, &H00, &H00, &H00, &H00, &H00,
				&H64, &H00, &HEC, &H0F, &HF0, &H00, &H70, &H17, &H70, &H17, &HC8, &H0F,
				&H70, &H17, &H4B, &H00, &H3C, &H00, &H41, &H00, &H43, &H00, &H57, &H00,
				&H47, &H00, &H32, &H00, &H39, &H00, &H4B, &H00, &H1E, &H00, &H0A, &H00,
				&H3C, &H00, &H2D, &H00, &H05, &H00, &H32, &H00, &HC2, &H01, &HE8, &H03,
				&H08, &H07, &H90, &H01, &H00, &H00, &H49, &H00, &HCE, &H31, &H4C, &H04,
				&H01, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H8C, &H00,
				&HDC, &H00, &HF0, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H04, &H01, &H7E, &H13, &H58, &H02, &H14, &H00, &H50, &H00,
				&H64, &H00, &H8A, &H02, &H78, &H00, &H00, &H00, &H01, &H00, &H05, &H00,
				&H05, &H00, &H9C, &H04, &H8A, &H02, &H2D, &H00, &H00, &H00, &HC2, &H01,
				&H00, &H00, &H12, &H02, &H4B, &H00, &HC8, &H00, &HC2, &H01, &H2C, &H01,
				&H3C, &H00, &HBC, &H02, &H00, &H00, &H50, &H14, &H00, &H00, &H14, &H00,
				&H32, &H00, &HC3, &H00, &H64, &H00, &H0A, &H00, &H14, &H00, &H0A, &H00,
				&H00, &H00, &H64, &H00, &HF8, &H11, &H2C, &H01, &H70, &H17, &H70, &H17,
				&H68, &H10, &HC0, &H12, &H3D, &H00, &H3D, &H00, &H41, &H00, &H57, &H00,
				&H57, &H00, &H48, &H00, &H3C, &H00, &H3B, &H00, &H44, &H00, &H64, &H00,
				&H0A, &H00, &H50, &H00, &H14, &H00, &H12, &H00, &H16, &H00, &HC2, &H01,
				&HE8, &H03, &HC4, &H09, &H84, &H03, &H3C, &H00, &H3C, &H00, &HB4, &H2D,
				&H4C, &H04, &H01, &H00, &H08, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H78, &H00, &H82, &H00, &H8C, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00,
				&HDC, &H00, &HFA, &H00, &HC8, &H00, &HC0, &H12, &HB0, &H04, &H14, &H00,
				&H50, &H00, &H64, &H00, &H84, &H03, &H6E, &H00, &H00, &H00, &H02, &H00,
				&H02, &H00, &H05, &H00, &H46, &H05, &H5E, &H01, &H1E, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H90, &H01, &H64, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00, &HF2, &H12, &H01, &H00,
				&H00, &H00, &H64, &H00, &H64, &H00, &H64, &H00, &H00, &H00, &H19, &H00,
				&H04, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &HFA, &H00, &H3C, &H0F,
				&HE8, &H03, &HAC, &H0D, &H94, &H11, &H3C, &H00, &H41, &H00, &H41, &H00,
				&H57, &H00, &H57, &H00, &H3F, &H00, &H39, &H00, &H3A, &H00, &H51, &H00,
				&H49, &H00, &H12, &H00, &H00, &H00, &H5A, &H00, &H0A, &H00, &H1C, &H00,
				&H90, &H01, &H14, &H05, &H8C, &H0A, &HF4, &H01, &H14, &H00, &H46, &H00,
				&HF9, &H2A, &HE9, &H03, &H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H92, &H02, &H46, &H00, &H6E, &H00, &HA0, &H00, &HB4, &H00, &HC8, &H00,
				&HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02,
				&H1E, &H00, &H50, &H00, &HC8, &H00, &H20, &H03, &H64, &H00, &H00, &H00,
				&H01, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04, &H58, &H02, &H26, &H00,
				&H9C, &HFF, &H6A, &HFF, &H01, &H00, &HC8, &H00, &H64, &H00, &H96, &H00,
				&HFA, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H68, &H10,
				&H01, &H00, &H00, &H00, &H64, &H00, &H57, &H00, &H50, &H00, &H00, &H00,
				&H46, &H00, &H14, &H00, &H00, &H00, &H6B, &H00, &HAC, &H0D, &H18, &H01,
				&H74, &H0E, &H90, &H01, &H80, &H0C, &H10, &H13, &H41, &H00, &H3A, &H00,
				&H41, &H00, &H57, &H00, &H3F, &H00, &H38, &H00, &H37, &H00, &H3D, &H00,
				&H57, &H00, &H0A, &H00, &H05, &H00, &H00, &H00, &H5F, &H00, &H0A, &H00,
				&H16, &H00, &HF4, &H01, &HE8, &H03, &HFC, &H08, &HE8, &H03, &H00, &H00,
				&H5A, &H00, &H33, &H26, &H8A, &H02, &H01, &H00, &H02, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H3C, &H00, &H6E, &H00, &H6E, &H00, &HE6, &H00,
				&H54, &H01, &HFA, &H00, &H40, &H01, &H04, &H01, &H04, &H01, &H7E, &H13,
				&HB0, &H04, &H32, &H00, &H50, &H00, &H90, &H01, &H20, &H03, &H64, &H00,
				&H00, &H00, &H00, &H00, &H02, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02,
				&H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &HC8, &H00, &H64, &H00,
				&H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00,
				&H94, &H11, &H00, &H00, &H00, &H00, &H64, &H00, &HB4, &H00, &H64, &H00,
				&H00, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HCC, &H10,
				&HA0, &H00, &H5C, &H12, &H58, &H02, &H68, &H10, &H24, &H13, &H47, &H00,
				&H3F, &H00, &H44, &H00, &H77, &H00, &H76, &H00, &H59, &H00, &H27, &H00,
				&H3F, &H00, &H61, &H00, &H1E, &H00, &H0F, &H00, &H32, &H00, &H55, &H00,
				&H00, &H00, &H23, &H00, &H7C, &H01, &H4C, &H04, &HC4, &H09, &H58, &H02,
				&H14, &H00, &H50, &H00, &HAC, &H71, &HD4, &H49, &H01, &H00, &H01, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H50, &H00, &H62, &H00, &H91, &H00,
				&H2C, &H01, &H58, &H02, &HFA, &H00, &H40, &H01, &H04, &H01, &H72, &H01,
				&H5C, &H12, &H58, &H02, &H14, &H00, &H1E, &H00, &HA0, &H00, &H20, &H03,
				&H64, &H00, &H00, &H00, &H03, &H00, &H17, &H00, &H05, &H00, &H46, &H05,
				&H5E, &H01, &H23, &H00, &HB4, &H00, &HB4, &H00, &H07, &H00, &HC2, &H01,
				&H9C, &HFF, &HDC, &H00, &HC2, &H01, &H64, &H00, &HCC, &H00, &H5E, &H01,
				&H28, &H00, &H94, &H11, &H00, &H00, &H3C, &H00, &H64, &H00, &HDC, &H00,
				&H64, &H00, &H00, &H00, &H3C, &H00, &H05, &H00, &H00, &H00, &H64, &H00,
				&H62, &H11, &H04, &H01, &H56, &H13, &H58, &H02, &H62, &H11, &H24, &H13,
				&H40, &H00, &H3B, &H00, &H40, &H00, &H4C, &H00, &H57, &H00, &H57, &H00,
				&H29, &H00, &H30, &H00, &H4F, &H00, &H3C, &H00, &H12, &H00, &H32, &H00,
				&H1E, &H00, &H01, &H00, &H20, &H00, &H5E, &H01, &HE8, &H03, &HDC, &H05,
				&HBC, &H02, &H00, &H00, &H41, &H00, &H10, &H72, &H4C, &H04, &H01, &H00,
				&H06, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H78, &H00, &H82, &H00,
				&H8C, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &HDC, &H00, &HFA, &H00,
				&HC8, &H00, &HC0, &H12, &HB0, &H04, &H14, &H00, &H50, &H00, &H64, &H00,
				&H84, &H03, &H6E, &H00, &H00, &H00, &H01, &H00, &H08, &H00, &H05, &H00,
				&H00, &H05, &H8A, &H02, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&HFA, &H00, &H9C, &HFF, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H2A, &H12, &H01, &H00, &H41, &H00, &H64, &H00,
				&H6E, &H00, &H64, &H00, &H1E, &H00, &H14, &H00, &H0A, &H00, &H00, &H00,
				&H64, &H00, &HAC, &H0D, &HF0, &H00, &HD8, &H0E, &HB4, &H00, &H04, &H10,
				&H24, &H13, &H41, &H00, &H34, &H00, &H41, &H00, &H57, &H00, &H3F, &H00,
				&H33, &H00, &H3E, &H00, &H3D, &H00, &H57, &H00, &H64, &H00, &H09, &H00,
				&H46, &H00, &H32, &H00, &H0A, &H00, &H16, &H00, &H90, &H01, &HE8, &H03,
				&HB0, &H04, &HBC, &H02, &H00, &H00, &H32, &H00, &H5C, &H2B, &HF4, &H01,
				&H01, &H00, &H04, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H46, &H00,
				&H5A, &H00, &H82, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02, &H0A, &H00, &H50, &H00,
				&H64, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H0A, &H00,
				&H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H90, &H01, &H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H32, &H00,
				&H41, &H00, &H1D, &H01, &H78, &H00, &H00, &H00, &H28, &H00, &H0A, &H00,
				&H00, &H00, &H60, &H00, &H5C, &H12, &HF4, &H01, &H70, &H17, &H70, &H17,
				&H62, &H11, &HC0, &H12, &H40, &H00, &H3B, &H00, &H40, &H00, &H57, &H00,
				&H57, &H00, &H57, &H00, &H36, &H00, &H38, &H00, &H42, &H00, &H4B, &H00,
				&H0A, &H00, &H4B, &H00, &H32, &H00, &H14, &H00, &H14, &H00, &H2C, &H01,
				&HE8, &H03, &H34, &H08, &HBC, &H02, &H00, &H00, &H1E, &H00, &H1C, &H25,
				&H40, &H06, &H01, &H00, &H05, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H5F, &H00, &H82, &H00, &HA0, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00,
				&H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &HB0, &H04, &H0A, &H00,
				&H50, &H00, &H64, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H00, &H00,
				&H0A, &H00, &H05, &H00, &H9C, &H04, &HB6, &H03, &H1E, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H2C, &H01, &H2C, &H01, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00, &H5C, &H12, &H01, &H00,
				&H1E, &H00, &H64, &H00, &H6E, &H00, &H64, &H00, &H00, &H00, &H14, &H00,
				&H0A, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &H5E, &H01, &H94, &H11,
				&HF4, &H01, &H48, &H0D, &HC0, &H12, &H41, &H00, &H37, &H00, &H41, &H00,
				&H57, &H00, &H57, &H00, &H40, &H00, &H3A, &H00, &H3A, &H00, &H51, &H00,
				&H49, &H00, &H12, &H00, &H00, &H00, &H28, &H00, &H12, &H00, &H05, &H00,
				&H90, &H01, &HE8, &H03, &H34, &H08, &HBC, &H02, &H00, &H00, &H50, &H00,
				&H3F, &H30, &H2F, &H09, &H01, &H00, &H03, &H00, &H00, &H00, &H00, &H00,
				&HB6, &H01, &H64, &H00, &H78, &H00, &H96, &H00, &HB4, &H00, &H5E, &H01,
				&HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02,
				&H0A, &H00, &H50, &H00, &H64, &H00, &H52, &H03, &H64, &H00, &H00, &H00,
				&H01, &H00, &H01, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00,
				&H00, &H00, &H00, &H00, &H08, &H00, &H64, &H00, &H0A, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H94, &H11,
				&H00, &H00, &H46, &H00, &H64, &H00, &HBE, &H00, &H64, &H00, &H0A, &H00,
				&H28, &H00, &H00, &H00, &H00, &H00, &H64, &H00, &HEC, &H0F, &HF0, &H00,
				&H70, &H17, &H70, &H17, &HC8, &H0F, &H70, &H17, &H4B, &H00, &H3C, &H00,
				&H41, &H00, &H43, &H00, &H57, &H00, &H57, &H00, &H2E, &H00, &H35, &H00,
				&H4A, &H00, &H1E, &H00, &H0A, &H00, &H3C, &H00, &H2D, &H00, &H05, &H00,
				&H32, &H00, &HC2, &H01, &HE8, &H03, &H08, &H07, &H90, &H01, &H00, &H00,
				&H49, &H00, &HCE, &H31, &H4C, &H04, &H01, &H00, &H07, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H8C, &H00, &HDC, &H00, &HF0, &H00, &HE6, &H00,
				&H54, &H01, &HFA, &H00, &H40, &H01, &H04, &H01, &H04, &H01, &H7E, &H13,
				&H58, &H02, &H14, &H00, &H50, &H00, &H64, &H00, &H8A, &H02, &H78, &H00,
				&H00, &H00, &H01, &H00, &H05, &H00, &H05, &H00, &H9C, &H04, &H8A, &H02,
				&H2D, &H00, &H00, &H00, &HC2, &H01, &H00, &H00, &H12, &H02, &H4B, &H00,
				&HC8, &H00, &HC2, &H01, &H2C, &H01, &H3C, &H00, &HBC, &H02, &H00, &H00,
				&H50, &H14, &H00, &H00, &H14, &H00, &H32, &H00, &HC3, &H00, &H64, &H00,
				&H0A, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HF8, &H11,
				&H2C, &H01, &H70, &H17, &H70, &H17, &H68, &H10, &HC0, &H12, &H3D, &H00,
				&H3D, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H57, &H00, &H38, &H00,
				&H36, &H00, &H44, &H00, &H64, &H00, &H0A, &H00, &H50, &H00, &H14, &H00,
				&H12, &H00, &H16, &H00, &HC2, &H01, &HE8, &H03, &HC4, &H09, &H84, &H03,
				&H3C, &H00, &H3C, &H00, &HB4, &H2D, &H4C, &H04, &H01, &H00, &H08, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H78, &H00, &H82, &H00, &H8C, &H00,
				&HE6, &H00, &H54, &H01, &HFA, &H00, &HDC, &H00, &HFA, &H00, &HC8, &H00,
				&HC0, &H12, &HB0, &H04, &H14, &H00, &H50, &H00, &H64, &H00, &H84, &H03,
				&H6E, &H00, &H00, &H00, &H02, &H00, &H02, &H00, &H05, &H00, &H46, &H05,
				&H5E, &H01, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H90, &H01,
				&H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01,
				&H00, &H00, &HF2, &H12, &H01, &H00, &H00, &H00, &H64, &H00, &H64, &H00,
				&H64, &H00, &H00, &H00, &H19, &H00, &H04, &H00, &H00, &H00, &H64, &H00,
				&HAC, &H0D, &HFA, &H00, &H3C, &H0F, &HE8, &H03, &HAC, &H0D, &H94, &H11,
				&H39, &H00, &H3E, &H00, &H3E, &H00, &H57, &H00, &H45, &H00, &H42, &H00,
				&H3E, &H00, &H3D, &H00, &H50, &H00, &H49, &H00, &H12, &H00, &H00, &H00,
				&H5A, &H00, &H0A, &H00, &H1C, &H00, &H90, &H01, &H14, &H05, &H8C, &H0A,
				&HF4, &H01, &H14, &H00, &H46, &H00, &HF9, &H2A, &HE9, &H03, &H01, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &H92, &H02, &H46, &H00, &H6E, &H00,
				&HA0, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01,
				&H0E, &H01, &HC0, &H12, &H58, &H02, &H1E, &H00, &H50, &H00, &HC8, &H00,
				&H20, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H0A, &H00, &H05, &H00,
				&H9C, &H04, &H58, &H02, &H26, &H00, &H9C, &HFF, &H6A, &HFF, &H01, &H00,
				&HC8, &H00, &H64, &H00, &H96, &H00, &HFA, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H68, &H10, &H01, &H00, &H00, &H00, &H64, &H00,
				&H57, &H00, &H50, &H00, &H00, &H00, &H46, &H00, &H14, &H00, &H00, &H00,
				&H6B, &H00, &HAC, &H0D, &H18, &H01, &H74, &H0E, &H90, &H01, &H80, &H0C,
				&H10, &H13, &H41, &H00, &H3A, &H00, &H41, &H00, &H57, &H00, &H40, &H00,
				&H42, &H00, &H3F, &H00, &H3F, &H00, &H53, &H00, &H0A, &H00, &H05, &H00,
				&H00, &H00, &H5F, &H00, &H0A, &H00, &H16, &H00, &HF4, &H01, &HE8, &H03,
				&HFC, &H08, &HE8, &H03, &H00, &H00, &H5A, &H00, &H33, &H26, &H8A, &H02,
				&H01, &H00, &H02, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H3C, &H00,
				&H6E, &H00, &H6E, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H04, &H01, &H7E, &H13, &HB0, &H04, &H32, &H00, &H50, &H00,
				&H90, &H01, &H20, &H03, &H64, &H00, &H00, &H00, &H00, &H00, &H02, &H00,
				&H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &HC8, &H00, &H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H00, &H00,
				&H64, &H00, &HB4, &H00, &H64, &H00, &H00, &H00, &H14, &H00, &H0A, &H00,
				&H00, &H00, &H64, &H00, &HCC, &H10, &HA0, &H00, &H5C, &H12, &H58, &H02,
				&H68, &H10, &H24, &H13, &H41, &H00, &H39, &H00, &H3E, &H00, &H57, &H00,
				&H46, &H00, &H3D, &H00, &H46, &H00, &H3E, &H00, &H52, &H00, &H1E, &H00,
				&H0F, &H00, &H32, &H00, &H55, &H00, &H00, &H00, &H23, &H00, &H7C, &H01,
				&H4C, &H04, &HC4, &H09, &H58, &H02, &H14, &H00, &H50, &H00, &HAC, &H71,
				&HD4, &H49, &H01, &H00, &H01, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H50, &H00, &H62, &H00, &H91, &H00, &H2C, &H01, &H58, &H02, &HFA, &H00,
				&H40, &H01, &H04, &H01, &H72, &H01, &H5C, &H12, &H58, &H02, &H14, &H00,
				&H1E, &H00, &HA0, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H03, &H00,
				&H17, &H00, &H05, &H00, &H46, &H05, &H5E, &H01, &H23, &H00, &HB4, &H00,
				&HB4, &H00, &H07, &H00, &HC2, &H01, &H9C, &HFF, &HDC, &H00, &HC2, &H01,
				&H64, &H00, &HCC, &H00, &H5E, &H01, &H28, &H00, &H94, &H11, &H00, &H00,
				&H3C, &H00, &H64, &H00, &HDC, &H00, &H64, &H00, &H00, &H00, &H3C, &H00,
				&H05, &H00, &H00, &H00, &H64, &H00, &H62, &H11, &H04, &H01, &H56, &H13,
				&H58, &H02, &H62, &H11, &H24, &H13, &H41, &H00, &H3C, &H00, &H41, &H00,
				&H57, &H00, &H44, &H00, &H40, &H00, &H42, &H00, &H3F, &H00, &H51, &H00,
				&H3C, &H00, &H12, &H00, &H32, &H00, &H1E, &H00, &H01, &H00, &H20, &H00,
				&H5E, &H01, &HE8, &H03, &HDC, &H05, &HBC, &H02, &H00, &H00, &H41, &H00,
				&H10, &H72, &H4C, &H04, &H01, &H00, &H06, &H00, &H00, &H00, &H00, &H00,
				&HB6, &H01, &H78, &H00, &H82, &H00, &H8C, &H00, &HE6, &H00, &H54, &H01,
				&HFA, &H00, &HDC, &H00, &HFA, &H00, &HC8, &H00, &HC0, &H12, &HB0, &H04,
				&H14, &H00, &H50, &H00, &H64, &H00, &H84, &H03, &H6E, &H00, &H00, &H00,
				&H01, &H00, &H08, &H00, &H05, &H00, &H00, &H05, &H8A, &H02, &H1E, &H00,
				&H00, &H00, &H00, &H00, &H00, &H00, &HFA, &H00, &H9C, &HFF, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H2A, &H12,
				&H01, &H00, &H41, &H00, &H64, &H00, &H6E, &H00, &H64, &H00, &H1E, &H00,
				&H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &HF0, &H00,
				&HD8, &H0E, &HB4, &H00, &H04, &H10, &H24, &H13, &H41, &H00, &H34, &H00,
				&H41, &H00, &H57, &H00, &H49, &H00, &H40, &H00, &H42, &H00, &H3D, &H00,
				&H4B, &H00, &H64, &H00, &H09, &H00, &H46, &H00, &H32, &H00, &H0A, &H00,
				&H16, &H00, &H90, &H01, &HE8, &H03, &HB0, &H04, &HBC, &H02, &H00, &H00,
				&H32, &H00, &H5C, &H2B, &HF4, &H01, &H01, &H00, &H04, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H46, &H00, &H5A, &H00, &H82, &H00, &HB4, &H00,
				&HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12,
				&H58, &H02, &H0A, &H00, &H50, &H00, &H64, &H00, &H20, &H03, &H64, &H00,
				&H00, &H00, &H01, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02,
				&H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H90, &H01, &H64, &H00,
				&H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00,
				&H94, &H11, &H00, &H00, &H32, &H00, &H41, &H00, &H1D, &H01, &H78, &H00,
				&H00, &H00, &H28, &H00, &H0A, &H00, &H00, &H00, &H60, &H00, &H5C, &H12,
				&HF4, &H01, &H70, &H17, &H70, &H17, &H62, &H11, &HC0, &H12, &H41, &H00,
				&H3C, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H46, &H00, &H43, &H00,
				&H3C, &H00, &H40, &H00, &H4B, &H00, &H0A, &H00, &H4B, &H00, &H32, &H00,
				&H14, &H00, &H14, &H00, &H2C, &H01, &HE8, &H03, &H34, &H08, &HBC, &H02,
				&H00, &H00, &H1E, &H00, &H1C, &H25, &H40, &H06, &H01, &H00, &H05, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H5F, &H00, &H82, &H00, &HA0, &H00,
				&HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01,
				&HC0, &H12, &HB0, &H04, &H0A, &H00, &H50, &H00, &H64, &H00, &H20, &H03,
				&H64, &H00, &H00, &H00, &H00, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04,
				&HB6, &H03, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H2C, &H01,
				&H2C, &H01, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01,
				&H00, &H00, &H5C, &H12, &H01, &H00, &H1E, &H00, &H64, &H00, &H6E, &H00,
				&H64, &H00, &H00, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00,
				&HAC, &H0D, &H5E, &H01, &H94, &H11, &HF4, &H01, &H48, &H0D, &HC0, &H12,
				&H41, &H00, &H37, &H00, &H41, &H00, &H57, &H00, &H48, &H00, &H42, &H00,
				&H40, &H00, &H3D, &H00, &H4E, &H00, &H49, &H00, &H12, &H00, &H00, &H00,
				&H28, &H00, &H12, &H00, &H05, &H00, &H90, &H01, &HE8, &H03, &H34, &H08,
				&HBC, &H02, &H00, &H00, &H50, &H00, &H3F, &H30, &H2F, &H09, &H01, &H00,
				&H03, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H64, &H00, &H78, &H00,
				&H96, &H00, &HB4, &H00, &H5E, &H01, &HFA, &H00, &H40, &H01, &H04, &H01,
				&H0E, &H01, &HC0, &H12, &H58, &H02, &H0A, &H00, &H50, &H00, &H64, &H00,
				&H52, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H01, &H00, &H05, &H00,
				&H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00, &H08, &H00,
				&H64, &H00, &H0A, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H46, &H00, &H64, &H00,
				&HBE, &H00, &H64, &H00, &H0A, &H00, &H28, &H00, &H00, &H00, &H00, &H00,
				&H64, &H00, &HEC, &H0F, &HF0, &H00, &H70, &H17, &H70, &H17, &HC8, &H0F,
				&H70, &H17, &H41, &H00, &H32, &H00, &H37, &H00, &H43, &H00, &H57, &H00,
				&H44, &H00, &H4D, &H00, &H39, &H00, &H4D, &H00, &H1E, &H00, &H0A, &H00,
				&H3C, &H00, &H2D, &H00, &H05, &H00, &H32, &H00, &HC2, &H01, &HE8, &H03,
				&H08, &H07, &H90, &H01, &H00, &H00, &H49, &H00, &HCE, &H31, &H4C, &H04,
				&H01, &H00, &H07, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H8C, &H00,
				&HDC, &H00, &HF0, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H04, &H01, &H7E, &H13, &H58, &H02, &H14, &H00, &H50, &H00,
				&H64, &H00, &H8A, &H02, &H78, &H00, &H00, &H00, &H01, &H00, &H05, &H00,
				&H05, &H00, &H9C, &H04, &H8A, &H02, &H2D, &H00, &H00, &H00, &HC2, &H01,
				&H00, &H00, &H12, &H02, &H4B, &H00, &HC8, &H00, &HC2, &H01, &H2C, &H01,
				&H3C, &H00, &HBC, &H02, &H00, &H00, &H50, &H14, &H00, &H00, &H14, &H00,
				&H32, &H00, &HC3, &H00, &H64, &H00, &H0A, &H00, &H14, &H00, &H0A, &H00,
				&H00, &H00, &H64, &H00, &HF8, &H11, &H2C, &H01, &H70, &H17, &H70, &H17,
				&H68, &H10, &HC0, &H12, &H3D, &H00, &H3D, &H00, &H41, &H00, &H57, &H00,
				&H57, &H00, &H45, &H00, &H44, &H00, &H3B, &H00, &H45, &H00, &H64, &H00,
				&H0A, &H00, &H50, &H00, &H14, &H00, &H12, &H00, &H16, &H00, &HC2, &H01,
				&HE8, &H03, &HC4, &H09, &H84, &H03, &H3C, &H00, &H3C, &H00, &HB4, &H2D,
				&H4C, &H04, &H01, &H00, &H08, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H78, &H00, &H82, &H00, &H8C, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00,
				&HDC, &H00, &HFA, &H00, &HC8, &H00, &HC0, &H12, &HB0, &H04, &H14, &H00,
				&H50, &H00, &H64, &H00, &H84, &H03, &H6E, &H00, &H00, &H00, &H02, &H00,
				&H02, &H00, &H05, &H00, &H46, &H05, &H5E, &H01, &H1E, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H90, &H01, &H64, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00, &HF2, &H12, &H01, &H00,
				&H00, &H00, &H64, &H00, &H64, &H00, &H64, &H00, &H00, &H00, &H19, &H00,
				&H04, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &HFA, &H00, &H3C, &H0F,
				&HE8, &H03, &HAC, &H0D, &H94, &H11, &H3C, &H00, &H41, &H00, &H41, &H00,
				&H53, &H00, &H57, &H00, &H3B, &H00, &H37, &H00, &H3E, &H00, &H53, &H00,
				&H49, &H00, &H12, &H00, &H00, &H00, &H5A, &H00, &H0A, &H00, &H1C, &H00,
				&H90, &H01, &H14, &H05, &H8C, &H0A, &HF4, &H01, &H14, &H00, &H46, &H00,
				&HF9, &H2A, &HE9, &H03, &H01, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&H92, &H02, &H46, &H00, &H6E, &H00, &HA0, &H00, &HB4, &H00, &HC8, &H00,
				&HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02,
				&H1E, &H00, &H50, &H00, &HC8, &H00, &H20, &H03, &H64, &H00, &H00, &H00,
				&H01, &H00, &H0A, &H00, &H05, &H00, &H9C, &H04, &H58, &H02, &H26, &H00,
				&H9C, &HFF, &H6A, &HFF, &H01, &H00, &HC8, &H00, &H64, &H00, &H96, &H00,
				&HFA, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H68, &H10,
				&H01, &H00, &H00, &H00, &H64, &H00, &H57, &H00, &H50, &H00, &H00, &H00,
				&H46, &H00, &H14, &H00, &H00, &H00, &H6B, &H00, &HAC, &H0D, &H18, &H01,
				&H74, &H0E, &H90, &H01, &H80, &H0C, &H10, &H13, &H41, &H00, &H3A, &H00,
				&H41, &H00, &H57, &H00, &H3E, &H00, &H3D, &H00, &H39, &H00, &H40, &H00,
				&H57, &H00, &H0A, &H00, &H05, &H00, &H00, &H00, &H5F, &H00, &H0A, &H00,
				&H16, &H00, &HF4, &H01, &HE8, &H03, &HFC, &H08, &HE8, &H03, &H00, &H00,
				&H5A, &H00, &H33, &H26, &H8A, &H02, &H01, &H00, &H02, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H3C, &H00, &H6E, &H00, &H6E, &H00, &HE6, &H00,
				&H54, &H01, &HFA, &H00, &H40, &H01, &H04, &H01, &H04, &H01, &H7E, &H13,
				&HB0, &H04, &H32, &H00, &H50, &H00, &H90, &H01, &H20, &H03, &H64, &H00,
				&H00, &H00, &H00, &H00, &H02, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02,
				&H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &HC8, &H00, &H64, &H00,
				&H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00,
				&H94, &H11, &H00, &H00, &H00, &H00, &H64, &H00, &HB4, &H00, &H64, &H00,
				&H00, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HCC, &H10,
				&HA0, &H00, &H5C, &H12, &H58, &H02, &H68, &H10, &H24, &H13, &H41, &H00,
				&H39, &H00, &H3E, &H00, &H57, &H00, &H57, &H00, &H57, &H00, &H42, &H00,
				&H32, &H00, &H48, &H00, &H1E, &H00, &H0F, &H00, &H32, &H00, &H55, &H00,
				&H00, &H00, &H23, &H00, &H7C, &H01, &H4C, &H04, &HC4, &H09, &H58, &H02,
				&H14, &H00, &H50, &H00, &HAC, &H71, &HD4, &H49, &H01, &H00, &H01, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H50, &H00, &H62, &H00, &H91, &H00,
				&H2C, &H01, &H58, &H02, &HFA, &H00, &H40, &H01, &H04, &H01, &H72, &H01,
				&H5C, &H12, &H58, &H02, &H14, &H00, &H1E, &H00, &HA0, &H00, &H20, &H03,
				&H64, &H00, &H00, &H00, &H03, &H00, &H17, &H00, &H05, &H00, &H46, &H05,
				&H5E, &H01, &H23, &H00, &HB4, &H00, &HB4, &H00, &H07, &H00, &HC2, &H01,
				&H9C, &HFF, &HDC, &H00, &HC2, &H01, &H64, &H00, &HCC, &H00, &H5E, &H01,
				&H28, &H00, &H94, &H11, &H00, &H00, &H3C, &H00, &H64, &H00, &HDC, &H00,
				&H64, &H00, &H00, &H00, &H3C, &H00, &H05, &H00, &H00, &H00, &H64, &H00,
				&H62, &H11, &H04, &H01, &H56, &H13, &H58, &H02, &H62, &H11, &H24, &H13,
				&H41, &H00, &H3C, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H57, &H00,
				&H3C, &H00, &H36, &H00, &H45, &H00, &H3C, &H00, &H12, &H00, &H32, &H00,
				&H1E, &H00, &H01, &H00, &H20, &H00, &H5E, &H01, &HE8, &H03, &HDC, &H05,
				&HBC, &H02, &H00, &H00, &H41, &H00, &H10, &H72, &H4C, &H04, &H01, &H00,
				&H06, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H78, &H00, &H82, &H00,
				&H8C, &H00, &HE6, &H00, &H54, &H01, &HFA, &H00, &HDC, &H00, &HFA, &H00,
				&HC8, &H00, &HC0, &H12, &HB0, &H04, &H14, &H00, &H50, &H00, &H64, &H00,
				&H84, &H03, &H6E, &H00, &H00, &H00, &H01, &H00, &H08, &H00, &H05, &H00,
				&H00, &H05, &H8A, &H02, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00,
				&HFA, &H00, &H9C, &HFF, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H64, &H00,
				&H90, &H01, &H00, &H00, &H2A, &H12, &H01, &H00, &H41, &H00, &H64, &H00,
				&H6E, &H00, &H64, &H00, &H1E, &H00, &H14, &H00, &H0A, &H00, &H00, &H00,
				&H64, &H00, &HAC, &H0D, &HF0, &H00, &HD8, &H0E, &HB4, &H00, &H04, &H10,
				&H24, &H13, &H41, &H00, &H34, &H00, &H41, &H00, &H57, &H00, &H3D, &H00,
				&H35, &H00, &H40, &H00, &H42, &H00, &H57, &H00, &H64, &H00, &H09, &H00,
				&H46, &H00, &H32, &H00, &H0A, &H00, &H16, &H00, &H90, &H01, &HE8, &H03,
				&HB0, &H04, &HBC, &H02, &H00, &H00, &H32, &H00, &H5C, &H2B, &HF4, &H01,
				&H01, &H00, &H04, &H00, &H00, &H00, &H00, &H00, &HB6, &H01, &H46, &H00,
				&H5A, &H00, &H82, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00, &H40, &H01,
				&H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02, &H0A, &H00, &H50, &H00,
				&H64, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H01, &H00, &H0A, &H00,
				&H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00, &H00, &H00, &H00, &H00,
				&H00, &H00, &H90, &H01, &H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H90, &H01, &H00, &H00, &H94, &H11, &H00, &H00, &H32, &H00,
				&H41, &H00, &H1D, &H01, &H78, &H00, &H00, &H00, &H28, &H00, &H0A, &H00,
				&H00, &H00, &H60, &H00, &H5C, &H12, &HF4, &H01, &H70, &H17, &H70, &H17,
				&H62, &H11, &HC0, &H12, &H41, &H00, &H3C, &H00, &H41, &H00, &H57, &H00,
				&H57, &H00, &H57, &H00, &H3F, &H00, &H34, &H00, &H42, &H00, &H4B, &H00,
				&H0A, &H00, &H4B, &H00, &H32, &H00, &H14, &H00, &H14, &H00, &H2C, &H01,
				&HE8, &H03, &H34, &H08, &HBC, &H02, &H00, &H00, &H1E, &H00, &H1C, &H25,
				&H40, &H06, &H01, &H00, &H05, &H00, &H00, &H00, &H00, &H00, &HB6, &H01,
				&H5F, &H00, &H82, &H00, &HA0, &H00, &HB4, &H00, &HC8, &H00, &HFA, &H00,
				&H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &HB0, &H04, &H0A, &H00,
				&H50, &H00, &H64, &H00, &H20, &H03, &H64, &H00, &H00, &H00, &H00, &H00,
				&H0A, &H00, &H05, &H00, &H9C, &H04, &HB6, &H03, &H1E, &H00, &H00, &H00,
				&H00, &H00, &H00, &H00, &H2C, &H01, &H2C, &H01, &H3C, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H90, &H01, &H00, &H00, &H5C, &H12, &H01, &H00,
				&H1E, &H00, &H64, &H00, &H6E, &H00, &H64, &H00, &H00, &H00, &H14, &H00,
				&H0A, &H00, &H00, &H00, &H64, &H00, &HAC, &H0D, &H5E, &H01, &H94, &H11,
				&HF4, &H01, &H48, &H0D, &HC0, &H12, &H41, &H00, &H37, &H00, &H41, &H00,
				&H57, &H00, &H57, &H00, &H3D, &H00, &H3C, &H00, &H3D, &H00, &H50, &H00,
				&H49, &H00, &H12, &H00, &H00, &H00, &H28, &H00, &H12, &H00, &H05, &H00,
				&H90, &H01, &HE8, &H03, &H34, &H08, &HBC, &H02, &H00, &H00, &H50, &H00,
				&H3F, &H30, &H2F, &H09, &H01, &H00, &H03, &H00, &H00, &H00, &H00, &H00,
				&HB6, &H01, &H64, &H00, &H78, &H00, &H96, &H00, &HB4, &H00, &H5E, &H01,
				&HFA, &H00, &H40, &H01, &H04, &H01, &H0E, &H01, &HC0, &H12, &H58, &H02,
				&H0A, &H00, &H50, &H00, &H64, &H00, &H52, &H03, &H64, &H00, &H00, &H00,
				&H01, &H00, &H01, &H00, &H05, &H00, &H9C, &H04, &H1C, &H02, &H1E, &H00,
				&H00, &H00, &H00, &H00, &H08, &H00, &H64, &H00, &H0A, &H00, &H3C, &H00,
				&H3C, &H00, &H3C, &H00, &H64, &H00, &H90, &H01, &H00, &H00, &H94, &H11,
				&H00, &H00, &H46, &H00, &H64, &H00, &HBE, &H00, &H64, &H00, &H0A, &H00,
				&H28, &H00, &H00, &H00, &H00, &H00, &H64, &H00, &HEC, &H0F, &HF0, &H00,
				&H70, &H17, &H70, &H17, &HC8, &H0F, &H70, &H17, &H41, &H00, &H32, &H00,
				&H37, &H00, &H43, &H00, &H57, &H00, &H57, &H00, &H49, &H00, &H35, &H00,
				&H49, &H00, &H1E, &H00, &H0A, &H00, &H3C, &H00, &H2D, &H00, &H05, &H00,
				&H32, &H00, &HC2, &H01, &HE8, &H03, &H08, &H07, &H90, &H01, &H00, &H00,
				&H49, &H00, &HCE, &H31, &H4C, &H04, &H01, &H00, &H07, &H00, &H00, &H00,
				&H00, &H00, &HB6, &H01, &H8C, &H00, &HDC, &H00, &HF0, &H00, &HE6, &H00,
				&H54, &H01, &HFA, &H00, &H40, &H01, &H04, &H01, &H04, &H01, &H7E, &H13,
				&H58, &H02, &H14, &H00, &H50, &H00, &H64, &H00, &H8A, &H02, &H78, &H00,
				&H00, &H00, &H01, &H00, &H05, &H00, &H05, &H00, &H9C, &H04, &H8A, &H02,
				&H2D, &H00, &H00, &H00, &HC2, &H01, &H00, &H00, &H12, &H02, &H4B, &H00,
				&HC8, &H00, &HC2, &H01, &H2C, &H01, &H3C, &H00, &HBC, &H02, &H00, &H00,
				&H50, &H14, &H00, &H00, &H14, &H00, &H32, &H00, &HC3, &H00, &H64, &H00,
				&H0A, &H00, &H14, &H00, &H0A, &H00, &H00, &H00, &H64, &H00, &HF8, &H11,
				&H2C, &H01, &H70, &H17, &H70, &H17, &H68, &H10, &HC0, &H12, &H3D, &H00,
				&H3D, &H00, &H41, &H00, &H57, &H00, &H57, &H00, &H57, &H00, &H40, &H00,
				&H33, &H00, &H45, &H00, &H64, &H00, &H0A, &H00, &H50, &H00, &H14, &H00,
				&H12, &H00, &H16, &H00, &HC2, &H01, &HE8, &H03, &HC4, &H09, &H84, &H03,
				&H3C, &H00, &H3C, &H00, &HB4, &H2D, &H4C, &H04, &H01, &H00, &H08, &H00,
				&H00, &H00, &H00, &H00, &HB6, &H01, &H78, &H00, &H82, &H00, &H8C, &H00,
				&HE6, &H00, &H54, &H01, &HFA, &H00, &HDC, &H00, &HFA, &H00, &HC8, &H00,
				&HC0, &H12, &HB0, &H04, &H14, &H00, &H50, &H00, &H64, &H00, &H84, &H03,
				&H6E, &H00, &H00, &H00, &H02, &H00, &H02, &H00, &H05, &H00, &H46, &H05,
				&H5E, &H01, &H1E, &H00, &H00, &H00, &H00, &H00, &H00, &H00, &H90, &H01,
				&H64, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H3C, &H00, &H90, &H01,
				&H00, &H00, &HF2, &H12, &H00, &H00, &H00, &H00, &H03, &H00, &H00, &H00,
				&HEC, &H16, &HF0, &HBF, &HF0, &H16, &HF0, &HBF, &HF4, &H16, &HF0, &HBF,
				&H02, &H00, &H06, &H00, &H02, &H00, &H00, &H00, &HF8, &H16, &HF0, &HBF,
				&HFC, &H16, &HF0, &HBF, &H00, &H17, &HF0, &HBF, &H02, &H00, &H04, &H00,
				&H02, &H00, &H00, &H00, &H04, &H17, &HF0, &HBF, &H09, &H17, &HF0, &HBF,
				&H18, &H17, &HF0, &HBF, &H02, &H00, &H05, &H00, &H02, &H00, &H00, &H00,
				&H1C, &H17, &HF0, &HBF, &H20, &H17, &HF0, &HBF, &H24, &H17, &HF0, &HBF,
				&H0A, &H00, &H03, &H00, &H01, &H00, &H00, &H00, &H29, &H17, &HF0, &HBF,
				&H39, &H17, &HF0, &HBF, &H49, &H17, &HF0, &HBF, &H0A, &H00, &H02, &H00,
				&H02, &H00, &H00, &H00, &H59, &H17, &HF0, &HBF, &H69, &H17, &HF0, &HBF,
				&H78, &H17, &HF0, &HBF, &H02, &H00, &H02, &H00, &H01, &H00, &H00, &H00,
				&H7D, &H17, &HF0, &HBF, &H8D, &H17, &HF0, &HBF, &H9D, &H17, &HF0, &HBF,
				&H02, &H00, &H02, &H00, &H00, &H00, &H00, &H00, &HAC, &H17, &HF0, &HBF,
				&HB0, &H17, &HF0, &HBF, &HB4, &H17, &HF0, &HBF, &H0A, &H00, &H01, &H00,
				&H00, &H00, &H00, &H00, &HB8, &H17, &HF0, &HBF, &HBC, &H17, &HF0, &HBF,
				&HC0, &H17, &HF0, &HBF, &H0A, &H00, &H01, &H00, &H00, &H00, &H00, &H00,
				&HB8, &H17, &HF0, &HBF, &HBC, &H17, &HF0, &HBF, &HC0, &H17, &HF0, &HBF,
				&H0A, &H00, &H01, &H00, &H00, &H00, &H00, &H00, &HE9, &H4E, &HF0, &HBF,
				&HD5, &H17, &HF0, &HBF, &HE5, &H17, &HF0, &HBF, &H0A, &H00, &H01, &H00,
				&H00, &H00, &H00, &H00, &HF5, &H17, &HF0, &HBF, &H05, &H18, &HF0, &HBF,
				&H15, &H18, &HF0, &HBF, &H0A, &H00, &H01, &H00, &H00, &H00, &H00, &H00,
				&HB8, &H17, &HF0, &HBF, &HBC, &H17, &HF0, &HBF, &HC0, &H17, &HF0, &HBF,
				&H00, &H00, &H00, &H00, &H00, &H00, &H00, &H00
				}
						#endif
					#endif
				#endif

			#endif

		#endif // Globals, Structures, Enumerations, and Constants

	#if 1 // Lib Functions and Subs

		#if 1 // homebrew Functions and Subs

			// added this as, I'm disabling interrupts around the serial comms, bracketing CS with interrupt(T/F)
			// so to remove any reliance on timer delays w/in comms, dealing with it more granularly
			sub tts_asmdly(count) 		// roughly:
				 '	279.2173ns/call on 48mhz samd21 (13.4 cycles)  (~279.2173us average for a 1000 calls)  '~
				 '	120.7408ns/call on 100mhz 1756 (12.08 cycles)  (~120.7408us average for a 1000 calls)  '~
				 '	66.75126ns/call on 204mhz 4330 (13.6 cycles)   (~66.75126us average for a 1000 calls)  '~
				while count
					 __asm__(&H46C0) // nop
					count -= 1
					loop
				endsub

			// this replaces the tts_read_byte_spi and tts_write_byte_spi with a BB'd solution - for now...
			// timing adjusted for quick BB results to minimize
			// impacts of disabling interrupts during comms (was having issues with interrupts effin with things.  Need to
			// move to spi peripheral once working...
			//
			// need to write with a dummy byte to do a read, and this does implement a full duplex read when writing out ...
			// the TTS module 's docs clearly enumerate that reading while writing is needed, however
			// the libs that mikroelectronika provided seemingly don't satisfy this requirement .. WIP
			// the mid-xmit receipt of an ad-hoc msg start sequence and related arbitration is handled at higher levels of functions
			function tts_spi_xchg8(dat)	as integer  'implementation of SPIBI for single byte xfers
				dim j, tts_rxd as integer		'to read a byte, just send a padding byte (&H00)...

				tts_rxd = 0
				j = &H80 'setup bit field position indexer - msb first in this context

				// NOTE: CSEL is controlled by a higher layer, at the transaction level, as is serial-traffic-related interrupt disablement

				while j 'and walk thru all 8 bits - ordering of shifts done to drive ~50:50 sclk duty cycles w/o using delays

					tts_sclk_active					// H2L edge causes slave to setup next bit xfer

					tts_rxd <<= 1					// shift rxd byte buff left as lsb is last, shifting prior to setting b0 so, at conclusion, b0 is unfettered

					tts_mosi = (dat and j)			// set the mosi bit output port (this imputess enuf sclk period delay)

					j >>= 1 						// bump position indexer right

					tts_sclk_idle					// do a L2H which serves to assert to slave that it's input bits are valid

					tts_rxd or= (tts_miso and 1)	// then read in the miso bit (this imputess enuf sclk period delay)

					loop							// and do it again until all 8 bits are done

				// NOTE: CSEL is controlled by a higher layer, at the transaction level, as is serial-traffic-related interrupt disablement

				return tts_rxd
				endfunction

			/** CS active - moved from text_to_speech_hal.h/.c
			*
			* Used by HW layer functions to set CS PIN high (deselect)
			*/
			sub tts_hal_cs_active()
				interrupt(false)	// disable interupts to ensure traffic is not effed with (was having problems...).
				tts_led_active
				tts_sclk_idle	//  make sure clk is idle before asserting cs_active
				tts_asmdly(csel_dwell_asmdly_cnt) 'wait a small time for slave to do its thing
				tts_csel_active
				tts_asmdly(csel_dwell_asmdly_cnt) 'wait a small time for slave to do its thing
				endsub

			/** CS idle - moved from text_to_speech_hal.h/.c
			*
			* Used by HW layer functions to set CS PIN low (selecet)
			*/
			sub tts_hal_cs_idle()
				tts_asmdly(csel_dwell_asmdly_cnt) 'wait a small time for slave to do its thing
				tts_csel_idle
				tts_asmdly(csel_dwell_asmdly_cnt) 'wait a small time for slave to do its thing
				tts_sclk_idle	// make sure clk is idle after asserting cs_idle
				tts_led_idle
				interrupt(true)
				endsub

			/** MSG Ready
			*
			* Returns state of RDY PIN.
			*
			* @retval TRUE  - RDY high
			* @retval FALSE - RDY low
			*/
			function tts_hal_msg_rdy() as integer
				return in(tts_ready_io)
				endfunction

			// per protocol manual section 3.4, except ISC_BOOT_RUN_RESP - see 4.4.2.6.Note_1
			// NOTE: CSEL is controlled by a higher layer, at the transaction level, as is serial-traffic-related interrupt dis/enablement
			sub tts_pad_comms_traffic(paramarray cnt)  // cnt(0) defaults to 16 if _cnt not passed
				dim entry_cs_state as integer
				dim j, _flush_f as integer		'to read a byte, just send a padding byte (&H00)...

				// cnt(0) is pad byte count
				// cnt(1) if present, forces a flush, ignoring dataready sensing

				if cnt(15) <0
					cnt(0) = _pad_bytes_reqd
					_flush_f = 0
				else
					// use the first parameter passed as the count of padding bytes to push
					if cnt(15) > 0
						interrupt(false)
						_flush_f = cnt(1)
					else
						_flush_f = 0
						endif
					endif

				entry_cs_state = tts_cs_state
				tts_hal_cs_active // make csel active

				while cnt(0)>0

					// was tts_spi_xchg8(PADDING_BYTE) but,
					// doing an inline of tts_spi_xchg8, so code can monitor msg_ready during padding, twice/BIT, and not burden
					// other serial traffic w/ the related overhead
					// will abruptly cease padding xmit and exit when a l2h transition of msg_ready is sensed

					j = &H80 'setup bit field position indexer - msb first in this context

					while j 'and walk thru 8 bits - positioning of bit shifting done to drive ~50:50 sclk duty cycles w/o using delays
						if tts_hal_msg_rdy and (_flush_f = 0)	// interrupts are overtly disabled during serial comms, so comm routines will need to monitor
							tts_hal_cs_idle 	// abruptly cease xmission as slave is wanting to be serviced
							tts_sclk_idle		// returning to idle AFTER idle'g CS (prevents spi-bit state latching)
							exit				// bust out of this bit-level while loop
						else
							tts_sclk_active		// H2L edge causes slave to setup next bit xfer
							tts_mosi = 0		// set the mosi bit output port (this imputess enuf sclk period delay) ... padding is all zeros...
							j >>= 1 			// bump bit position indexer right
							endif

						if tts_hal_msg_rdy and (_flush_f = 0)	// interrupts are overtly disabled during serial comms, so comm routines will need to monitor
							tts_hal_cs_idle 	// abruptly cease xmission as slave is wanting to be serviced
							tts_sclk_idle		// returning to idle AFTER idle'g CS (prevents spi-bit state latching)
							exit				// bust out of this bit-level while loop
						else
							tts_sclk_idle		// do a L2H which serves to assert to slave that it's input bits are valid
							endif
						loop					// and do it again until all 8 bits are done

					if tts_hal_msg_rdy and (_flush_f = 0)	// interrupts are overtly disabled during serial comms, so comm routines will need to monitor
						tts_hal_cs_idle 		// abruptly cease xmission as slave is wanting to be serviced
						tts_sclk_idle			// returning to idle AFTER idle'g CS (prevents spi-bit state latching)
						exit					// bust out of this byte-level while loop, causing the padding to cease immediately, even mid-byte
						endif

					cnt(0) -= 1
					loop

					if cnt(15) > 0
						interrupt(true)
					endif

				endsub

			#endif // homebrew Functions and Subs

		#if 1 // text_to_speech_hal.h/.c  NOTE: moved cs control procs up higher as called by previous code

			/** MUTE High
			*
			* Used by HW layer to set MUTe PIN high (mute)
			*/
			sub tts_hal_mute_hi()
				out(tts_mute_io) = 1
				endsub

			/** MUTE Low
			*
			* Used by HW layer to set MUT PIN low (unmute)
			*/
			sub tts_hal_mute_lo()
				out(tts_mute_io) = 0
				endsub

			/** Hardware Reset		 // see http://bit.ly/2yRy9gU and https://i.imgur.com/oB7zm86.png and https://i.imgur.com/101b43E.png
			*
			* Resets the module via RST PIN
			*/
			sub tts_hal_reset()		// post reset delay is baked into the code herein

			_reset_again:
				tts_asmdly(reset_keepout_asmdly_cnt)  ' T2 - 2 Tosc (32.768K) 61.x uS after powerup before reset goes active
				tts_reset_active
				tts_asmdly(reset_keepout_asmdly_cnt)  ' T3 - 2 Tosc (32.768K) 61.x uS in reset
				tts_reset_idle
				tts_asmdly(reset_keepout_asmdly_cnt)  ' T4 - 2 Tosc (32.768K) 61.x uS after reset before anything

				// have a weird issue with the device restarting on reset only 50% of the time - every. other. reset. with no power cycles
				tts_asmdly(tts_45ms_asmdly_cnt)

				if 	tts_hal_msg_rdy
					tts_pad_comms_traffic(16,1)  // try forcing a flush of the slave to see if it'll de-assert ready...
					tts_asmdly(tts_45ms_asmdly_cnt)
					goto _reset_again	// symptom is that @ reset, Ready remains asserted by Target for some 75ms, so sensing same @ 45ms and resetting again...
					endif

				tts_asmdly(post_reset_asmdly_period-tts_45ms_asmdly_cnt)

				endsub

			/** HAL Initialization
			*
			* Hal layer initialization. Must be called before any other function.
			*/
			sub tts_hal_init()

				// setup pointers to message buffers
				_last_req = addressof(ISC_REQ_Struct)
				_last_rsp = addressof(ISC_RESP_Struct)

				_pad_bytes_reqd = 0				// init var

				endsub

			/** HW abstraction code via proper function vs. pointers, as calling by pointer with params not supported in AB
			*/
			function tts_write_byte_spi(txbyte_ptr as integer) as integer

				dim tmp_b as integer
				tmp_b = rd_byte(txbyte_ptr)	// need to do a rd_byte here as a *ptr causes a non-word align access which borks out on some MCUs,
											// and the SAMD21s just freezes, as an example...

				return tts_spi_xchg8(tmp_b)
				endfunction

			/** HW abstraction code via proper function vs. pointers, as calling by pointer with params not supported in AB
			*/
			function tts_read_byte_spi(txbyte_ as integer)
				return tts_spi_xchg8(txbyte_)
				endfunction

			/** HAL Write
			*
			* Writes data through SPI bus
			*
			* @note Function have no affect to the CS PIN state - chip select is
			* controled directly from HW layer.
			*
			* @param[in] buffer
			* @param[in] count
			*/
			sub tts_hal_write(buffer_ptr as integer, count as integer)

				dim rxb as integer

				while(count)

					rxb = tts_write_byte_spi(buffer_ptr)

					buffer_ptr += 1
					count -= 1
					loop

				endsub

			/** HAL Write Byte
			* OK, so this was declared in text_to_speech_hal.h, BUT was not defined anywhere in the library,
			* but going to keep it here for the sake of completness....
			*/
			sub tts_hal_write_byte(byte_ as integer)		//  it 's unused
				endsub

			/** HAL Read
			*
			* Reads data from SPI bus
			*
			* @note Function have no affect to the CS PIN state - chip select is controled directly from HW layer
			*
			* @param[out] buffer
			* @param[in] count
			*/
			sub tts_hal_read(buffer_ptr as integer, count as integer)

				while(count)
					wr_byte(buffer_ptr, tts_read_byte_spi(DUMMY_BYTE))
					buffer_ptr += 1
					count -= 1
					loop

				endsub

			#endif // text_to_speech_hal.h/.c

		#if 1 // text_to_speech_hw.h/.c

			//  READ RESPONSE, called if data ready goes high, stuffs message into last_resp buffer, and sends padding
			sub tts_resp_read()

				dim tmp_byte, tmp_len, tmp_wfri_us as integer

				tts_hal_cs_active()							// csel dwell delay therein as is interrupt disablement

			_get_another_byte:								// re-entry point if a dummy byte received
				tmp_byte = &H00
				tmp_len = 0

				tts_hal_read(addressof(tmp_byte), 1)		// get byte that is waiting to be sent by slave

				if tmp_byte = START_MESSAGE					// yea, go get the while message and stuff it into the buffer
					tts_hal_read(_last_rsp, 2) 				// get len and stuff it home
					tmp_len  = rd_byte(_last_rsp)			// get len lsB from buffer
					tmp_len or= rd_byte(_last_rsp+1) << 8	// get len msB from buffer

					tts_hal_read(_last_rsp + 2, tmp_len-2)  // then get len bytes of payload, stuffing them home into the last_rsp buffer

				else
					if ((tmp_byte = &H00) and tts_hal_msg_rdy)	// incoming responses are almost always preceeded with a dummy byte
						goto _get_another_byte						// so just ignore same and go get the next byte
						endif
					endif

				// the padding proc could be entered immediately after slave emits a message.  However, need to stall here a bit until data
				// ready goes low, otherwise the detection of an ad-doc message during padding (by listening for data ready) is compromised.
				// so, stall until data ready goes low, for up to ___uS (host dependent) - error out if it takes too long

				#if 1 	// wait for module to idle it's message_ready signal

					tmp_len = timer		// using a variable that is no longer used as a timer start value
					tmp_wfri_us = 2000	// wait for ready idle time
					while ((timer - tmp_len) < tmp_wfri_us) // stall up to ___us - msg ready usually idles itself in <10us
						if not tts_hal_msg_rdy
							' print "idled in ";timer - tmp_len;" uS"
							exit
							endif
						loop
					if tts_hal_msg_rdy
						print "heads-up: stalled ";tmp_wfri_us;" us and tts_hal_msg_rdy never idle'd..."
						' stop		// not going to stop here - could be a timer roll-over and also, with the above print, the sig will likely idle anyways...
						endif
					#endif

				tts_pad_comms_traffic()		// padding is required on received messages as well...
											// padding byte count set priot to calling this proc, so honor it by not overwrighting

				tts_hal_cs_idle()			// csel dwell delay therein, as is interrupt enablement

				endsub

			//  'WRITE REQUEST ' a  'private ' function - no original details...
			sub tts_write_req(paramarray _leave_cs_active)

				dim cnt, tmp_idx, keep_cs_active as integer
				dim start(1) as byte

				keep_cs_active = _leave_cs_active(0)

				if _leave_cs_active(15) < 0
					keep_cs_active = false
				elseif (_leave_cs_active(15) > 0) or (keep_cs_active < 0) or (keep_cs_active > 1)
					print "tts_write_req - bad param count or param out of bounds"
					stop
					endif

				start(0) = START_MESSAGE
				start(1) = &H00

				cnt   = rd_byte(_last_req+ISC_REQ_len_os)
				cnt or= rd_byte(_last_req+ISC_REQ_len_os+1) << 8

				tts_hal_cs_active()	// csel dwell delay therein as is interrupt disablement

				tts_hal_write(addressof(start), 1)	// write start byte

				tts_hal_write(_last_req, cnt)		// write the rest of the bytes

				tts_pad_comms_traffic()				// padding is required on sent messages as well...

				if (not (keep_cs_active))
					tts_hal_cs_idle()				// csel dwell delay therein as is interrupt disablement
					endif

				endsub

			// moved up here from text_to_speech.h/.c, as forward references in AB sort of a pita...
			/** Response Data
			*
			* Fill given buffer with last received response data if there is data at all.
			* Size of buffer must be big enough.
			*
			* @param[out] buffer
			*/
			sub tts_rsp_data(buffer_PTR)
				dim bfr, cnt, ptr as integer

				bfr = buffer_PTR
				ptr = _last_rsp+ISC_RESP_pld_os

				cnt   = rd_byte(_last_rsp+ISC_RESP_len_os)
				cnt or= rd_byte(_last_rsp+ISC_RESP_len_os+1) << 8

				cnt -= 4

				while(cnt)
					wr_byte(bfr, rd_byte(ptr))
					bfr += 1
					ptr += 1
					cnt -= 1
					loop
				endsub

			// moved up here from text_to_speech.h/.c, as forward references in AB sort of a pita...
			/** Response Index
			*
			* Returns last received response code.
			*
			* @return (&H0000 - &HFFFF)
			*/
			function tts_rsp_idx() as integer
				dim tmp as integer

				tmp   = rd_byte(_last_rsp+ISC_RESP_idx_os)
				tmp or= rd_byte(_last_rsp+ISC_RESP_idx_os+1) << 8

				return tmp
				endfunction

			// moved up here from text_to_speech.h/.c, as forward references in AB sort of a pita...
			// used to parse ad-hoc response & idenify msg type received while looping and waiting for a specific response
			// useful when error or other out of sequence msgs (shouldn't be any...) are received, or
			// when state flag changes need to be made - helps to address the blocking nature of waiting for a specific response
			// in a single thread/non-rtos/non-multitasking implementation such as this...
			function tts_parse_last_rsp_ind() as integer
				dim rsp_idx as integer
				dim rsp_data(4) as byte

				memset(addressof(rsp_data),&H00,5)

				rsp_idx = tts_rsp_idx()

				// error msg trapping
				if (rsp_idx = ISC_MSG_BLOCKED_RESP)
					tts_rsp_data(addressof(rsp_data))
					_req_err    = rsp_data(0)
					_req_err  or= rsp_data(1) << 8
					_err_code   = rsp_data(2)
					_err_code or= rsp_data(3) << 8

					if(_msg_block_callback <> NULL)
						call(_msg_block_callback)		 // _msg_block_callback need to use _req_err & _err_code globals
						endif
					return 1
				elseif (rsp_idx = ISC_ERROR_IND)
					_req_err = 0
					tts_rsp_data(addressof(rsp_data))
					_err_code   = rsp_data(0)
					_err_code or= rsp_data(1) << 8
					if ((_err_code > 0) and (_err_code < &H8000))

						if(_err_callback <> NULL)
							call(_err_callback) 		// _err_callback will have to use global _err_code - no _req_err...
							endif
					elseif ((_err_code > 0) and (_err_code > &H7FFF))

						if(_fatal_err_callback <> NULL)
							call(_fatal_err_callback) 	// _fatal_err_callback will have to use global _err_code - no _req_err...
							endif
						endif
					return 1
				// state msg trapping with flag setting
				elseif (rsp_idx = ISC_tts_ready_IND)
					_tts_rdy_f = 1
				elseif (rsp_idx = ISC_SPCODEC_READY_IND)
					_spc_rdy_f = 1
				elseif (rsp_idx = ISC_TTS_FINISHED_IND)
					_tts_fin_f = 1
				elseif (rsp_idx = ISC_SPCODEC_FINISHED_IND)
					_spc_fin_f = 1
					endif
				return 0
				endfunction

			/** Timer Tick
			*
			* Should be placed inside the user defined interrupt routine that will call
			* this function every milisecond.
			*/
			sub tts_tick_isr()	// fires every 1mS

				_ticker += 1 'increment mS counter
				if(_ticker > 500) 'if 1/2 sec passes,
					_ticker_f = true 'set ticker flag
				endif

				if tts_hal_msg_rdy  // interrupts are overtly disabled during serial comms, so comm routines will need to monitor
					tts_resp_read	// hmm
					tts_parse_last_rsp_ind
					endif

				endsub

			// interrupts are forcibly disabled during comms (when CSEL is active)
			interrupt sub timer1irq
				tts_tick_isr

				#ifdef LPC1756 	// timer Clear interrupt codes
					T1_IR = 1	       ' Clear interrupt
				#elif defined SAMD21
					WR_BYTE (R08_TC5_INTFLAG, (1<<4) )  ' MC0 - clear the interrupt
				#else
					#error Need to modify the tts.lib to support your target - timer_defs section
					#endif

				endsub

			// timer_defs
			#ifdef LPC1756 	// timer instantiation codes

				// 1756 timer1 codes - interrupts are forcibly disabled during comms (when CSEL is active - via interrupt(F/T))
				sub tts_on_timer (half_msec, dothis )	' due to the -1 for the match register, made changes herein
					TIMER1_ISR   = dothis + 1			' set VIC ISR -- need the +1 for Thumb operation
					T1_PR  = 24999>>1					' 1ms prescale divided by two as calling the BASIClib version with a count of 1mS fails to fire (-1 below)
					VICIntEnable or= (1<<2)				' Enable interrupt
					T1_MR0 = half_msec-1				' set up match number of ms
					T1_MCR = 3							' Interrupt and Reset on MR0
					T1_IR  = 1							' clear interrupt
					T1_TC  = 0							' clear timer counter
					T1_TCR = 1							' TIMER1 Enable
					endsub

			#elif defined SAMD21

				// using timer5 here
				sub tts_on_timer (half_msec, dothis )	' due to the -1 for the match register, made changes herein
					TC5_ISR = dothis + 1  ' set function of VIC   -- need the +1 for Thumb operation
					WR_HALF (R16_GCLK_CLKCTRL, (1<<14) or (0<<8) or &H1C )
					WR_HALF (R16_TC5_CTRLA,1) ' TC_CTRLA_SWRST
					VICIntEnable or= (1<<TC5_IRQn)  ' Enable interrupt
					WR_BYTE(R08_TC5_INTENSET, (1<<4)) ' MC0
					TC5_CC0 = &H17 * half_msec	' 500us scaler
					WR_HALF (R16_TC5_CTRLA, (7<<8) or (1<<5) or (0<<2) or (1<<1) )
					endsub

			#else

				#error Need to modify the tts.lib to support your target - timer_defs section

				#endif

			/** HW Layer Initialization
			*
			* Initalization of HW Layer, must be done before any other function.
			* This function also executes HAL layer initialization inside it self.
			*/
			sub tts_hw_init()

				// init hal variables/pointers/etc.

				tts_hal_init()

				// null out the ticker flag and counter
				_ticker_f = false
				_ticker = 0

				// Null Out Req and Resp structures
				memset(_last_req,&H00,ISC_REQ_len_cnt+ISC_REQ_idx_cnt+MAIN_MESSAGE_MAX)

				// dunno why this is &HFF - not used herein for null msg detect or anything...
				memset(_last_rsp+ISC_RESP_len_os,&HFF,ISC_RESP_len_cnt)
				memset(_last_rsp+ISC_RESP_idx_os,&H00,ISC_RESP_idx_cnt+RESP_MESSAGE_MAX)

				// set initial io states
				tts_reset_idle
				tts_csel_idle
				tts_sclk_idle
				tts_mosi_idle
				tts_mute_active

				// set GPIO directions
				output(tts_reset_io)
				output(tts_csel_io)
				output(tts_sclk_io)
				output(tts_mosi_io)
				output(tts_mute_io)
				input(tts_miso_io)
				input(tts_ready_io)

				#ifdef LPC1756	// start timer codes

					// set up timer to fire every 1 millisecond
					tts_on_timer(2, addressof(timer1irq))  // reconfigured timer sub for a 500uS rate, hence 2...

					// and illuminate led
					out(led0_io) = 1
					output(led0_io)
					out(led0_io) = 0

					// seems a delay fixes some silly hang here on the 1756
					wait(10)	' this works, but the following don't & I don't know why...
					' tts_asmdly(tts_10ms_asmdly_cnt)

				#elif defined SAMD21

					// set up timer to fire every 25 milliseconds
					// while TTS SOC calls for 1mS interrupts, a slow host like the SAMD21 and fast ints = much drama...
					tts_on_timer(50, addressof(timer1irq))  // reconfigured timer sub for a 500uS rate...

					#ifdef SAMD21_uChip
						// need to make pin 15 a 3v3 PS output by jumpering the 3v3 SMD jumper on the uChip
						// make pin 16 a 5V output
						out(vext_select_io) = 0
						output(vext_select_io)
						out(vext_select_io) = 1
						#endif

					// and illuminate led
					out(led0_io) = 0
					output(led0_io)
					out(led0_io) = 1

				#else
					#error need to fix the lib - tts_hw_init
					#endif

				tts_hal_reset()		// and reset the tts module

				endsub

			/** Mute Command
			*
			* Mute using MUT pin
			*
			* @param[in] cmd (true - mute / false - unmute)
			*/
			sub tts_mute_cmd(cmd as integer)
				if(cmd)
					tts_hal_mute_hi()
				else
					tts_hal_mute_lo()
				endif
				endsub

			/** Request Parser - sets msg header (len/ID) in buffer, places payload into buffer
			*
			* Preparing request for writing. Loads data into output buffer and executes
			* write function.
			*
			* @param[in] req - valid request code
			* @param[in] payload - data
			* @param[in] pl_len - data size
			*/
			sub tts_parse_req(req as integer, payload_PTR as integer, pl_len as integer)
				dim i as integer

				// setup: req msg header w/in buffer structure
				// msg len -> buffer (+4 is for header (len & msgID))
				wr_byte(_last_req+ISC_REQ_len_os, pl_len + 4)
				wr_byte(_last_req+ISC_REQ_len_os+1, (pl_len + 4) >> 8)

				// msg id -> buffer
				wr_byte(_last_req+ISC_REQ_idx_os, req)
				wr_byte(_last_req+ISC_REQ_idx_os+1, req >> 8)

				// setup/init last resp - overwritten when response received
				wr_byte(_last_rsp+ISC_RESP_idx_os, &HFF)
				wr_byte(_last_rsp+ISC_RESP_idx_os+1, &HFF)

				// if payload exists, stuff it into the msg buffer
				if (payload_PTR <> NULL)
					i = 0
					while (pl_len > 0)
						wr_byte(_last_req+ISC_REQ_pld_os + i  , rd_byte(payload_PTR))
						payload_PTR += 1
						i += 1
						pl_len -= 1
						loop
					endif

				endsub

			/** Boot Image Request Parser - sets msg header (len/ID) in buffer, places payload into buffer
			*
			* Function is used for the uploading of boot image
			*
			* @param[in] payload - boot image part
			* @param[in] pl_len - data size
			*/
			sub tts_runtime_img_parse(payload_PTR as integer, pl_len as integer)
				dim i as integer

				// setup: req msg header w/in buffer structure
				// msg len -> buffer (+4 is for header (len & msgID))	;~
				wr_byte(_last_req+ISC_REQ_len_os, pl_len + 4)
				wr_byte(_last_req+ISC_REQ_len_os+1, (pl_len + 4) >> 8)

				// msgID -> buffer
				wr_byte(_last_req+ISC_REQ_idx_os, &H00 )
				wr_byte(_last_req+ISC_REQ_idx_os+1, &H10)

				// setup/init last resp - overwritten when response received
				wr_byte(_last_rsp+ISC_RESP_idx_os, &HFF)
				wr_byte(_last_rsp+ISC_RESP_idx_os+1, &HFF)

				// if payload, stuff it into buffer
				if (payload_PTR <> NULL)
					i = 0
					while (pl_len > 0)
						wr_byte(_last_req+ISC_REQ_pld_os + i, rd_byte(payload_PTR))
						payload_PTR += 1
						i += 1
						pl_len -= 1
						loop
					endif

				endsub

			/** Speak Request Parser - sets msg header (len/ID) in buffer, places payload into buffer, and writes out buffer
			*
			* Preparing speak request for writing. Provided word must be valid null-terminated string.
			*  Size of word must be shorter than 2115 characters including null terminator.
			*
			* @param[in] req - speak request code
			* @param[in] flush_en - flash option
			* @param[in] word - char array
			* @param[in] word_len - char array length
			*/
			sub tts_parse_speak_req(req as integer, flush_en as integer, phrase_PTR as integer, phrase_len as integer)
				dim i as integer

				// setup: req msg header w/in buffer structure
				// msg len -> buffer (+7 is for header (len & msgID) + flush char + eow framing chars (2))
				wr_byte(_last_req+ISC_REQ_len_os  , (phrase_len + 7) and &HFF)
				wr_byte(_last_req+ISC_REQ_len_os+1, ((phrase_len + 7) and &HFF00) >> 8)

				// msgID -> buffer
				wr_byte(_last_req+ISC_REQ_idx_os  , req and &HFF)
				wr_byte(_last_req+ISC_REQ_idx_os+1, (req and &HFF00) >> 8)

				// setup/init last resp - overwritten when response received
				wr_byte(_last_rsp+ISC_RESP_idx_os, &HFF)
				wr_byte(_last_rsp+ISC_RESP_idx_os+1, &HFF)

				// start phrase with a 0/1 control character for flush purposes
				/* =&H00 – flush disabled – this string is spoken after any previous speak requests have been finished.
				   =&H01 – flush enabled – this TTS output is flushed and the current string is spoken immediately
				   (other values are undefined) */
				if(flush_en)
					wr_byte(_last_req+ISC_REQ_pld_os, &H01)
				else
					wr_byte(_last_req+ISC_REQ_pld_os, &H00)
				endif

				// stuff phrase into buffer
				i = 1	// 1 vs 0 is due to flush ctl char in payload B0 already
				while (phrase_len > 0)
					wr_byte(_last_req+ISC_REQ_pld_os + i  , rd_byte(phrase_PTR))
					phrase_PTR += 1
					i += 1
					phrase_len -= 1
					loop

				// space-frame and null-terminate the word in buffer
				wr_byte(_last_req+ISC_REQ_pld_os + i, &H20)	// add a space onto the end of the word
				wr_byte(_last_req+ISC_REQ_pld_os + i + 1, &H00) // add a null byte terminator onto the end of the word

				endsub

			/** Response
			*
			* Cheks SPI for response. If there is a response then this
			* function calls read response functions to fill the input buffer
			* with received data.
			*
			*/
			// amendeed this from init c lib to receive an optional parameter and to
			// pass that on to the padding loop, in the event that there is a rqmt for diff padding
			// (see protocol manual tables 10 & 11 -  ISC_BOOT_RUN_REQ & ISC_BOOT_RUN_RESP)
			sub tts_resp_get()	// pad counts are set before entry by calling sub

				// can consider letting this simply return as there is a timer running that checks hal msg ready... hmm...
				// hmm

				if tts_hal_msg_rdy

					tts_resp_read

				endif

				endsub

			/** Check Response Index
			*
			* Compares received response code with code provided as argument. Returns
			* true if codes have same value, otherwise returns false.
			*
			* @param[in] idx - response code for comparing
			*
			* @retval TRUE - codes are same
			* @retval FLASE - codes are different
			*/
			function tts_rsp_chk(idx as integer)
				dim tmp as integer

				tmp   = rd_byte(_last_rsp+ISC_RESP_idx_os)
				tmp or= rd_byte(_last_rsp+ISC_RESP_idx_os+1) << 8

				return (if(idx = tmp, true, false))	 '~
				endfunction

			#endif	// text_to_speech_hw.h/.c

		#if 1 // text_to_speech.h/.c

			/** Text to Speech Initialization
			*
			* Sets all needed internal parameters to default. This function must be called
			* before any other function.
			*/
			sub tts_init()
' print "tts_init start"

				_req_err = 0
				_err_code = 0

				_tts_rdy_f = true
				_spc_rdy_f = true
				_tts_fin_f = true
				_spc_fin_f = true

				_speaking_flush_enable = false

				_msg_block_callback = NULL
				_fatal_err_callback = NULL
				_err_callback = NULL

				// orig c source made use of structure and structures within structures.
				// this is a bit of a cludge workaround for lack of structures/unions within AB
				// but it seems to be working OK at this time

				_audio_conf = addressof(ACONF_Struct)			// added port code - structure pointers - tts.c
				_tts_conf = addressof(TTSCONF_Struct)			// added port code - structure pointers - tts.c
				_pman_conf = addressof(PMANCONF_Struct)			// added port code - structure pointers - tts.c

				_cur_audio_conf = addressof(cur_ACONF_Struct)	// added port code - structure pointers - tts.c
				_cur_tts_conf = addressof(cur_TTSCONF_Struct)	// added port code - structure pointers - tts.c
				_cur_pman_conf = addressof(cur_PMANCONF_Struct)	// added port code - structure pointers - tts.c

				_last_req = addressof(ISC_REQ_Struct)			// added port code - structure pointers - tts_hw.c
				_last_rsp = addressof(ISC_RESP_Struct)			// added port code - structure pointers - tts_hw.c

				// these structure fields are all single byte elements
				wr_byte(_audio_conf + ACONF_as_os 			, &H00)
				wr_byte(_audio_conf + ACONF_ag_os 			, &H43)		// &H00 mute, &H01 = -48db ... &H31 = 0db ... &H43 = +18db - linear
				wr_byte(_audio_conf + ACONF_amp_os			, &H00)
				wr_byte(_audio_conf + ACONF_asr_os			, ASR_11KHZ)
				wr_byte(_audio_conf + ACONF_ar_os 			, &H00)
				wr_byte(_audio_conf + ACONF_atc_os			, &H00)
				wr_byte(_audio_conf + ACONF_acs_os			, &H00)
				wr_byte(_audio_conf + ACONF_dc_os 			, &H00)

				// these structure fields are all single byte elements
				wr_byte(_tts_conf + TTSCONF_sr_os			, &H01)
				wr_byte(_tts_conf + TTSCONF_voice_os		, &H00)
				wr_byte(_tts_conf + TTSCONF_ep_os			, &H00)
				wr_byte(_tts_conf + TTSCONF_lang_os			, &H00)
				wr_byte(_tts_conf + TTSCONF_sr_wpm_lsb_os	, &HC8)	//200 wpm
				wr_byte(_tts_conf + TTSCONF_sr_wpm_msb_os	, &H00)
				wr_byte(_tts_conf + TTSCONF_ds_os			, &H00)
				wr_byte(_tts_conf + TTSCONF_res_os			, &H00)

				// these structure fields are all single byte elements
				wr_byte(_pman_conf + PMANCONF_am_lsb_os		, &H01)
				wr_byte(_pman_conf + PMANCONF_am_msb_os		, &H00)
				wr_byte(_pman_conf + PMANCONF_spi_clk_os 	, &H01)
				wr_byte(_pman_conf + PMANCONF_pad_os		, PADDING_BYTE)

' print "tts_hw_init"
				tts_hw_init()

' print "tts_init done"
				endsub

			/** Message Block Callback
			static void ( *_msg_block_callback )( uint16_t *msg_code, uint16_t *err_code );
			*
			* Callback function must be made by user and will be called
			* every time when message block response is received.
			* Message block is sent in response to a request that has been blocked by
			* the device system controller. Request messages are blocked usually when
			* the system controller identifies that there is insufficient system
			* resource to service the request.
			*
			* @note
			* All request messages are blocked if the interface has not been
			* registered.
			*
			* Example :</h4>
			*
			* @code
			* // Declaration of callback for blocked messages
			* void msg_blk(dim as integer *req, dim as integer *err)
			* {
			*     char txt(15)
			*
			*     UART_Write_Text(" Message blocked : ")
			*     sprinti(txt, "%x\r\n", *req)
			*     UART_Write_Text(txt)
			*     sprinti(txt, "%x\r\n", *err)
			*     UART_Write_Text(txt)
			* }
			*
			* // Setting up
			* tts_msg_block_callback(msg_blk)
			* @endcode
			*
			*/

			'sub tts_msg_block_callback(msg_blk_ptr as integer, req_ptr as integer, err_ptr as integer)
			sub tts_msg_block_callback(msg_blk_ptr as integer)
				_msg_block_callback = msg_blk_ptr	// a global
				endsub

			/** Fatal Error Callback
			*
			* This function adds the callback function made by user that will be called
			* every time when fatal error indication is received so user can handle
			* fatal error exception. Once fatal error is received user should
			* restart the module.
			*
			* Example :</h4>
			*
			* @code
			* // Declaration of callback for fatal errors
			* void fatal_err(dim as integer *err)
			* {
			*     UART_Write_Text("Fatal Error Occured - TTS restart...")
			*     // Reinitialization of TTS
			*     tts_init()
			*     // Reset the callback
			*     tts_fatal_err_callback(fatal_err)
			* }
			*
			* // Setting up
			* tts_fatal_err_callback(fatal_err)
			* @endcode
			*/
				 'sub tts_fatal_err_callback(fatal_err_ptr as integer, err_ptr as integer)
			sub tts_fatal_err_callback(fatal_err_ptr as integer)
				_fatal_err_callback = fatal_err_ptr	// a global
				endsub

			/** Non Fatal Error
			*
			* This function adds the callback function made by user that will be called
			* every time when non fatal error inidication is received.
			*
			* Example :</h4>
			*
			* @code
			* // Declaration of callback for error occurence
			* void err_detected(dim as integer *err)
			* {
			*     char txt(15)
			*
			*     UART_Write_Text(" Error occured : ")
			*     sprinti(txt, "%x\r\n", *err)
			*     UART_Write_Text(txt)
			* }
			*
			* // Setting up
			* tts_err_callback(err_detected)
			* @endcode
			*/
				 'sub tts_err_callback(error_ptr as integer, err_ptr as integer)
			sub tts_err_callback(error_ptr as integer)
				_err_callback = error_ptr	// a global
				endsub

			/** TTS Hardware Mute
			*
			* Mute using MUT pin
			*/
			sub tts_mute()
				tts_mute_cmd(true)
				endsub

			/** TTS Hardware Unmute
			*
			* Unmute using MUT pin
			*/
			sub tts_unmute()
				tts_mute_cmd(false)
				endsub

			/** Requests Version in Boot Mode
			*
			* Used to request information about the chip hardware version.
			* This request should be performed after the power on or restart
			* routine. The functionality to wait RESET_TO_BOOT_TIME
			* is already implemented into the restart function and don 't care
			* about that timing. This is the simpliest way to check that device is
			* powered on and to check the basic functionality of the device itself.
			* For detailed information about version of the device you should use
			* tts_version_main. For more information see VER_t.
			*
			* Example :
			*
			* VER_t boot_ver 'declares the variable as a pre-defined structure
			*
			*typedef struct
			*	{
			*		char            hwver(5); 'first 5 bytes are char type
			*		char            fwver(8); 'next 8 bytes are char type
			*		FF_t            fwf; 'then an embedded structure (pair of bytes) that nibble-maps to to 2 features flags via an array B1:0
			*		EFF_t           fwef; 'ends w/ an embedded struct (byte) that bitmaps to features flags via an array b5:0
			*
			*	}VER_t;
			*
			*typedef enum
			*	{
			*		/**
			*		 * Text to Speech * /
			*		FF_TTS                                                      = &H0001,
			*		/**
			*		 * ADPCM * /
			*		FF_ADPCM                                                    = &H0010,
			*		/**
			*		 * GPIO * /
			*		FF_GPIO                                                     = &H0100
			*
			*	}FF_t;
			*
			*	typedef enum
			*	{
			*		/**
			*		 * US English * /
			*		EFF_US                                                      = &H01,
			*		/**
			*		 * German * /
			*		EFF_D                                                       = &H02,
			*		/**
			*		 * Castilian Spanish * /
			*		EFF_CS                                                      = &H04,
			*		/**
			*		 * French * /
			*		EFF_F                                                       = &H08,
			*		/**
			*		 * UK English * /
			*		EFF_UK                                                      = &H10,
			*		/**
			*		 * Latin Spanish * /
			*		EFF_LS                                                      = &H20
			*
			*	}EFF_t;
			*
			* if(not tts_version_boot(boot_ver)) 'always returns a &H0000, unless an error exists - somewhat inverted logic, but meh
			* {
			*     UART_Write_Text(boot_ver.hwver) 'if it returned a &H0000, then prints the hw.ver portion of the structure
			* }
			*/
			function tts_version_boot(version_ptr as integer) as integer

				dim temp_str(8), tmp_resp(16) as byte
				dim i as integer

				memset(addressof(temp_str),&H00,9)
				memset(addressof(tmp_resp),&H00,17)

				tts_asmdly(reset_to_boot_asmdly_period)

				tts_parse_req(ISC_VERSION_REQ_BOOT, NULL, 0)	// place msg in buffer

				_pad_bytes_reqd = 16							// pad the sent msg with 16 pad bytes per protocol manual 3.4

				tts_write_req(tts_leave_cs_active)				// and then send it

				_pad_bytes_reqd = 16							// pads the rx msg with 16 pad bytes per protocol manual 3.4

				while(not(tts_rsp_chk(ISC_VERSION_RESP_BOOT)))  // while waiting for a specific response

					tts_resp_get()								// do a non-blocking check to see if msg_ready is signaled by slave

					if(tts_parse_last_rsp_ind())				// and parse any ad-hoc msgs received

						return _err_code						// unless one indicates and error, then bork out
						endif
					loop										// and keep waiting

				tts_rsp_data(addressof(tmp_resp))

				temp_str = sprintf("%d",tmp_resp(0)) + "." + sprintf("%d",tmp_resp(1))

				i = 0
				while(temp_str(i)<>0)
					wr_byte(version_ptr+i, temp_str(i))
					i += 1
					loop

				return &H0000
				endfunction

			/** Sends Code Image to TTS module for loading into SRAM
			*
			* This request must be pefrormed after the power on or restart
			* routine and before the entering to main mode.
			*
			* @param[in] image - valid image
			* @param[in] count - image length in bytes
			*
			* @note Keep on mind that because of large image size this loadnig can take
			* few seconds, depends on SPI bus speed.
			*
			* Example :
			*
			* @code
			* if(not tts_runtime_image_xmit(TTS_INIT_DATA, sizeof(TTS_INIT_DATA)))
			*     UART_Write_Text("Image loading done successfully")
			* else
			*     UART_Write_Text("Image loading error")
			* @endcode
			*/
			function tts_runtime_image_xmit(image_ptr as integer, count as integer) as integer
				dim tmp_resp, index as integer
				dim raw_resp(2) as byte

				tmp_resp = 0
				index = 0

				memset(addressof(raw_resp),&H00,3)

				// commented tf out of this as I was having a hell of a time getting the module to launch
				// the runtime image from boot mode.  Everything worked up to the point of executing the
				// runtime and then it friggin just sat there fat, dumb, and did nutin but generate heat.
				// Finally, at my final hours of exasperation - being ready to shelve this whole effort,
				// I looked at Epson's site and found where they had provided an image in a bin file.
				// I did a .hex C export of same and replaced the original image with that one and viola
				// issue resolved.  Left all of the comments here for posterity's sake...	'~

																				// send full blocks until only a partial block remains
				while ((count - index) > (BOOT_MESSAGE_MAX - 4))				// we're doing a series of 2K chunks here
					tts_runtime_img_parse(image_ptr + index, BOOT_MESSAGE_MAX - 4)	// stuff msg header and payload chunk into buffer

					_pad_bytes_reqd = 16										// setup proper padding to be sent in tts_resp_get
					tts_write_req(tts_leave_cs_active)							// and transmit it out of the serial port

					_pad_bytes_reqd = 16										// setup proper padding to be sent in tts_resp_get
					while(not(tts_rsp_chk(ISC_BOOT_LOAD_RESP)))					// keep doing a non-comms-block response check
						tts_resp_get()											// get any response, padding therein
						if(tts_parse_last_rsp_ind())							// process any ad-hoc responses received
							return _err_code									// borking out if an error exists
							endif												// otherwise
						loop													// keep listening for needed response	'~
					index += (BOOT_MESSAGE_MAX - 4)								// once we have it, index the counter
					loop														// and keep stuffing away until we can ...

																				// send the final partial block
				tts_runtime_img_parse(image_ptr + index, count - index)			// start with stuffing payload chunk into buffer
				_pad_bytes_reqd = 16											// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)								// and send it ...

																				// and wait for a response	'~
				_pad_bytes_reqd = 16											// pads the rx msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_BOOT_LOAD_RESP)))                     // keep doing a non-comms-block response check
					tts_resp_get()												// get any response, padding therein
					if(tts_parse_last_rsp_ind())                                // process any ad-hoc responses received
						return _err_code                                        // borking out if an error exists
						endif                                                   // otherwise
					loop                                                        // keep listening for needed response	'~

				tts_rsp_data(addressof(raw_resp))								// get response data from rx buffer into local variable

																				// do some codes to pull out the response message payload
				tmp_resp   = raw_resp(0)										// we're looking for a ...
				tmp_resp or= raw_resp(1) << 8									// ... &H0001 (successful image xfer response)

				if tmp_resp = 1													// since we got the response we want
					return &H0000												// return a no-error null
				else															// otherwise
					return tmp_resp												// return the response received
					endif														// and we're done

				endfunction

			/** Starts Executing Image and Enters the Main Mode
			*
			* This request enters from boot to main mode after completion of loading the
			* initialisation data. This function is used to switch to running in main
			* mode. The functionality to wait
			* @link
			* BOOT_TO_MAIN_MODE
			* @endlink
			* is already implemented inside the restart function so don 't care
			* about that timing.
			*
			* Example :
			*
			* @code
			* if(not tts_runtime_image_exec())
				   UART_Write_Text("Main mode entered successfully")
			* @endcode
			*/
			function tts_runtime_image_exec() as integer
				dim tmp_resp, j as integer
				dim raw_resp(2) as byte

				tmp_resp = 0
				memset(addressof(raw_resp),&H00,3)

				tts_parse_req(ISC_BOOT_RUN_REQ, NULL, 0)		// xmit app run request (no payload)

				_pad_bytes_reqd = 8								// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)				// includes padding sent msg with 8 pad bytes per protocol manual 4.4.2.5

																// and wait for a response	'~
				_pad_bytes_reqd = 8								// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_BOOT_RUN_RESP)))
					tts_resp_get()								// includes padding rcv'd msg with 8 pad bytes per protocol manual 4.4.2.5

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				// get response data from rx buffer into local variable
				tts_rsp_data(addressof(raw_resp))

				// do some codes to pull out the message payload
				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				if tmp_resp = 1
					return &H0000
				else
					return tmp_resp
				endif

				endfunction

			/** Register Host Hardware & Test Interface
			*
			* This request must be called after the entering the main mode because it
			* register the host with the device (S1V30120). If request is performed
			* without errors that indicates the device is operating correctly and host
			* registration was successful.
			*
			* Example :
			*
			* @code
			* if(not tts_reg_host_n_test_interface())
			*     UART_Write_Text("Host Register & Interface test - success")
			* @endcode
			*/
			function tts_reg_host_n_test_interface() as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				tmp_resp = 0
				memset(addressof(raw_resp),&H00,3) // clear any residual stuff on entry

				tts_asmdly(boot_to_main_mode_asmdly_period)

				tts_parse_req(ISC_TEST_REQ, addressof(tts_RegHostPayload), 8)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TEST_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Version & Support Info in Main Mode
			*
			* Used to request information about the hardware version, firmware
			* version and supported firmware functionality. Returns informations
			* about current system version, more info
			* @link VER_t @endlink
			*
			* Example :
			*
			* @code
			* VER_t current_version
			*
			* if (not tts_version_main(&current_version))
			* {
			*     UART_Write_Text(current_version.hwver)
			*     UART_Write_Text(current_version.fwver)
			* }
			* @endcode
			*/
			function tts_version_main(buffer_ptr as integer) as integer

				dim tmp_resp(20) as byte
				dim temp_hwver_str(8), temp_fwver_str(12) as byte  ' string
				dim i as integer

				memset(addressof(tmp_resp),&H00,21)
				memset(addressof(temp_hwver_str),&H00,9)
				memset(addressof(temp_fwver_str),&H00,23)

				tts_parse_req(ISC_VERSION_REQ_MAIN, NULL, 0)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4

				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4

				while(not(tts_rsp_chk(ISC_VERSION_RESP_MAIN)))

					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(tmp_resp))

				temp_hwver_str = sprintf("%d",tmp_resp(0)) + "." + sprintf("%d",tmp_resp(1))

				i = 0
				while(temp_hwver_str(i)<>0)
					wr_byte(buffer_ptr+VER_hwver_os+i, temp_hwver_str(i))
					i += 1
					loop

				temp_fwver_str = sprintf("%d",tmp_resp(2)) + "." + sprintf("%d",tmp_resp(3)) + "." + sprintf("%d",tmp_resp(12))

				i = 0
				while(temp_fwver_str(i)<>0)
					wr_byte(buffer_ptr+VER_fwver_os+i, temp_fwver_str(i))
					i += 1
					loop

				i = 0
				while(i<4)
					wr_byte(buffer_ptr+VER_fwf_os+i, rd_byte(addressof(tmp_resp)+4+i)
					i += 1
					loop

				i = 0
				while(i<4)
					wr_byte(buffer_ptr+VER_fwef_os+i, rd_byte(addressof(tmp_resp)+8+i)
					i += 1
					loop

				return &H0000
				endfunction

			/** Power Manager Configuration
			*
			* Request to configure power manager with default parameters.
			*
			* @note All of parameters are configured automaticly by device
			* and this request also doesnt have any parameters yet.
			*
			* Example :
			*
			* @code
			* if(not tts_power_default_config())
			*     UART_Write_Text("Power configuration done  not ")
			* @endcode
			*/
			function tts_power_default_config() as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				memset(addressof(raw_resp),&H00,3)

				tts_parse_req(ISC_PMAN_CONFIG_REQ, _pman_conf, 4)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_PMAN_CONFIG_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Entry to standby mode
			*
			* Request can be used to reach the lowest power mode.
			* Most power management on the device is performed automatically by the
			* device without intervention from the host.
			* However, to reach the lowest power mode, Standby Mode, the host has to
			* request entry to this mode. Device can leave this mode only with
			* @link tts_standby_exit @endlink.
			* Time needed to enter the standby mode
			* @link STBY_MODE_ENTERY @endlink
			* is already implemented and you don't have to care about that.
			*
			* Example :
			*
			* @code
			* if(not tts_standby_enter())
			*     UART_Write_Text("Standby mode entered  not ")
			* @endcode
			*/
			function tts_standby_enter() as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				memset(addressof(raw_resp),&H00,3)

				tts_parse_req(ISC_PMAN_STANDBY_ENTRY_REQ, NULL, 0)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_PMAN_STANDBY_ENTRY_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Standby Mode Exit
			*
			* Request wakes up the device from standby mode. This is only request
			* that device can performe whhile it is in standby mode.
			*
			* Example :
			*
			* @code
			* if(not tts_standby_exit())
			*     UART_Write_Text("Standby mode exited  not ")
			* @endcode
			*/
			function tts_standby_exit() as integer
				tts_asmdly(stby_mode_entry_asmdly_period)
				tts_parse_req(ISC_PMAN_STANDBY_EXIT_IND, NULL, 0)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_PMAN_STANDBY_EXIT_IND)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
				loop

				return &H0000
				endfunction

			/** stall until current speech completes
			*
			*/
			function tts_wait_ttsfin() as integer

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_FINISHED_IND)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
				loop

				return &H0000
				endfunction

			/** Configure Audio Output
			*
			* Audio configuration is required before starting speech/audio playback.
			* Request sends default audio configuration to device.
			*
			* Example :
			*
			* @code
			* if(not tts_audio_default_config())
			*     UART_Write_Text("Audio configuration done  not ")
			* @endcode
			*/
			function tts_audio_default_config() as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				memset(addressof(raw_resp),&H00,3)

				tts_parse_req(ISC_AUDIO_CONFIG_REQ, _audio_conf, 8)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_AUDIO_CONFIG_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Sets the audio output configuration.
			*
			*
			* Audio configuration is required before starting speech/audio playback.
			* @param[in] audio_gain (-49 - 19)
			* @param[in] sample_rate
			* @param[in] dac_control (true / false)
			*
			* Example :
			*
			* @code
			* if(not tts_audio_config(10, ASR_11KHZ, true))
			*     UART_Write_Text("Advanced audio configuration done  not ")
			* @endcode
			*/
			function tts_audio_config(audio_gain as integer, sample_rate as integer, dac_control as integer) as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				memset(addressof(raw_resp),&H00,3)

				if ((audio_gain < -48) or (audio_gain > 18))
					return &HFFFF
					endif

				if ((sample_rate <> 0) or (sample_rate <> 1) or (sample_rate <> 3))
					return &HFFFF
					endif

				wr_byte(_cur_audio_conf + ACONF_as_os 			, &H00)
				wr_byte(_cur_audio_conf + ACONF_ag_os 			, audio_gain)
				wr_byte(_cur_audio_conf + ACONF_amp_os			, &H00)
				wr_byte(_cur_audio_conf + ACONF_asr_os			, sample_rate)
				wr_byte(_cur_audio_conf + ACONF_ar_os 			, &H00)
				wr_byte(_cur_audio_conf + ACONF_atc_os			, &H00)
				wr_byte(_cur_audio_conf + ACONF_acs_os			, &H00)
				wr_byte(_cur_audio_conf + ACONF_dc_os 			, dac_control)

				tts_parse_req(ISC_AUDIO_CONFIG_REQ, _cur_audio_conf, 8)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_AUDIO_CONFIG_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Set volume (Analog Gain)
			*
			* Request changes the output audio volume and sends it to the device.
			* Value is gain increment / decrement in dB.
			*
			* @param[in] audio_gain
			*
			* Example :
			*
			* @code
			* if(not tts_volume_set(0))
			*     UART1_Write_Text("Volume setting done  not ")
			* @endcode
			*/
			function tts_volume_set(gain as integer) as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_gain(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_gain),&H00,3)

				tmp_gain(0) = gain and &H00FF
				tmp_gain(1) = (gain and &HFF00) >> 8

				tts_parse_req(ISC_AUDIO_VOULME_REQ, addressof(tmp_gain), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_AUDIO_VOLUME_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Mute Audio Output
			*
			* Request mutes the audio output immediately.
			*
			* Example :
			*
			* @code
			* if(not tts_audio_mute())
			*     UART1_Write_Text("Audio muted  not ")
			* @endcode
			*/
			function tts_audio_mute() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_mute(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_mute),&H00,3)
				tmp_mute(0) = 1

				tts_parse_req(ISC_AUDIO_MUTE_REQ, addressof(tmp_mute), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_AUDIO_MUTE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Unmute Audio Output
			*
			* Request mutes the audio output immediately.
			*
			* Example :
			*
			* @code
			* if(not tts_audio_unmute())
			*     UART1_Write_Text("Audio unmuted  not ")
			* @endcode
			*/
			function tts_audio_unmute() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_mute(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_mute),&H00,3)

				tts_parse_req(ISC_AUDIO_MUTE_REQ, addressof(tmp_mute), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_AUDIO_MUTE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Configure Speech Codec
			*
			* The Speech Codec application supports Voice Playback (Decode) using an
			* ADPCM codec. This is request to configure the codec and can only be used
			* when the SPCODEC is inactive. Currently all parameters are default so there
			* is no setable parameters in this request.
			*/
			function tts_codec_configure() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_codec(32) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_codec),&H00,33)

				tmp_codec(0) = &H01
				tmp_codec(1) = &H01
				tmp_codec(24) = &H02	// really.?.

				tts_parse_req(ISC_SPCODEC_CONFIG_REQ , addressof(tmp_codec), 32)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_SPCODEC_CONFIG_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Start Speech Codec
			*
			* Request is used to transfer data to the speech decoder.
			*/
			function tts_codec_start(codec_data as integer, count as integer) as integer
				dim tmp_f, tmp_resp as integer
				dim raw_resp(2) as byte

				tmp_f = false
				memset(addressof(raw_resp),&H00,3)

				if (count <> 512 or count <> 1024 or count <> 2048)
					return &HFFFF
					endif

// this seems to be a possible copy/paste error - need to look at orig .c sources
				// while(not(_spc_fin_f))
					// tts_resp_get()

					// if(tts_parse_last_rsp_ind())
						// return _err_code
						// endif
				// loop

				tts_parse_req(ISC_SPCODEC_START_REQ , addressof(codec_data), count)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_spc_rdy_f = 0
				_spc_fin_f = 0

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tmp_f and _spc_rdy_f))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif

					if(tts_rsp_chk(ISC_TTS_SPEAK_RESP))
						tts_rsp_data(addressof(raw_resp))

						tmp_resp   = raw_resp(0)
						tmp_resp or= raw_resp(1) << 8
						tmp_f = true
						endif
					loop

				return tmp_resp
				endfunction

			/** Pause Speech Codec Audio Input / Output
			*
			* Request to pause the speech decoders to processing speech data.
			*/
			function tts_codec_pause() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_data(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_data),&H00,3)
				tmp_data(0) = 1

				tts_parse_req(ISC_SPCODEC_PAUSE_REQ , addressof(tmp_data), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_SPCODEC_PAUSE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Unpause Speech Codec Audio Input / Output
			*
			* Request to unpause the speech decoders to processing speech data.
			*/
			function tts_codec_unpause() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_data(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_data),&H00,3)

				tts_parse_req(ISC_SPCODEC_PAUSE_REQ , addressof(tmp_data), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_SPCODEC_PAUSE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Stop Speech Codec Immediately
			*
			* Request to terminate the decode of speech data immediately. Audio data
			* already decoded will be processed before termination. If the SPCODEC is
			* reset, system resources used by the SPCODEC are freed, and all configuration
			* data is lost (the SPCODEC is finalised).
			*
			* @param[in] reset
			*/
			function tts_codec_stop(reset as integer) as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_data(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_data),&H00,3)

				if(reset)
					tmp_data(0) = 1
					endif

				tts_parse_req(ISC_SPCODEC_STOP_REQ, addressof(tmp_data), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_SPCODEC_PAUSE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Configure the TTS
			*
			* Request sends the default configuration to the device and can be used when
			* the TTS system is inactive.
			*
			* Example :
			*
			* @code
			* if(not tts_write_default_mod_config())
			*     UART1_Write_Text("TTS configured  not \")
			* @endcode
			*/
			function tts_write_default_mod_config() as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				memset(addressof(raw_resp),&H00,3)

				tts_parse_req(ISC_TTS_CONFIG_REQ, _tts_conf, 8) // _tts_conf is a pre-loaded buffer

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_CONFIG_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Default setup
			*
			* Should be used after the  tts_init to upload the init data
			* and configure the click board in the most common manner.
			*/
			sub tts_setup()

				dim version(32) as byte	// dummy variable for use with versioning codes below

' print "tts_init"
				tts_init()

				print" - Hardware Ver: ";
' print "tts_version_boot"
				if(not tts_version_boot(addressof(version)))
					print sprintf ("%X.%X",rd_byte(_last_rsp+ISC_RESP_pld_os),rd_byte(_last_rsp+ISC_RESP_pld_os+1))
					print " - Loading Run-Time Image: ";
				else
					Print " - error getting tts_version_boot"
					stop
				endif

' print "tts_runtime_image_xmit"
				if(not tts_runtime_image_xmit(addressof(TTS_INIT_DATA), TTS_INIT_DATA_Size))
					// no errors - do nutin
				else
					Print " - error loading runtime image"
					stop
				endif

' print "tts_runtime_image_exec"
				if(not tts_runtime_image_exec())
					// no errors - do nutin
				else
					Print " - error when entering main mode"
					stop
				endif

' print "tts_reg_host_n_test_interface"
				if(not tts_reg_host_n_test_interface())
					// no errors - do nutin
				else
					Print " - error on registration"
					stop
				endif

' print "tts_version_main"
				if(not tts_version_main(addressof(version)))
					print sprintf ("%d.%d.%d",rd_byte(_last_rsp+ISC_RESP_pld_os+2),rd_byte(_last_rsp+ISC_RESP_pld_os+3),rd_byte(_last_rsp+ISC_RESP_pld_os+12))
				else
					Print " - error getting tts_version_main"
					stop
				endif

' print "tts_power_default_config"
				if(not tts_power_default_config())
					// no errors - do nutin
				else
					Print " - error on config of power parameters"
					stop
				endif

' print "tts_audio_default_config"
				if(not tts_audio_default_config())
					// no errors - do nutin
				else
					Print " - error on config of audio parameters"
					stop
				endif

' print "tts_volume_set"
				if(not tts_volume_set())
					// no errors - do nutin
				else
					Print " - error on config of volume parameters"
					stop
				endif

' print "tts_write_default_mod_config"
				if(not tts_write_default_mod_config())
					// no errors - do nutin
				else
					Print " - error writing default module config parameters"
					stop
				endif

' print "tts_setup done"
				endsub

			/** Sets the text to speech configuration
			*
			* Request sends the user provided configuration to the device and can be used
			* when the TTS system is inactive.
			*
			* @param[in] voice_type (0 - 9)
			* @param[in] epson_parse (true / false)
			* @param[in] language
			* @param[in] speaking_rate (&H004A - &H0259)
			*
			* Example :
			*
			* @code
			* if(not tts_config(&H01, false, TTSV_US, &H0200))
			*     UART_Write_Text("TTS advanced configuration done  not ")
			* @endcode
			*/
			function tts_config(voice_type as integer, epson_parse as integer, language as integer, speaking_rate as integer) as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte

				memset(addressof(raw_resp),&H00,3)

				// bounds checks

				if (voice_type > 8)
					return &HFFFF
					endif

				if (language > 4)
					return &HFFFF
					endif

				if (speaking_rate < &H004B or speaking_rate > &H0258)
					return &HFFFF
					endif

				wr_byte(_cur_tts_conf + TTSCONF_sr_os			, &H01)			// sample rate
				wr_byte(_cur_tts_conf + TTSCONF_voice_os		, voice_type)
				wr_byte(_cur_tts_conf + TTSCONF_ep_os			, epson_parse)
				wr_byte(_cur_tts_conf + TTSCONF_lang_os			, language)
				wr_byte(_cur_tts_conf + TTSCONF_sr_wpm_lsb_os	, (speaking_rate and &H00FF))			//200 wpm
				wr_byte(_cur_tts_conf + TTSCONF_sr_wpm_msb_os	, ((speaking_rate and &HFF00) >> 8))
				wr_byte(_cur_tts_conf + TTSCONF_ds_os			, &H00)
				wr_byte(_cur_tts_conf + TTSCONF_res_os			, &H00)

				tts_parse_req(ISC_TTS_CONFIG_REQ, _cur_tts_conf, 8)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_CONFIG_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Start the TTS (Optionally Attach Data)
			*
			* Request sends the text data to the device. User can't send more data until
			*  the response indication that device is ready for more data is received.
			*
			* Example :
			*
			* @code
			* if(not tts_speak("Hello world"))
			*     UART1_Write_Text("Speak done!")
			* else
			*     UART1_Write_Text("Speak ERROR!")
			* @endcode
			*/
			function tts_speak(byref tts_str as string) as integer
				dim tmp_resp as integer
				dim raw_resp(2) as byte
				dim wlen, tts_cmd_ack_f, wptr, word_ptr as integer
				dim tts_string(255) as string

				tts_string = tts_str

				wptr = addressof(tts_string)
				word_ptr = addressof(tts_string)

				// count the # of characters to be emitted
				wlen = 0
				while(rd_byte(word_ptr)<>&H00)
					wlen += 1
					word_ptr += 1
					loop

				tts_cmd_ack_f = false
				memset(addressof(raw_resp),&H00,3)

				tts_parse_speak_req(ISC_TTS_SPEAK_REQ, _speaking_flush_enable, wptr, wlen)

				tts_write_req(tts_leave_cs_active)
				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4

				_tts_rdy_f = 0
				_tts_fin_f = false

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while((tts_cmd_ack_f = 0) or (_tts_rdy_f=0))
					tts_resp_get()
					if(tts_parse_last_rsp_ind())
						return _err_code
						endif

					if(tts_rsp_chk(ISC_TTS_SPEAK_RESP))
						tts_rsp_data(addressof(raw_resp))

						tmp_resp   = raw_resp(0)
						tmp_resp or= raw_resp(1) << 8
						tts_cmd_ack_f = true
						endif
					loop

				return tmp_resp
				endfunction

			/** Pause TTS
			*
			* Request will stop or restart the speech synthesiser text proccessing.
			* Time must be allowed for the audio output buffers to drain before the pause
			* can take effect.
			*
			* Example :
			*
			* @code
			* if(not tts_pause())
			*     UART_Write_Text("Paused  not ")
			* @endcode
			*/
			function tts_pause() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_pause(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_pause),&H00,3)
				tmp_pause(0) = 1

				tts_parse_req(ISC_TTS_PAUSE_REQ, addressof(tmp_pause), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_PAUSE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Unpause TTS
			*
			* Request will resume the speech synthesiser.
			*
			* Example :
			*
			* @code
			* if(not tts_unpause())
			*     UART_Write_Text("Unpaused  not ")
			* @endcode
			*/
			function tts_unpause() as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_pause(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_pause),&H00,3)

				tts_parse_req(ISC_TTS_PAUSE_REQ, addressof(tmp_pause), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_PAUSE_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Stop TTS Immediately
			*
			* Request that should be executed to stop text sythesis in order to free
			* system resources associated with TTS. Device can be reset after the this
			* request and, in that case, all configuration data is lost.
			*
			* @param[in] reset (true / false)
			*
			* Example :
			*
			* @code
			* if(not tts_stop())
			*     UART_Write_Text("Stoped  not ")
			* @endcode
			*/
			function tts_stop(reset as integer) as integer
				dim tmp_resp as integer
				dim raw_resp(2), tmp_reset(2) as byte

				memset(addressof(raw_resp),&H00,3)
				memset(addressof(tmp_reset),&H00,3)

				if(reset)
					tmp_reset(0) = &H01
					endif

				tts_parse_req(ISC_TTS_STOP_REQ, addressof(tmp_reset), 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_STOP_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(raw_resp))

				tmp_resp   = raw_resp(0)
				tmp_resp or= raw_resp(1) << 8

				return tmp_resp
				endfunction

			/** Send User Dictionary Data to the Device
			*
			* Request sends user dictionary data. User dictionary data is transferred in a
			* single message. Erase parameter is used to erase any previously transferred
			* user dictionary data. Udict data must be valid and counter is size of data
			* in bytes.
			*
			* @param[in] erase (true / false)
			* @param[in] udict_data
			* @param[in] count
			*/
			function tts_user_dict(erase as integer, udict_data_ptr as integer, count as integer) as integer
				dim cnt, tmp_rsp as integer
				dim rsp_data(2), tmp_data(BOOT_MESSAGE_MAX) as byte

				cnt = 2
				memset(addressof(rsp_data),&H00,3)
				memset(addressof(tmp_data),&H00,BOOT_MESSAGE_MAX+1)

				if (erase)
					tmp_data(0) = 1
					endif

				while (count)
					' tmp_data(cnt) = *(udict_data_ptr)
					tmp_data(cnt) = rd_byte(udict_data_ptr)
					udict_data_ptr += 1
					cnt += 1
					count -= 1
					loop

				tts_parse_req(ISC_TTS_UDICT_DATA_REQ, addressof(tmp_data), count + 2)

				_pad_bytes_reqd = 16					// pad the sent msg with 16 pad bytes per protocol manual 3.4
				tts_write_req(tts_leave_cs_active)

				_pad_bytes_reqd = 16					// pads the received msg with 16 pad bytes per protocol manual 3.4
				while(not(tts_rsp_chk(ISC_TTS_UDICT_DATA_RESP)))
					tts_resp_get()

					if(tts_parse_last_rsp_ind())
						return _err_code
						endif
					loop

				tts_rsp_data(addressof(tmp_rsp))

				tmp_rsp   = rsp_data(0)
				tmp_rsp or= rsp_data(1) << 8

				return tmp_rsp
				endfunction

			#endif	// text_to_speech.h/.c

		#endif	// Lib Functions and Subs

	#endif // tts_lib mult include guard
